/*****************************************************************************
 *  Rohde&Schwarz BTC Broadcast Test Center instrument driver     
 *  VXIpnp Style Instrument Driver
 *  Original Release: 12/2013
 *  By: 
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *
 *  Modification History:
 *    see rsbtc_vxi.chm
 *****************************************************************************/

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "rsbtc.h"
#include "rsidr_core.h"

#include "time.h"
#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
    #define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
        #include <windows.h>
#endif 
static ViString  stateArr[] = {"OFF","ON"};  
static ViString  cmmbPlchRsArr[] = {"0","1","2","3"};      
static ViString  cmmbPlchLdpdArr[] = {"R1_2","R3_4"};   
static ViString  cmmbPlchConstArr[] = {"C2","C4","C16"};

static ViString  waveformFileTagArr[] = {"TYPE","CRESTFACTOR","LEVEL OFFS","CLOCK","SAMPLES","IQ SWAP","DATE","COMMENT"};
static ViString  statusRegisterArr[] = {"COND","EVEN","ENAB","PTR","NTR"};

/*****************************************************************************
 * Function: rsbtc_init
 * Purpose:  VXIplug&play required function. Calls the
 *           rsbtc_InitWithOptions function.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice, ViSession *newInstrSession)
{
    ViStatus    error = VI_SUCCESS;

    if (newInstrSession == NULL)
        {
        (void) Rs_SetErrorInfo (0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                          VI_ERROR_PARAMETER4, "Null address for Instrument Handle");
        checkErr( RS_ERROR_INVALID_PARAMETER);
        }

    checkErr( rsbtc_InitWithOptions (resourceName, IDQuery, resetDevice,
                                      "QueryInstrStatus=1", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rsbtc_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_InitWithOptions(
    ViRsrc          resourceName,
    ViBoolean       IDQuery,
    ViBoolean       resetDevice,
    ViString        optionString,
    ViSession      *newInstrSession
)
{
    ViStatus                error = VI_SUCCESS;
    ViChar                  newResourceName[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar                  newOptionString[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViBoolean               isLogicalName = 0;
    ViSession               instrSession = 0, rmSession = 0;
    RsAttrPropertiesPtr     *attrList=NULL;
    RsRepCapPtr             repCapTable = NULL;

    if (newInstrSession == NULL)
        {
        (void) Rs_SetErrorInfo (0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                         VI_ERROR_PARAMETER5, "Null address for Instrument Handle");
        checkErr( RS_ERROR_INVALID_PARAMETER);
        }

    /* Prepare resource manager session handle */
    checkErr (viOpenDefaultRM (&rmSession));

    /* Establish communication session with the instrument */

    viCheckErr( viOpen (rmSession, resourceName, 0, 0, &instrSession));
    
    viCheckErr( viClear (instrSession));
    /* Configure VISA Formatted I/O */
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, 30000 ));
    viCheckErr( viSetBuf (instrSession, (ViUInt16) (VI_READ_BUF | VI_WRITE_BUF), 4000));
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_WR_BUF_OPER_MODE, VI_FLUSH_ON_ACCESS));
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_RD_BUF_OPER_MODE, VI_FLUSH_ON_ACCESS));

    checkErr( Rs_GetInfoFromResourceName (resourceName,
                                          (ViString)optionString,
                                          newResourceName,
                                          newOptionString,
                                          &isLogicalName));

    ATTRLIST(attrList,rsbtc); 
    checkErr( Rs_SpecificDriverNew (instrSession, "rsbtc", newOptionString, attrList));

    /* Build repeated capability table */
    REPCAPTABLE(repCapTable,rsbtc);
    checkErr( Rs_BuildRepCapTable (instrSession, repCapTable));


    /* With remote control via Ethernet, remote control is not automatically
       set by means of a command. The instrument must be explicitly set to
       the REMOTE state, e.g. by sending the intf command &GTR
    */
    checkErr (viWrite (instrSession, (ViBuf) "&GTR\n", 5, NULL));
    
    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice == VI_TRUE)
    {
        checkErr( rsbtc_reset (instrSession));
    }
    else  /*- Send Default Instrument Setup ---------------------------------*/
        checkErr( rsbtc_DefaultInstrSetup (instrSession));

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery == VI_TRUE)
        {
        ViChar rdBuffer[RSBTC_IO_BUFFER_SIZE] = "";

        checkErr( Rs_GetAttribute (instrSession, NULL, (ViAttr) RSBTC_ATTR_ID_QUERY_RESPONSE,
                                   0, RSBTC_IO_BUFFER_SIZE, rdBuffer));

        if (strncmp (rdBuffer, RSBTC_VALID_ID_RESPONSE_STRING, strlen(RSBTC_VALID_ID_RESPONSE_STRING)) != 0)
            {
            viCheckErr( VI_ERROR_FAIL_ID_QUERY);
            }
        }

    if (isLogicalName == VI_FALSE)
        {
        ViInt32 oldFlag = 0;

        checkErr (Rs_GetAttributeFlags (instrSession, RS_ATTR_IO_RESOURCE_DESCRIPTOR, &oldFlag));
        checkErr (Rs_SetAttributeFlags (instrSession, RS_ATTR_IO_RESOURCE_DESCRIPTOR, oldFlag & 0xfffb | 0x0010));
        checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_IO_RESOURCE_DESCRIPTOR, 0, newResourceName));
        }
    

    if (isLogicalName == VI_TRUE)
        checkErr( Rs_ApplyDefaultSetup (instrSession));

    /* Instrument session accessible by the end user is native VISA session,
       or when simulated virtual instrument (vi) session. */
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_VISA_RM_SESSION, 0, &rmSession));

    checkErr( rsbtc_CheckStatus (instrSession));

Error:

   if (error < VI_SUCCESS)
    {
        if (instrSession != 0)
        {
            (void) viClose (instrSession);
            (void) Rs_Dispose (instrSession);
        }

        if (rmSession != 0)
            (void) viClose (rmSession);
    }
    else
    {
        *newInstrSession = instrSession;
    }
    return error;
}

/// HIFN  This function configures Tx modulator.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_BASEBAND_SIGNAL_TYPE
/// HIFN     RSBTC_ATTR_BASEBAND_SIGNAL_FREQUENCY_OFFSET
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR signalType/This control selects the signal type. 
/// HIPAR frequencyOffset/This control sets Signal Frequency Offset.
ViStatus _VI_FUNC rsbtc_ConfigureSignalType(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	signalType,
	ViReal64	frequencyOffset
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_BASEBAND_SIGNAL_TYPE, signalType
                                               ), 3, "Signal Type");
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_BASEBAND_SIGNAL_FREQUENCY_OFFSET, frequencyOffset
                                                ), 4, "Frequency Offset");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures the DTV transmission standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_BASEBAND_SIGNAL_TRANSMISSION_DTV_STANDARD
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce]:DM:TRANsmission[:STANdard]
/// HIFN     
/// HIFN     
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dtvTransmissionStandard/This control sets the transmission standard.
ViStatus _VI_FUNC rsbtc_ConfigureDTVTransmissionStandard(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dtvTransmissionStandard
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_BASEBAND_SIGNAL_TRANSMISSION_DTV_STANDARD, dtvTransmissionStandard
                                               ), 3, "DTV Transmission Standard");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures the ATV transmission standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_BASEBAND_SIGNAL_TRANSMISSION_ATV_STANDARD
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:DM:ATV[:STANdard]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR atvTransmissionStandard/This control sets the ATV Transmission Standard.
ViStatus _VI_FUNC rsbtc_ConfigureATVTransmissionStandard(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	atvTransmissionStandard
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_BASEBAND_SIGNAL_TRANSMISSION_ATV_STANDARD, atvTransmissionStandard
                                               ), 3, "ATV Transmission Standard");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function sets the audio broadcasting transmission standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_BASEBAND_SIGNAL_TRANSMISSION_AUDIO_BC_STANDARD
/// HIFN     
/// HIFN     Note:
/// HIFN     (1) Requires the AM/FM RDS coder option (R&S BTC-K570).
/// HIFN     Use this option to generate broadcast signals in FM and AM. In FM, you 
/// HIFN  can generate a mono or a stereo signal. For stereo signals generated 
/// HIFN  according to the multiplex method, an RDS (radio data system) coder is 
/// HIFN  available and is used to code fixed data. Many parameters can be 
/// HIFN  changed over wide setting ranges.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:DM:AUDio[:STANdard]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR audioBCTransmissionStandard/This control sets the audio broadcasting transmission standard. 
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCTransmissionStandard(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	audioBCTransmissionStandard
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_BASEBAND_SIGNAL_TRANSMISSION_AUDIO_BC_STANDARD, audioBCTransmissionStandard
                                               ), 3, "Audio BC Transmission Standard");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN This function configures the output signal polarity.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR polarity/Inverts the output signal, i.e. the I and Q signals are exchanged.
ViStatus _VI_FUNC rsbtc_ConfigureSignalPolarity (ViSession instrSession,
                                                 ViInt32 path, 
												 ViInt32 polarity)
{
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_BASEBAND_SIGNAL_POLARITY, polarity
                                               ), 3, "Polarity");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures DVB-T2 Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_INTERFACE
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PID
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_SID
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_NUMBER_OF_PLP
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:INTerface
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:PID
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:SID
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:NPLP
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR t2MIInterface/Activates or deactivates the T2 modulator interface.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface. 
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR t2MIPID/This control sets the PID for the MPEG transport stream packets that 
/// HIPAR t2MIPID/contain T2MI data.
/// HIPAR t2MISID/This control sets the T2MI stream ID used when transmitting a 
/// HIPAR t2MISID/composite signal, in accordance with annex I of the DVBT2 
/// HIPAR t2MISID/specification. If only a single stream is used, must be set to 0.
/// HIPAR numberOfPLP/This control sets the physical layer pipe (PLP) number.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2InputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	t2MIInterface,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	t2MIPID,
	ViInt32	t2MISID,
	ViInt32	numberOfPLP
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
   
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_INTERFACE, t2MIInterface
                                                 ), 3, "T2 MIInterface");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_SOURCE, source
                                               ), 4, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_INPUT, input
                                               ), 5, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 6, "IP TS Channel");		
		}
	}
			   		
	if (t2MIInterface == VI_TRUE)  {
		if (input != RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST) {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PID, t2MIPID
	                                               ), 7, "T2 MI PID");
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_SID, t2MISID
		                                          ), 8, "T2 MI SID");
		}
	}
	else  {
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_NUMBER_OF_PLP, numberOfPLP
                                               ), 9, "Number Of PLP");
	}
	
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function reads selected coding value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DVBT2_INPUT_SIGNAL_PLP_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBT2_INPUT_SIGNAL_PLP_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBT2_INPUT_SIGNAL_PLP_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:T2DVb:PLP<1..20>:USEFul:MAX?
/// HIFN     READ<hw>[:IQCoder]:T2DVb:PLP<1..20>[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:T2DVb:PLP<1..20>:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number (NPLP = 1: single PLP).
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDVBT2InputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);

   switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT2_INPUT_SIGNAL_PLP_MAX_USEFUL_DATA_RATE, 
	            result), 5, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT2_INPUT_SIGNAL_PLP_MEASURED_DATA_RATE, 
                result), 5, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT2_INPUT_SIGNAL_PLP_USEFUL_DATA_RATE, 
                result), 5, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Data Rate"); 

   }
  Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function displays the current value of Tmin or Tmax.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMIN1
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMIN2
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMIN3
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX1
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX2
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX3
/// HIFN     RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX4
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T1Min?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T2Min?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T3Min?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T1MAx?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T2MAx?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T3MAx?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:INPut:T2MI:T4MAx?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR measurementMode/Selects the measurement mode.  
/// HIPAR t2MITime/This control selects the value to be read from instrument.
/// HIPAR currentTimeValue/This control returns the selected current value.
ViStatus _VI_FUNC rsbtc_ReadDVBT2InputSignalT2MIPacketTiming(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	measurementMode,
	ViInt32	t2MITime,
	ViReal64*	currentTimeValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_MEAS_MODE, measurementMode
                                               ), 3, "Measurement Mode");
	switch (t2MITime){
        case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMIN1:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMIN1, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMIN2:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMIN2, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMIN3:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMIN3, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMAX1:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX1, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMAX2:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX2, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMAX3:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX3, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_MI_PACKET_TIMING_TMAX4:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PACKET_TIMING_T2_MI_TMAX4, 
	            currentTimeValue), 5, "Current Time Value");
        break;
		  
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "T2 MI Time"); 
	}
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-T2 coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBT2_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBT2_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DVBT2_CONFIGURING_PAYLOAD_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBT2_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:TSPacket
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PIDTestpack
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PID
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PAYLoad PRBS
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control sets the payload length of the test TS.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets the PID of the test TS packets, if PID of test TS 
/// HIPAR pid/packet is set to VARiable.
/// HIPAR payloadTestTSPacket/Defines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestTSPacket/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestTSPacket/packets".
/// HIPAR prbs/This control defines the period length of the PRBS generator which 
/// HIPAR prbs/fills the payload area of the transport stream packet (test signal or 
/// HIPAR prbs/null packet).
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2Settings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestTSPacket,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

 
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
	                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_CONFIGURING_PID, pid),
		                         5, "PID"); 

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_CONFIGURING_PAYLOAD_TEST_PACKET, payloadTestTSPacket),
                         6, "Payload Test TS Packet"); 
  
	if  (payloadTestTSPacket == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_CONFIGURING_PRBS, prbs),
                         7, "PRBS");    
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-T2 Mode Stream Adaptation parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number (NPLP = 1: single PLP).
/// HIPAR plpID/This control sets the PLP identification.
/// HIPAR plpType/This control sets the PLP type.
/// HIPAR bbMode/This control selects the baseband mode.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2ModeStreamAdaptation(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	plpID,
	ViInt32	plpIDGroup,
	ViInt32	plpType,
	ViInt32	bbMode
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_MODE_STREAM_PLP_ID, plpID),
                         4, "PLP ID");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_MODE_STREAM_PLP_GROUP_ID, plpIDGroup),
                         5, "PLP ID Group");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_MODE_STREAM_PLP_TYPE, plpType),
                         6, "PLP Type");	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_MODE_STREAM_BB_MODE, bbMode),
                         7, "BB Mode");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-T2 Bit Interleaved Coding and Modulation 
/// HIFN  subitem parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_BICM_FEC_FRAME
/// HIFN     RSBTC_ATTR_DVBT2_BICM_CODE_RATE
/// HIFN     RSBTC_ATTR_DVBT2_BICM_CONSTELLATION
/// HIFN     RSBTC_ATTR_DVBT2_BICM_CONSTELLATION_ROTATION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:FECFrame
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:RATE
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:CONStel
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:CROTation
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number (NPLP = 1: single PLP).
/// HIPAR fecFrame/This control sets the FEC frame.
/// HIPAR codeRate/This control sets the code rate.
/// HIPAR constellation/This control selects the constellation.
/// HIPAR constellRotation/The constellation can be transmitted rotated or not rotated.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2BICMParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	fecFrame,
	ViInt32	codeRate,
	ViInt32	constellation,
	ViBoolean	constellRotation
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_FEC_FRAME, fecFrame),
                         4, "FEC Frame");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_CODE_RATE, codeRate),
                         5, "Code Rate");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_CONSTELLATION, constellation),
                         6, "Constellation");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_CONSTELLATION_ROTATION, constellRotation),
                         7, "Constell. Rotation");  
 
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-T2 Bit Interleaved Coding and Modulation 
/// HIFN  subitem parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_BICM_TIME_INTERLEAVER_TYPE
/// HIFN     RSBTC_ATTR_DVBT2_BICM_FRAME_INTERVAL
/// HIFN     RSBTC_ATTR_DVBT2_BICM_TIME_INTERLEAVER_LENGTH
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:TIL:TYPE
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:TIL:FINT
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PLP<1..20>:TIL:LENGth
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number (NPLP = 1: single PLP).
/// HIPAR timeInterleaverType/This control sets the time interleaver type.
/// HIPAR frameIntervalIJump/Defines the frame interval (I Jump).
/// HIPAR timeInterleaverLength/Time Interleaver LengthDefines the number of time interleaver blocks 
/// HIPAR timeInterleaverLength/(TIB) within the time interleaving frame.
/// HIPAR firstFrameIndex/Displays the index of the first frame of the super frame in
/// HIPAR firstFrameIndex/which the current PLP occurs.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2BICMTimeInterleaverParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	timeInterleaverType,
	ViInt32	frameIntervalIJump,
	ViInt32	timeInterleaverLength,
	ViInt32	firstFrameIndex
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_TIME_INTERLEAVER_TYPE, timeInterleaverType),
                         4, "Time Interleaver Type");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_FRAME_INTERVAL, frameIntervalIJump),
                         5, "Frame Interval I Jump");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_TIME_INTERLEAVER_LENGTH, timeInterleaverLength),
                         6, "Time Interleaver Length");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_BICM_FIRST_FRAME_INDEX, firstFrameIndex),
                         7, "First Frame Index");
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures FRAMING + OFDM parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_CHANNEL_BANDWIDTH
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_FFT_SIZE
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_PILOT_PATTERN
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:CHANnel[:BANDwidth]
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:FFT:MODE
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:GUARd:INTerval
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PILot
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR channelBandwidth/This control sets the channel bandwidth.
/// HIPAR fftSize/This control sets the FFT size.
/// HIPAR guardInterval/This control sets the guard interval.
/// HIPAR pilotPattern/This control sets the pilot pattern.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2FramingOFDMParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	channelBandwidth,
	ViInt32	fftSize,
	ViInt32	guardInterval,
	ViInt32	pilotPattern
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_CHANNEL_BANDWIDTH, channelBandwidth
                                               ), 3, "Channel Bandwidth");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_FFT_SIZE, fftSize
                                               ), 4, "FFT Size");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_GUARD_INTERVAL, guardInterval
                                               ), 5, "Guard Interval");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_PILOT_PATTERN, pilotPattern
                                               ), 6, "Pilot Pattern");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-T2 Frames parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_T2_FRAMES_PER_SUPER_FRAME
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_OFDM_SYMBOLS_PER_T2_FRAME
/// HIFN     RSBTC_ATTR_DVBT2_FRAMING_SUBSLICES_PER_T2_FRAME
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:NT2Frames
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:LDATa
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:NSUB
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR t2FramesPerSuperFrame/This control sets the number of T2 frames per super frame.
/// HIPAR dataSymbolsPerT2Frame/Sets the number of data symbols per T2 frame.
/// HIPAR subslicesPerT2Frame/Sets the number of subslices per T2 frame. The possible values depend 
/// HIPAR subslicesPerT2Frame/on the constellation and the FEC type of all data type 2 PLPs.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2FramingOFDM(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	t2FramesPerSuperFrame,
	ViInt32	dataSymbolsPerT2Frame,
	ViInt32	subslicesPerT2Frame
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_T2_FRAMES_PER_SUPER_FRAME, t2FramesPerSuperFrame
                                               ), 3, "T2 Frames Per Super Frame");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_DATA_SYMBOLS_PER_T2_FRAME, dataSymbolsPerT2Frame
                                               ), 4, "Data Symbols Per T2 Frame");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_FRAMING_SUBSLICES_PER_T2_FRAME, subslicesPerT2Frame
                                               ), 5, "Subslices Per T2 Frame");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures transmission system parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_TRANSMISSION_SYSTEM
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_PEAK_TO_AVRAGE_POWER_RATIO
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_TIME_FREQUENCY_SLICING
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP_MODE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:TXSYs
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PAPR
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:FEF
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:TFS
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:MISO
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:MISO:MODE
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR transmissionSystem/Displays the transmission system.
/// HIPAR peakToAvragePowerRatio/This control sets the peak-to-average-power ratio state.
/// HIPAR futureExtensionFrames/Sets the future extension frames (FEF) state.
/// HIPAR timeFrequencySlicing/Sets the time frequency slicing (TFS) state.
/// HIPAR misoGroup/This control sets the MISO group.
/// HIPAR misoGroupMode/This control selects the MISO group operation mode.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2TransmissionSystem(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	transmissionSystem,
	ViInt32	peakToAvragePowerRatio,
	ViBoolean	futureExtensionFrames,
	ViBoolean	timeFrequencySlicing,
	ViInt32	misoGroup,
	ViInt32	misoGroupMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_TRANSMISSION_SYSTEM, transmissionSystem
                                               ), 3, "Transmission System");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_PEAK_TO_AVRAGE_POWER_RATIO, peakToAvragePowerRatio
                                               ), 4, "Peak To Avrage Power Ratio");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES, futureExtensionFrames
                                               ), 5, "Future Extension Frames");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_TIME_FREQUENCY_SLICING, timeFrequencySlicing
                                               ), 6, "Time Frequency Slicing");
	
	if (transmissionSystem ==  RSBTC_VAL_IQC_DVBT2_TRANS_MISO) {
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP_MODE, misoGroupMode
                                               ), 8, "MISO Group Mode");
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP, misoGroup
	                                               ),7, "MISO Group");
	}
	
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures T2 system network mode.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_NETWORK_MODE
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_PROFILE_MODE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:NETWorkmode
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:PROFile
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR networkMode/Sets the network mode.
/// HIPAR profileMode/This control mutes P1FEF, if modulator operates in a multi profile 
/// HIPAR profileMode/environment and is used to generate a RF combined T2Base/T2Lite 
/// HIPAR profileMode/composite signal.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2TransmissionSystemNetwork(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	networkMode,
	ViInt32	profileMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_NETWORK_MODE, networkMode
                                               ), 3, "Network Mode");
	if (networkMode == RSBTC_VAL_NETWORK_MODE_SFN) 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_PROFILE_MODE, profileMode
                                               ), 4, "Profile Mode");

	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures Future Extension Frames parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_LENGTH
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_TYPE
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_INTERVAL
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_PAYLOAD
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:FEF:LENGth
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:FEF:TYPE
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:FEF:INTerval
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:FEF:PAYLoad
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fefLength/This control sets Future Extension Frames length.
/// HIPAR fefType/This control sets the type of the associated FEF part.
/// HIPAR fefInterval/This control sets Future Extension Frames interval.
/// HIPAR fefPayload/This control sets Future Extension Frames payload.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2TransmissionFutureExtensionFrames(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	fefLength,
	ViInt32	fefType,
	ViInt32	fefInterval,
	ViInt32	fefPayload
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_LENGTH, fefLength
                                               ), 3, "FEF Length");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_TYPE, fefType
                                               ), 4, "FEF Type");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_INTERVAL, fefInterval
                                               ), 5, "FEF Interval");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_FEF_PAYLOAD, fefPayload
                                               ), 6, "FEF Payload");
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures transmission system L1 parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_T2_VERSION
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_POST_MODULATION
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_REPETITION
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_POST_SCRAMBLED
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:L:T2Version
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:L:CONStel
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:L:REPetition
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:L:SCRambled
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR l1PostModulation/This control sets the L1 post constellation.
/// HIPAR l1Repetition/Sets the L1 repetition state.
/// HIPAR l1T2Version/This control sets the T2 specification version used for transmission.
/// HIPAR l1PostScrambled/Activates or deactivates L1 post scrambling according to T2 version 
/// HIPAR l1PostScrambled/1.3.1 ("L1 T2 VERSION").
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2TransmissionL1Parameters(
	ViSession	instrSession,
	ViInt32	path,
		ViInt32	l1T2Version,
	ViInt32	l1PostModulation,
	ViBoolean	l1Repetition,
	ViBoolean	l1PostScrambled
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_T2_VERSION, l1T2Version
                                               ), 3, "L1 T2 Version");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_POST_MODULATION, l1PostModulation
                                               ), 4, "L1 Post Modulation");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_REPETITION, l1Repetition
                                               ), 5, "L1 Repetition");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_L1_POST_SCRAMBLED, l1PostScrambled
                                               ), 6, "L1 Post Scrambled");
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures transmission system identification 
/// HIFN  parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_CELL_ID
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_NETWORK_ID
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_ID
/// HIFN     RSBTC_ATTR_DVBT2_T2_SYSTEM_TX_ID_AVAILABILITY
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:ID:CELL
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:ID:NETWork
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:ID:T2SYstem
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:ID:TXID:AVAil
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR cellID/This control sets the cell identification.
/// HIPAR networkID/This control sets the network identification.
/// HIPAR t2SystemID/This control sets the T2 system identification.
/// HIPAR txIDAvailability/Sets the availability of transmitter identification signals within the 
/// HIPAR txIDAvailability/current geographic cell.
ViStatus _VI_FUNC rsbtc_ConfigureDVBT2TransmissionSystemIdentification(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	cellID,
	ViInt32	networkID,
	ViInt32	t2SystemID,
	ViInt32	txIDAvailability
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_CELL_ID, cellID
                                               ), 3, "CellID");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_NETWORK_ID, networkID
                                               ), 4, "Network ID");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_ID, t2SystemID
                                               ), 5, "T2 System ID");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT2_T2_SYSTEM_TX_ID_AVAILABILITY, txIDAvailability
                                               ), 6, "TX ID Availability");
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries selected delay value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_SFN_MAX_DEVIATION_TIME
/// HIFN     RSBTC_ATTR_DVBT2_SFN_STATIC_DELAY
/// HIFN     RSBTC_ATTR_DVBT2_SFN_DYNAMIC_DELAY
/// HIFN     RSBTC_ATTR_DVBT2_SFN_TOTAL_DELAY
/// HIFN     RSBTC_ATTR_DVBT2_SFN_PROCESS_DELAY  
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:DEViation[?]
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:STATic[?]
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:PROCess?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:DYNamic?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:TOTal?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR delayParameter/Selects the delay parameter.
/// HIPAR timeValue/This control returns the selected delay value, if the modulator 
/// HIPAR timeValue/operates in SFN network mode.
ViStatus _VI_FUNC rsbtc_ReadDVBT2SFNDelayParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	delayParameter,
	ViReal64*	timeValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	switch (delayParameter){
        case RSBTC_VAL_DVBT2_SFN_MAX_DEVIATION_TIME:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_MAX_DEVIATION_TIME, 
	            timeValue), 4, "Time Value");
        break;
		  
		case RSBTC_VAL_DVBT2_SFN_STATIC_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_STATIC_DELAY, 
	            timeValue), 4, "Time Value");
        break;
			
		case RSBTC_VAL_DVBT2_SFN_DYNAMIC_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_DYNAMIC_DELAY, 
	            timeValue), 4, "Time Value");
        break;
				  
		case RSBTC_VAL_DVBT2_SFN_TOTAL_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_TOTAL_DELAY, 
	            timeValue), 4, "Time Value");
        break;
		
		case RSBTC_VAL_DVBT2_SFN_PROCESS_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_PROCESS_DELAY, 
	            timeValue), 4, "Time Value");
        break;

		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Delay Parameter"); 
	}
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the currently received T2-MI timestamps 
/// HIFN  parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_DATE
/// HIFN     RSBTC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_TIME
/// HIFN     RSBTC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_SECONDS_SINCE_2000
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:TSP:DATE?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:TSP:TIME?
/// HIFN     [SOURce<hw>][:IQCoder]:T2DVb:DELay:TSP:SEConds?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR utcDate/This control returns the UTC date that was captured during the last 
/// HIPAR utcDate/UTC reference update.
/// HIPAR utcTime/This control returns the UTC time that was captured during the last 
/// HIPAR utcTime/UTC reference update.
/// HIPAR secondsSince2000/This control returns the elapsed seconds since 2000 based on the value 
/// HIPAR secondsSince2000/of the last UTC reference update.
ViStatus _VI_FUNC rsbtc_ReadDVBT2SFNTimestampParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViChar	utcDate[],
	ViChar	utcTime[],
	ViInt32*	secondsSince2000
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	if (!utcDate) viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "UTC Date");
	if (!utcTime) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "UTC Time"); 
	if (!secondsSince2000) viCheckParm (RS_ERROR_INVALID_PARAMETER, 5, "Seconds Since 2000"); 
			
    viCheckParm (rsbtc_GetAttributeViString (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_DATE, 1024,
                                            utcDate), 2, "UTC Date");
	viCheckParm (rsbtc_GetAttributeViString (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_TIME, 1024,
                                            utcTime), 3, "UTC Time");
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_SECONDS_SINCE_2000,
                                            secondsSince2000), 4, "Seconds Since 2000");
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures DVB-C2 physical layer pipe (PLP) number.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_INPUT_SIGNAL_NUMBER_OF_PLP
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:INPut:NPLP
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfPLP/Selects the number of PLPs.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2NumberOfPLP(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOfPLP
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_INPUT_SIGNAL_NUMBER_OF_PLP, numberOfPLP
											    ), 3, "Number Of PLP");        
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-C2 input signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_INPUT_SIGNAL_INPUT_FORMAT
/// HIFN     RSBTC_ATTR_DVBC2_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DVBC2_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DVBC2_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_DVBC2_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:INPut:FORMat
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:INPut:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:INPut:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:PLP<1..4>:TSCHannel
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:INPut:TESTsigna
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number.
/// HIPAR inputFormat/This control sets the input format.
/// HIPAR source/Selects the input signal source for a PLP (MPEG2 transport stream). 
/// HIPAR source/All PLPs can be fed with a live transport stream, but all PLPs are fed 
/// HIPAR source/from the same source. This is caused by hardware restrictions. If one 
/// HIPAR source/source is set to e.g. "External", all sources that are currently set to 
/// HIPAR source/"MM Generator" are also automatically set to "External". Alternatively, 
/// HIPAR source/PLPs can be fed by a test signal.
/// HIPAR input/Configures the external input interface. 
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR testSignal/This control selects the signal source for the DVB-C2 coder.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2InputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	inputFormat,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal
)
{
	ViStatus	error = VI_SUCCESS;  
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (plp, 1, 4), 3, "PLP");    
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_DVBC2_INPUT_SIGNAL_INPUT_FORMAT, inputFormat
                                                 ), 4, "Input Format");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_INPUT_SIGNAL_SOURCE, source
                                               ), 5, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_INPUT_SIGNAL_INPUT, input
                                               ), 6, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 7, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBC2_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 8, "Test Signal");  
	}
 
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function reads selected  data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DVBC2_INPUT_SIGNAL_MAX_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBC2_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBC2_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:C2DVb:PLP<1..4>:MAXDatarate?
/// HIFN     READ<hw>[:IQCoder]:C2DVb:PLP<1..4>[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:C2DVb:PLP<1..4>:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDVBC2InputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;

    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (plp, 1, 4), 3, "PLP"); 
    
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);

   switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBC2_INPUT_SIGNAL_MAX_DATA_RATE, 
	            result), 5, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBC2_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 5, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBC2_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 5, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Data Rate"); 

   }
  Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-C2 coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBC2_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBC2_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DVBC2_CONFIGURING_PAYLOAD_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBC2_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:TSPacket H184 | S187
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PIDTestpack NULL | VARiable
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PID
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PAYLoad PRBS | H00 | HFF
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PRBS[:SEQuence] P23_1 | P15_1
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control specifies the structure of the test transport stream 
/// HIPAR testTSPacket/packet that is fed to the modulator.
/// HIPAR pidTestPacket/This control specifies the PID, if a header was set for the test TS 
/// HIPAR pidTestPacket/packet, that means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets defines the header value. The available values 
/// HIPAR pid/depend on the setting under "PID Test Packet".
/// HIPAR payloadTestTSPacket/This control sets the payload of the test TS packets.
/// HIPAR prbs/This control sets the PRBS to be used.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2Settings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestTSPacket,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

 
	 viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
	                         4, "PID Test Packet");
	
	if (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_CONFIGURING_PID, pid),
		                         5, "PID"); 

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_CONFIGURING_PAYLOAD_TEST_TS_PACKET, payloadTestTSPacket),
                         6, "Payload Test TS Packet"); 
  
	if (payloadTestTSPacket == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_CONFIGURING_PRBS, prbs),
                         7, "PRBS");    
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-C2 Mode Stream Adaptation parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_PLP_ID
/// HIFN     RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_BB_MODE
/// HIFN     RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_ISSY
/// HIFN     RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_NULL_PACKET_DELETION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:ID
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:BB_Mode
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:ISSY
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:NPD
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number.
/// HIPAR plpID/This control sets the PLP identification.
/// HIPAR bbMode/This control selects the baseband mode.
/// HIPAR issy/Input stream synchronization. If enabled, the ISCR values are 
/// HIPAR issy/transmitted. Every 180 ms, a BUFS/BUFSTAT pair is transmitted, 
/// HIPAR issy/replacing the ISCR field. The 180 ms period meets the "at least 5 times 
/// HIPAR issy/per second" requirement in the DVBC2 standard. The Implementation 
/// HIPAR issy/Guidelines recommend transmitting the BUFS/BUFSTAT variables at the 
/// HIPAR issy/beginning of a C2 frame. This feature is not implemented in the R&S 
/// HIPAR issy/BTC.
/// HIPAR nullPacketDeletion/Null packet deletion. MPEG2 null packets are removed from the 
/// HIPAR nullPacketDeletion/transport stream in order to decrease the amount of data to be 
/// HIPAR nullPacketDeletion/transmitted. The number of deleted null packets is signaled allowing 
/// HIPAR nullPacketDeletion/the receiver to re-insert null packets at the appropriate position.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2ModeStreamAdaptation(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	plpID,
	ViInt32	bbMode,
	ViInt32	issy,
	ViBoolean	nullPacketDeletion
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (plp, 1, 4), 3, "PLP"); 
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_PLP_ID, plpID),
                         4, "PLP ID");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_BB_MODE, bbMode),
                         5, "BB Mode");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_ISSY, issy),
                         6, "ISSY");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBC2_MODE_STREAM_ADAPTATION_NULL_PACKET_DELETION, nullPacketDeletion),
                         7, "Null Packet Deletion");  

	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures DVB-C2 Bit Interleaved Coding and PLP Mapping 
/// HIFN  parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_BICM_FEC_FRAME
/// HIFN     RSBTC_ATTR_DVBC2_BICM_CODE_RATE
/// HIFN     RSBTC_ATTR_DVBC2_BICM_CONSTELLATION
/// HIFN     RSBTC_ATTR_DVBC2_BICM_MAPPED_TO_DATA_SLICE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:FECFrame
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:RATE
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:CONStel Q1024 | Q4096
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:PLP<1..4>:MAPTodslice
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number.
/// HIPAR fecFrame/This control selects the length of the FEC Frame for every PLP 
/// HIPAR fecFrame/individually in accordance with the DVB-C2 specification.
/// HIPAR codeRate/This control sets the LDPC code rate for every PLP in accordance with 
/// HIPAR codeRate/the DVBC2 specification.
/// HIPAR constellation/This control selects the constellation.
/// HIPAR mapToDSlice/Assigns the PLP to one of the data slices (max. 4).
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2BICMPLPMappingParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	fecFrame,
	ViInt32	codeRate,
	ViInt32	constellation,
	ViInt32	mapToDSlice
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_plp[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (plp, 1, 4), 3, "PLP"); 
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_plpRepCap (instrSession, plp, rep_cap_plp));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_plp);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_BICM_FEC_FRAME, fecFrame),
                         4, "FEC Frame");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_BICM_CODE_RATE, codeRate),
                         5, "Code Rate");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_BICM_CONSTELLATION, constellation),
                         6, "Constellation");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_BICM_MAPPED_TO_DATA_SLICE, mapToDSlice),
                         7, "Mapped to Data Slice");  

	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function returns the minimum and maximum carrier index for the C2 
/// HIFN  signal.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_MIN_REL
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_MAX_REL
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_MIN_ABS
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_MAX_ABS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:MIN:REL?
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:MAX:REL?
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:MIN:ABS?
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:MAX:ABS?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR min_REL_DxTu/Displays the minimum carrier index for the C2 signal relative to the 
/// HIPAR min_REL_DxTu/start frequency in multiples of Dx ("Start Frequency", "Dx").
/// HIPAR max_REL_DxTu/Displays the maximum carrier index for the C2 signal relative to the 
/// HIPAR max_REL_DxTu/start frequency in multiples of Dx ("Start Frequency", "Dx").
/// HIPAR min_ABS_DxTu/Displays the minimum carrier index for the C2 signal in multiples of 
/// HIPAR min_ABS_DxTu/Dx.
/// HIPAR max_ABS_DxTu/Displays the maximum carrier index for the C2 signal in multiples of 
/// HIPAR max_ABS_DxTu/Dx.
ViStatus _VI_FUNC rsbtc_ReadDVBC2DataSliceMinMax(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	min_REL_DxTu,
	ViInt32*	max_REL_DxTu,
	ViInt32*	min_ABS_DxTu,
	ViInt32*	max_ABS_DxTu
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	if (!min_REL_DxTu) viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Min REL Dx/Tu");
	if (!max_REL_DxTu) viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Max REL Dx/Tu"); 
	if (!min_ABS_DxTu) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Min ABS Dx/Tu"); 
	if (!max_ABS_DxTu) viCheckParm (RS_ERROR_INVALID_PARAMETER, 5, "Max ABS Dx/Tu"); 
	
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_MIN_REL, 
               min_REL_DxTu), 3, "Min REL Dx/Tu");
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_MAX_REL, 
               max_REL_DxTu), 4, "Max REL Dx/Tu");
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_MIN_ABS, 
               min_ABS_DxTu), 5, "Min ABS Dx/Tu");
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_MAX_ABS, 
               max_ABS_DxTu), 6, "Max ABS Dx/Tu");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures number of data slices. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_NUMBER_OF_DATA_SLICES
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:NUMDslices
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR numberOfDataSlices/Selects the number of data slices.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2NumberOfDataSlices(
	ViSession	instrSession,
		ViInt32	path,
	ViInt32	numberOfDataSlices
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_DATA_SLICE_NUMBER_OF_DATA_SLICES, numberOfDataSlices
											    ), 3, "Number Of Data Slices");        
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures DVB-C2 Data Slice parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_ID
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_TI_DEPTH
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_TYPE
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_FEC_HEADER_TYPE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:ID
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:TIDepth
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:TYPE T1 | T2
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:FECHeader ROBust | HEM
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataSlice/This control sets the number of data slices table.
/// HIPAR dataSliceID/This control sets the data slice ID. The data slice ID uniquely 
/// HIPAR dataSliceID/identifies a data slice within the C2 signal.
/// HIPAR dataSliceTIDepth/Sets the depth of the time interleaver. Each data slice has its own 
/// HIPAR dataSliceTIDepth/time interleaver that can be set independently.
/// HIPAR dataSliceType/Selects the data slice type.
/// HIPAR fecHeaderType/Selects the type of FEC frame header. Type 2 data slice packets are 
/// HIPAR fecHeaderType/preceded by FEC frame headers.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2DataSliceParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataSlice,
	ViInt32	dataSliceID,
	ViInt32	dataSliceTIDepth,
	ViInt32	dataSliceType,
	ViInt32	fecHeaderType
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_dSlice[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_dSliceRepCap (instrSession, dataSlice, rep_cap_dSlice));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_dSlice);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_ID, dataSliceID),
                         4, "Data Slice ID");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_TI_DEPTH, dataSliceTIDepth),
                         5, "Data Slice TI Depth");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_TYPE, dataSliceType),
                         6, "Data Slice Type");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_FEC_HEADER_TYPE, fecHeaderType),
                         7, "FEC Header Type");  

	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

	  
/// HIFN  This function configures DVB-C2 Current Data Slice parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_OFFSET_LEFT
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_TUNE_POSITION_REL
/// HIFN     RSBTC_ATTR_DVBC2_DATA_SLICE_OFFSET_RIGHT
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:OFSLeft
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:TUNepos:REL
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:DSLice<1..4>:OFSRight
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataSlice/This control sets the number of data slices table.
/// HIPAR offsetLeft_DxTu/Sets the left edge of the current data slice.
/// HIPAR tunePosition_REL_DxTu/Sets the tuning position for the current data slice.
/// HIPAR offsetRight_DxTu/Sets the right edge of the current data slice.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2CurrentDataSliceParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataSlice,
	ViInt32	offsetLeft_DxTu,
	ViInt32	tunePosition_REL_DxTu,
	ViInt32	offsetRight_DxTu
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_dSlice[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_dSliceRepCap (instrSession, dataSlice, rep_cap_dSlice));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_dSlice);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_OFFSET_LEFT, offsetLeft_DxTu),
                         4, "Offset Left  [Dx/Tu]");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_TUNE_POSITION_REL, tunePosition_REL_DxTu),
                         5, "Tune Position (REL) [Dx/Tu]");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_DATA_SLICE_OFFSET_RIGHT, offsetRight_DxTu),
                         6, "Offset Right [Dx/Tu]");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures Number of notches.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_NOTCH_NUMBER_OF_NOTCHES
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:NUMNotches
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR numberOfNotches/This control sets Number of notches.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2NumberOfNotches(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOfNotches
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
   	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_NOTCH_NUMBER_OF_NOTCHES, numberOfNotches),
                         3, "Number Of Notches");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function selects and sets the relevant notch parameters in the 
/// HIFN  work view.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_NOTCH_START_REL
/// HIFN     RSBTC_ATTR_DVBC2_NOTCH_STOP_REL
/// HIFN     RSBTC_ATTR_DVBC2_NOTCH_WIDTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:NOTCh<1..4>:STARt:REL
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:NOTCh<1..4>:STOP:REL
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:NOTCh<1..4>:WIDTh
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR notch/This control sets the number of notch.
/// HIPAR start_REL_DxTu/Sets the start index of the notch.
/// HIPAR stop_REL_DxTu/Sets the stop index of the notch.
/// HIPAR width_DxTu/Sets the width of the notch
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2NotchValues(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	notch,
	ViInt32	start_REL_DxTu,
	ViInt32	stop_REL_DxTu,
	ViInt32	width_DxTu
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_notch[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_notchRepCap (instrSession, notch, rep_cap_notch));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_notch);
 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_NOTCH_START_REL, start_REL_DxTu),
                         4, "Start (REL) [Dx/Tu]");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_NOTCH_STOP_REL, stop_REL_DxTu),
                         5, "Stop (REL) [Dx/Tu]");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_NOTCH_WIDTH, width_DxTu),
                         6, "Width [Dx/Tu]");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures FRAMING + OFDM parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_FRAMING_CHANNEL_BANDWIDTH
/// HIFN     RSBTC_ATTR_DVBC2_FRAMING_C2_BANDWIDTH
/// HIFN     RSBTC_ATTR_DVBC2_FRAMING_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_DVBC2_FRAMING_BASEBAND_FILTER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:CHANnel[:BANDwidth]
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:C2Bandwidth
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:GUARd:INTerval
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:FILTer
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR channelBandwidth/This control sets the channel bandwidth.
/// HIPAR c2Bandwidth/Selects the total bandwidth of the C2 signal.
/// HIPAR guardInterval/This control sets the guard interval.
/// HIPAR basebandFilter/Sets the type of baseband filtering.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2FramingAndOFDMParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	channelBandwidth,
	ViInt32	c2Bandwidth,
	ViInt32	guardInterval,
	ViInt32	basebandFilter
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_FRAMING_CHANNEL_BANDWIDTH, channelBandwidth
                                               ), 3, "Channel Bandwidth");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_FRAMING_GUARD_INTERVAL, guardInterval
                                               ), 5, "Guard Interval");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_FRAMING_C2_BANDWIDTH, c2Bandwidth
                                               ), 4, "C2 Bandwidth");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_FRAMING_BASEBAND_FILTER, basebandFilter
                                               ), 6, "Baseband Filter");
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures C2 system identification parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC2_C2_SYSTEM_NETWORK_ID
/// HIFN     RSBTC_ATTR_DVBC2_C2_SYSTEM_ID
/// HIFN     RSBTC_ATTR_DVBC2_C2_SYSTEM_L1_TIME_INTERLEAVER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:ID:NETWork
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:ID:C2SYstem
/// HIFN     [SOURce<hw>][:IQCoder]:C2DVb:L1TI
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR networkID/This control sets the network ID that uniquely identifies the DVBC2 
/// HIPAR networkID/network.
/// HIPAR c2SystemID/This control sets the C2 system ID that uniquely identifies the C2 
/// HIPAR c2SystemID/system within the DVBC2 network.
/// HIPAR l1TimeInterleaver/Configures the time interleaver used by L1 signaling part 2.
ViStatus _VI_FUNC rsbtc_ConfigureDVBC2C2SystemParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	networkID,
	ViInt32	c2SystemID,
	ViInt32	l1TimeInterleaver
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_C2_SYSTEM_NETWORK_ID, networkID
                                               ), 3, "Network ID");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_C2_SYSTEM_ID, c2SystemID
                                               ), 4, "C2 System ID");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC2_C2_SYSTEM_L1_TIME_INTERLEAVER, l1TimeInterleaver
                                               ), 5, "L1 Time Interleaver");
	Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBT Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_SOURCE_LP
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_INPUT_LP
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_TEST_SIGNAL_LP
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_STUFFING
/// HIFN     RSBTC_ATTR_DVBT_INPUT_SIGNAL_STUFFING_LP
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce:LOW
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:[HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:LOW
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TESTsignal[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TESTsignal:LOW
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:STUFfing[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:STUFfing:LOW
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR priorityPath/This control selects the priority path.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface.
/// HIPAR testSignal/Configures the test signal.
/// HIPAR stuffing/Switches the stuffing on or off.
ViStatus _VI_FUNC rsbtc_ConfigureDVBTInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	priorityPath,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

		switch (priorityPath){
        case RSBTC_VAL_PRIORITY_HIGH: {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_SOURCE, source
                                               ), 4, "Source");

			if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_INPUT, input
                                               ), 5, "Input");
		
				if (input == RSBTC_IQC_INPUT_IP)  {
					viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
		                                               ), 6, "IP TS Channel");		
				}
			}
			   		
			if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
					viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
			                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_TEST_SIGNAL, testSignal
			     										   ), 7, "Test Signal");  
			} 
			else
				viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 8, "stuffing");	
		}									  	
        break;
      
		case RSBTC_VAL_PRIORITY_LOW: {
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_SOURCE_LP, source
                                               ), 4, "Source");

			if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_INPUT_LP, input
                                               ), 5, "Input");
		
				if (input == RSBTC_IQC_INPUT_IP)  {
					viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
		                                               ), 6, "IP TS Channel");		
				}
			}
			   		
			if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
					viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
			                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_TEST_SIGNAL_LP, testSignal
			     										   ), 7, "Test Signal");  
			} 
			else
				viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_DVBT_INPUT_SIGNAL_STUFFING_LP, stuffing
		                                               ), 8, "stuffing");	
		}
        break;
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Priority Path"); 
    }
		
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE_LP
/// HIFN     RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MEASURED_DATA_RATE_LP
/// HIFN     RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_USEFUL_DATA_RATE_LP
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:DVBT:USEFul[:RATE]:MAX[:HIGH]?
/// HIFN     READ<hw>[:IQCoder]:DVBT:USEFul[:RATE]:MAX:LOW?
/// HIFN     READ<hw>[:IQCoder]:DVBT[:INPut]:DATarate[:HIGH]?
/// HIFN     READ<hw>[:IQCoder]:DVBT[:INPut]:DATarate:LOW?
/// HIFN     READ<hw>[:IQCoder]:DVBT:USEFul[:RATE][:HIGH]?
/// HIFN     READ<hw>[:IQCoder]:DVBT:USEFul[:RATE]:LOW?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR priorityPath/This control selects the priority path.
/// HIPAR dataRate/This control selects the Data Rate value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDVBTInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	priorityPath,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 
		switch (priorityPath){
        	case RSBTC_VAL_PRIORITY_HIGH: 
			
			   	switch (dataRate) {
			        case RSBTC_VAL_MAX_USEFUL_DRATE:
			    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
				            result), 5, "Result");
			        break;
			        case RSBTC_VAL_MEAS_DRATE:
			    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MEASURED_DATA_RATE, 
			                result), 5, "Result");
			        break;
					case RSBTC_VAL_USEFUL_DRATE:																	   
			    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_USEFUL_DATA_RATE, 
			                result), 5, "Result");
			        break;
		
					default:
			            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Data Rate"); 
										  }
				
      		break;
			
			case RSBTC_VAL_PRIORITY_LOW: 
				
				switch (dataRate) {
				  	case RSBTC_VAL_MAX_USEFUL_DRATE:
			    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE_LP, 
				            result), 5, "Result");
			        break;
			        case RSBTC_VAL_MEAS_DRATE:
			    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_MEASURED_DATA_RATE_LP, 
			                result), 5, "Result");
			        break;
					case RSBTC_VAL_USEFUL_DRATE:																	   
			    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBT_INPUT_SIGNAL_USEFUL_DATA_RATE_LP, 
			                result), 5, "Result");
			        break;
		
					default:
			            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Data Rate"); 
				}
			break;
			default:
            	viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "priorityPath");
										 }
  Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures DVBT coding settings - packets.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBT_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBT_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DVBT_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_DVBT_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TSPacket H184 | S187
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:PIDTestpack NULL | VARiable
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:PID
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:PAYLoad PRBS | H00 | HFF
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:PRBS[:SEQuence] P23_1 | P15_1
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/Specifies the structure of the test transport stream packet that is 
/// HIPAR testTSPacket/fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR payloadTestStuff/Defines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestStuff/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestStuff/packets".
/// HIPAR prbs/Defines the period length of the PRBS generator which fills the 
/// HIPAR prbs/payload area of the transport stream packet (test signal or null 
/// HIPAR prbs/packet).
ViStatus _VI_FUNC rsbtc_ConfigureDVBTCodingSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBT coding TPS settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_TPS_CELL_ID
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_TPS_RESERVED_STATE
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_TPS_RESERVED_BITS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:CELL:ID
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TPSReserved:STATe
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TPSReserved:VALue
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR tpsCellID/This control sets TPS Cell ID.
/// HIPAR tpsResevedState/witches the TPS reserved state on or off.
/// HIPAR tpsReservedBits/Defines the reserved bits in form of a hex number.
ViStatus _VI_FUNC rsbtc_ConfigureDVBTTPS(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	tpsCellID,
	ViBoolean	tpsResevedState,
	ViInt32	tpsReservedBits
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_TPS_CELL_ID, tpsCellID),
                         3, "TPS Cell ID");
  
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_TPS_RESERVED_STATE, tpsResevedState),
			             4, "TPS Reseved State");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_TPS_RESERVED_BITS, tpsReservedBits),
                         5, "TPS Reserved Bits");
  
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBT coding Time Slicing and MPE.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_TIME_SLICING
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_TIME_SLICING_LP
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_MPE_FEC
/// HIFN     RSBTC_ATTR_DVBT_SETTINGS_MPE_FEC_LP
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TIMeslice[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:TIMeslice:LOW
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:MPEFec[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:MPEFec:LOW
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR priorityPath/This control selects the priority path.
/// HIPAR timeSlicing/Switches time slicing.
/// HIPAR mpeFEC/Switches MPE FEC.
ViStatus _VI_FUNC rsbtc_ConfigureDVBTTimeslicingAndMPE(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	priorityPath,
	ViBoolean	timeSlicing,
	ViBoolean	mpeFEC
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

   	switch (priorityPath){
        case RSBTC_VAL_PRIORITY_HIGH: {
	
			viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_TIME_SLICING, timeSlicing),
                         4, "timeSlicing");
				
			viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_MPE_FEC, mpeFEC),
                         5, "MPE FEC");
		}									  	
        break;
      
		case RSBTC_VAL_PRIORITY_LOW: {
	
			viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_TIME_SLICING_LP, timeSlicing),
                         4, "timeSlicing");
				
			viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBT_SETTINGS_MPE_FEC_LP, mpeFEC),
                         5, "MPE FEC");
		}
        break;
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Priority Path"); 
    }


Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBT coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_CODING_CHANNEL_BANDWIDTH
/// HIFN     RSBTC_ATTR_DVBT_CODING_USED_BANDWIDTH
/// HIFN     RSBTC_ATTR_DVBT_CODING_FFT_MODE
/// HIFN     RSBTC_ATTR_DVBT_CODING_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_DVBT_CODING_HIERARCHY
/// HIFN     RSBTC_ATTR_DVBT_CODING_CONSTELLATION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:CHANnel[:BANDwidth] BW_8 | BW_7 | BW_6 | 
/// HIFN  BW_5 | VARiable
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:USED[:BANDwidth]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:FFT:MODE M2K | M4K | M8K
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:GUARd:INTerval G1_4 | G1_8 | G1_16 | G1_32
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:HIERarchy NONHierachic | A1 | A2 | A4
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:CONStel T4 | T16 | T64
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR channelBandwidth/Selects the preset bandwidth. The associated used bandwidth is 
/// HIPAR channelBandwidth/displayed under "Used Bandwidth". The correlation between the two 
/// HIPAR channelBandwidth/bandwidths is shown in table "Correlation between channel bandwidth and 
/// HIPAR channelBandwidth/used bandwidth".
/// HIPAR usedBandwidth/This control allows setting of a freely selectable bandwidth between 5 
/// HIPAR usedBandwidth/MHz and 8 MHz.
/// HIPAR fftMode/This control selects the channel bandwidth for the DVB-T signal.
/// HIPAR guardInterval/This control sets the guard interval of the useful OFDM symbol 
/// HIPAR guardInterval/duration Tu.
/// HIPAR hierarchy/Selects the coding hierarchy.
/// HIPAR constellation/Defines the constellation. The possible values depend on the selected 
/// HIPAR constellation/coding hierarchy ("Hierarchy").
ViStatus _VI_FUNC rsbtc_ConfigureDVBTCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	channelBandwidth,
	ViReal64	usedBandwidth,
	ViInt32	fftMode,
	ViInt32	guardInterval,
	ViInt32	hierarchy,
	ViInt32	constellation
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	if (channelBandwidth == RSBTC_IQC_DVBT_CHBW_VAR)
	{
		viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_USED_BANDWIDTH, usedBandwidth),
                         4, "Used Bandwidth");
	}
	else
	{
		viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_CHANNEL_BANDWIDTH, channelBandwidth),
	                         3, "channelBandwidth");
	}
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_FFT_MODE, fftMode),
                         5, "FFT Mode");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_GUARD_INTERVAL, guardInterval),
                         6, "Guard Interval");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_HIERARCHY, hierarchy),
                         7, "Hierarchy");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_CONSTELLATION, constellation),
                         8, "Constellation");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVB-H coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_CODING_DVBH_STATE
/// HIFN     RSBTC_ATTR_DVBT_CODING_DVBH_SYMBOL_INTERLEAVER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:DVHState ON | OFF
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT:DVBH:SYMBol[:INTerleaver] NATive | INDepth
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the DVBH state.
/// HIPAR symbolInterleaverMode/This control switches the mode of the DVB-H symbol interleaver.
ViStatus _VI_FUNC rsbtc_ConfigureDVBTHCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViInt32	symbolInterleaverMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_DVBH_STATE, state),
                         3, "State");
	if (state == VI_TRUE)
		viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBT_CODING_DVBH_SYMBOL_INTERLEAVER, symbolInterleaverMode),
                         4, "Symbol Interleaver Mode");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function enables use of special DVBT coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables or disables all special settings. This is useful if you want 
/// HIPAR specialSettings/to quickly switch back to a standard-compliant channel coding without 
/// HIPAR specialSettings/losing your customized special settings.
ViStatus _VI_FUNC rsbtc_EnableDVBTSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
       
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBT_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function stores or loads carriers in the specified file.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBT_SPECIAL_LOAD_CARRIERS
/// HIFN     RSBTC_ATTR_DVBT_SPECIAL_STORE_CARRIERS
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) Switches off carriers of the DVB-T signal described in ASCII file 
/// HIFN  <string>. Which carriers are to be switched off is determined as 
/// HIFN  follows:
/// HIFN     - The carrier numbers are 0 to 1704 for 2K, 0 to 3408 for 4K, and0 to 
/// HIFN  6816 for 8K.
/// HIFN     - The delimiter is ",".
/// HIFN     - The file size may be up to 32768 characters.
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT[:SPECial]:DISable:CARRiers:LOAD
/// HIFN     [SOURce<hw>][:IQCoder]:DVBT[:SPECial]:DISable:CARRiers:STORe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/Selects operation.
/// HIPAR source/This control specifies the source of the operation to be performed. If 
/// HIPAR source/the operation requires a single parameter, this control specifies that 
/// HIPAR source/parameter.
ViStatus _VI_FUNC rsbtc_StoreAndLoadDVBTCarriers(
	ViSession	instrSession,
		ViInt32	path,
	ViInt32	operation,
	ViString	source
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 	switch (operation){
            case RSBTC_VAL_SAVE:
				viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap, RSBTC_ATTR_DVBT_SPECIAL_STORE_CARRIERS, source),
                         4, "Source");                           
            break;
        
            case RSBTC_VAL_RECALL:
				viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap, RSBTC_ATTR_DVBT_SPECIAL_LOAD_CARRIERS, source),
                         4, "Source");                           
            break;
			
			default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Operation"); 
        }   
    

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBC Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DVBC_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DVBC_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_DVBC_INPUT_SIGNAL_STUFFING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:TESTsignal
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:STUFfing
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface. All TS IN inputs are MPEG TS 
/// HIPAR input/ASI (asynchronous serial interface) inputs.
/// HIPAR testSignal/Configures the data signal fed to the modulator.
/// HIPAR stuffing/Switches the stuffing on or off.
ViStatus _VI_FUNC rsbtc_ConfigureDVBCInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
		ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBC_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 5, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBC_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_DVBC_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 7, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads selected coding value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DVBC_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBC_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBC_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:DVBC:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:DVBC[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:DVBC:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDVBCInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBC_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBC_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBC_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBC coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBC_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBC_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DVBC_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_DVBC_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:TSPacket H184 | S187
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:PIDTestpack NULL | VARiable
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:PID
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:PAYLoad PRBS | H00 | HFF
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:PRBS[:SEQuence] P23_1 | P15_1
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/Specifies the structure of the test transport stream packet that is 
/// HIPAR testTSPacket/fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR payloadTestStuff/Defines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestStuff/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestStuff/packets".
/// HIPAR prbs/Defines the period length of the PRBS generator which fills the 
/// HIPAR prbs/payload area of the transport stream packet (test signal or null 
/// HIPAR prbs/packet).
ViStatus _VI_FUNC rsbtc_ConfigureDVBCSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBC coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC_CODING_SYMBOL_RATE
/// HIFN     RSBTC_ATTR_DVBC_CODING_CONSTELLATION
/// HIFN     RSBTC_ATTR_DVBC_CODING_ROLL_OFF
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:SYMBols[:RATE]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:CONStel C16 | C32 | C64 | C128 | C256
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC:ROLLoff 0.10 | 0.13 | 0.15 | 0.18 | 0.20
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR symbolRate/This control allows setting of the symbol rate.
/// HIPAR constellation/This control selects the modulation (constellation) of the DVB-C 
/// HIPAR constellation/signal.
/// HIPAR rollOff/Defines the roll-off alpha factor. The output signals are pulse-shaped 
/// HIPAR rollOff/by an FIR filter, yielding a root raised cosine characteristic.
ViStatus _VI_FUNC rsbtc_ConfigureDVBCCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	symbolRate,
	ViInt32	constellation,
	ViInt32	rollOff
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBC_CODING_SYMBOL_RATE, symbolRate),
                         3, "Symbol Rate");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBC_CODING_CONSTELLATION, constellation),
                         4, "Constellation");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CODING_ROLL_OFF, rollOff),
                         5, "Roll Off");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBC_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBC[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableDVBCSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
 
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
       
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBC_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBS Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DVBS_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DVBS_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_DVBS_INPUT_SIGNAL_STUFFING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:TESTsignal
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:STUFfing
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface. All TS IN inputs are MPEG TS 
/// HIPAR input/ASI (asynchronous serial interface) inputs.
/// HIPAR testSignal/Configures the test signal.
/// HIPAR stuffing/Switches the stuffing on or off.
ViStatus _VI_FUNC rsbtc_ConfigureDVBSInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
		ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBS_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBS_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBS_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 5, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBS_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_DVBS_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 7, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads selected coding value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DVBS_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBS_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBS_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:DVBS:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:DVBS[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:DVBS:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDVBSInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBS_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBS_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBS_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBS coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBS_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBS_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DVBS_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_DVBS_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:TSPacket
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:PIDTestpack
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:PID
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:PAYLoad
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/Specifies the structure of the test transport stream packet that is 
/// HIPAR testTSPacket/fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/Defines the header value. The available values depend on the setting 
/// HIPAR pid/under "PID Test Packet".
/// HIPAR payloadTestStuff/Defines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestStuff/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestStuff/packets".
/// HIPAR prbs/This control sets the PRBS to be used.
ViStatus _VI_FUNC rsbtc_ConfigureDVBSSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures DVBS coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS_CODING_SYMBOL_RATE
/// HIFN     RSBTC_ATTR_DVBS_CODING_CONSTELLATION
/// HIFN     RSBTC_ATTR_DVBS_CODING_ROLL_OFF
/// HIFN     RSBTC_ATTR_DVBS_CODING_CODE_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:SYMBols[:RATE]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:CONStel
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:ROLLoff
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS:RATE
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR symbolRate/This control allows setting of the symbol rate.
/// HIPAR constellation/Defines the constellation.
/// HIPAR rollOff/The output signals are pulse-shaped by an FIR filter, yielding a root 
/// HIPAR rollOff/raised cosine characteristic. Defines the alpha value. The 
/// HIPAR rollOff/specification of DVB-S defines a roll-off alpha factor of 0.35. The 
/// HIPAR rollOff/specification of DVB-DSNG defines a roll-off alpha factor of 0.25 or 
/// HIPAR rollOff/0.35.
/// HIPAR codeRate/Defines the code rate. The available code rates depend on the setting 
/// HIPAR codeRate/under "Constellation".
ViStatus _VI_FUNC rsbtc_ConfigureDVBSCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	symbolRate,
	ViInt32	constellation,
	ViInt32	rollOff,
	ViInt32	codeRate
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBS_CODING_SYMBOL_RATE, symbolRate),
                         3, "Symbol Rate");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS_CODING_CONSTELLATION, constellation),
                         4, "Constellation");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS_CODING_ROLL_OFF, rollOff),
                         5, "Roll Off");
		
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS_CODING_CODE_RATE, codeRate),
                         6, "Code Rate");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures the CID signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR CID/Enables or disables the CID signal.
/// HIPAR hostSignal/Used for test purposes. Enables or disables the host signal.
/// HIPAR frequencyOffset/Sets the frequency offset with which the CID signal is added.
ViStatus _VI_FUNC rsbtc_ConfigureDVBSCIDSignal (ViSession instrSession,
                                                ViInt32 path, 
												ViBoolean CID,
                                                ViBoolean hostSignal,
                                                ViInt32 frequencyOffset)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_ENABLED, CID),
                         3, "CID");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_HOST_SIGNAL, hostSignal),
                         4, "Host Signal");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_FREQUENCY_OFFSET, frequencyOffset),
                         5, "Frequency Offset");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
 


/// HIFN This function configures the CID latitude/longitude information in signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the transmission of the latitude and
/// HIPAR state/longitude information.
/// HIPAR latitude/Sets the latitude information of the transmitter.
/// HIPAR longitude/Sets the longitude information of the transmitter.
ViStatus _VI_FUNC rsbtc_ConfigureDVBSCIDCoordinates (ViSession instrSession,
                                                     ViInt32 path,
                                                     ViBoolean state,
                                                     ViReal64 latitude,
                                                     ViReal64 longitude)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_LATITUDE_LONGITUDE_ENABLED, state),
                         3, "State");
	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_LATITUDE, latitude),
                         4, "Latitude");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_LONGITUDE, longitude),
                         5, "Longitude");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}   



/// HIFN This function configures the CID telephone content in signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the transmission of the telephone information.
/// HIPAR number/Sets the telephone number.
/// HIPAR extensionState/Enables or disables the use of the telephone number extension.
/// HIPAR extensionNumber/Sets the telephone number extension.
ViStatus _VI_FUNC rsbtc_ConfigureDVBSCIDTelephone (ViSession instrSession,
                                                   ViInt32 path, 
												   ViBoolean state,
                                                   ViString number,
                                                   ViBoolean extensionState,
                                                   ViString extensionNumber)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_TELEPHONE_ENABLED, state),
                         3, "State");
	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViString(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_TELEPHONE_NUMBER, number),
                         4, "Number");
	
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_TELEPHONE_EXTENSION_ENABLED, extensionState),
                         5, "Extension State");
		if (extensionState == VI_TRUE)
		{
			viCheckParm (rsbtc_SetAttributeViString(instrSession, rep_cap, RSBTC_ATTR_DVBS_CID_CONTENT_TELEPHONE_EXTENSION_NUMBER, extensionNumber),
                         6, "Extension Number");
		}
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Switches the phase noise generator on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR phaseNoise/Enables or diables the phase noise generator.
ViStatus _VI_FUNC rsbtc_EnableDVBSPhaseNoise (ViSession instrSession,
                                              ViInt32 path, 
											  ViBoolean phaseNoise)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_PHASE_NOISE_ENABLED, phaseNoise),
                         3, "Phase Noise");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the phase noise generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR CWMode/Disables the modulation and emits a continuous wave signal.
/// HIPAR magnitude/Selects the amplitude of the phase noise generator.
/// HIPAR shape/Selects the amplitude of the phase noise generator.
ViStatus _VI_FUNC rsbtc_ConfigureDVBSPhaseNoise (ViSession instrSession,
                                                ViInt32 path, 
												ViBoolean CWMode,
                                                ViInt32 magnitude, 
												ViInt32 shape)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_PHASE_NOISE_CW_MODE, CWMode),
                         3, "CW Mode");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS_PHASE_NOISE_MAGNITUDE, magnitude),
                         4, "Magnitude");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS_PHASE_NOISE_SHAPE, shape),
                         5, "Shape");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableDVBSSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures 8VSB Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_8VBS_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_8VSB_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_8VSB_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_8VSB_INPUT_SIGNAL_STUFFING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:TESTsignal
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:STUFfing
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/This control selects the signal source for the 8VSB coder.
/// HIPAR input/Configures the external input interface. 
/// HIPAR testSignal/Configures the test signal.
/// HIPAR stuffing/Switches the stuffing on or off.
ViStatus _VI_FUNC rsbtc_Configure8VSBInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
		ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_8VBS_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_8VSB_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_8VSB_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 5, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_8VSB_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_8VSB_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 7, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads selected coding value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_8VSB_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_8VSB_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_8VSB_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:VSB:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:VSB[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:VSB:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_Read8VSBInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_8VSB_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_8VSB_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_8VSB_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures 8VSB coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_8VSB_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_8VSB_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_8VSB_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_8VSB_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_8VSB_CONFIGURING_PRBS
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:TSPacket H184 | S187
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:PIDTestpack NULL | VARiable
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:PID
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:PAYLoad PRBS | H00 | HFF
/// HIFN     [SOURce<hw>][:IQCoder]:VSB:PRBS[:SEQuence] P23_1 | P15_1
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control selects the mode of the test TS packet.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR payloadTestStuff/Defines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestStuff/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestStuff/packets".
/// HIPAR prbs/Defines the period length of the PRBS generator which fills the 
/// HIPAR prbs/payload area of the transport stream packet (test signal or null 
/// HIPAR prbs/packet).
ViStatus _VI_FUNC rsbtc_Configure8VSBSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_8VSB_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_8VSB_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_8VSB_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_8VSB_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_8VSB_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_8VSB_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:VSB[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_Enable8VSBSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_8VSB_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures J83B Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_J83B_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_J83B_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_J83B_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_J83B_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_J83B_INPUT_SIGNAL_STUFFING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:TESTsignal
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:STUFfing
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface. All TS IN inputs are MPEG TS 
/// HIPAR input/ASI (asynchronous serial interface) inputs.
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR testSignal/This control selects the signal source for the J83B coder.
/// HIPAR stuffing/Switches the stuffing on or off.
ViStatus _VI_FUNC rsbtc_ConfigureJ83BInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_J83B_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_J83B_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_J83B_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 5, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_J83B_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_J83B_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 7, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads selected coding value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_J83B_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_J83B_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_J83B_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:J83B:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:J83B[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:J83B:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadJ83BInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_J83B_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_J83B_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_J83B_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures J83B coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_J83B_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_J83B_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_J83B_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_J83B_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_J83B_CONFIGURING_PRBS
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:TSPacket
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:PIDTestpack
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:PID
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:PAYLoad
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control selects the mode of the test TS packet.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/Defines the header value. The available values depend on the setting 
/// HIPAR pid/under "PID Test Packet".
/// HIPAR payloadTestStuff/This control defines the payload area content of the transport stream 
/// HIPAR payloadTestStuff/packet. The transport stream packet is the test signal ("Test TS 
/// HIPAR payloadTestStuff/Packet") or "null packets".
/// HIPAR prbs/This control defines the period length of the PRBS generator which 
/// HIPAR prbs/fills the payload area of the transport stream packet (test signal or 
/// HIPAR prbs/null packet).
ViStatus _VI_FUNC rsbtc_ConfigureJ83BSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_J83B_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_J83B_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_J83B_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_J83B_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_J83B_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures J83B coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_J83B_CODING_SYMBOL_RATE
/// HIFN     RSBTC_ATTR_J83B_CODING_CONSTELLATION
/// HIFN     RSBTC_ATTR_J83B_CODING_INTERLEAVER_MODE
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:SYMBols[:RATE]
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:CONStel
/// HIFN     [SOURce<hw>][:IQCoder]:J83B:INTerleaver:MODE
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR symbolRate/Sets the symbol rate. The symbol rate may deviate from the nominal 
/// HIPAR symbolRate/symbol rate by 10%.
/// HIPAR constellation/Defines the constellation.
/// HIPAR interleaver/Sets the interleaver mode. The ITUT J.83/B specification stipulates 
/// HIPAR interleaver/twelve different possibilities for the interleaver. Interleaver depth I 
/// HIPAR interleaver/and base delay J are both varied, a four-bit wide control word 
/// HIPAR interleaver/identifies the interleaver mode:
ViStatus _VI_FUNC rsbtc_ConfigureJ83BCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	symbolRate,
	ViInt32	constellation,
	ViInt32	interleaver
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_J83B_CODING_SYMBOL_RATE, symbolRate),
                         3, "Symbol Rate");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_J83B_CODING_CONSTELLATION, constellation),
                         4, "Constellation");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_J83B_CODING_INTERLEAVER_MODE, interleaver),
                         5, "Interleaver");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables use of special J83B coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_J83B_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:J83B[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableJ83BSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_J83B_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures ISDBT Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_ISDBT_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:SOURce:A
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:SOURce:B
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:SOURce:C 
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TESTsignal:A
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TESTsignal:B
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TESTsignal:C
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR layer/This control selects the layer for the ISDBT coder.
/// HIPAR source/Sets the modulation source for layer A, B or C.
/// HIPAR testSignal/Configures the test signal.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	layer,
	ViInt32	source,
	ViInt32	testSignal
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_layer[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_layerRepCap (instrSession, layer, rep_cap_layer));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_layer);
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ISDBT_INPUT_SIGNAL_SOURCE, source
                                               ), 4, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_ISDBT_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 5, "Test Signal");  
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures external ISDBT input signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_EXTERNAL_INPUT_SIGNAL_STUFFING
/// HIFN     RSBTC_ATTR_ISDBT_EXTERNAL_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_ISDBT_EXTERNAL_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:STUFfing
/// HIFN     [SOURce<hw>][:IQCoder]:INPut[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR input/Configures the external input interface. All TS IN inputs are MPEG TS 
/// HIPAR input/ASI (asynchronous serial interface) inputs.
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
ViStatus _VI_FUNC rsbtc_ConfigureISDBTExternalInputParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	input,
	ViInt32	ipTSChannel
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ISDBT_EXTERNAL_INPUT_SIGNAL_INPUT, input
                                               ), 3, "Input");
	if (input == RSBTC_IQC_INPUT_IP)
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ISDBT_EXTERNAL_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 4, "IP TS Channel");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_ISDBT_INPUT_SIGNAL_MEAS_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_ISDBT_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_ISDBT_EXTERNAL_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:ISDBt:USEFul[:RATE]:A?
/// HIFN     READ<hw>[:IQCoder]:ISDBt:USEFul[:RATE]:B?
/// HIFN     READ<hw>[:IQCoder]:ISDBt:USEFul[:RATE]:C?
/// HIFN     READ<hw>[:IQCoder]:ISDBt:USEFul[:RATE]:MAX:A?
/// HIFN     READ<hw>[:IQCoder]:ISDBt:USEFul[:RATE]:MAX:B?
/// HIFN     READ<hw>[:IQCoder]:ISDBt:USEFul[:RATE]:MAX:C?
/// HIFN     READ<hw>[:IQCoder]:ISDBt[:INPut]:DATarate?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR layer/This control selects the layer for the ISDBT coder.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadISDBTInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	layer,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_layer[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    
	if (dataRate != RSBTC_VAL_MEAS_DRATE)
	{
		checkErr(rsbtc_layerRepCap (instrSession, layer, rep_cap_layer));  
	
		strcpy (rep_cap, rep_cap_path);
	    strcat (rep_cap, ",");
	    strcat (rep_cap, rep_cap_layer);
	}
    
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ISDBT_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 5, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap_path, RSBTC_ATTR_READ_ISDBT_EXTERNAL_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 5, "Result");											 
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ISDBT_INPUT_SIGNAL_MEAS_USEFUL_DATA_RATE, 
                result), 5, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures ISDBT coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_ISDBT_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_ISDBT_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_ISDBT_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_ISDBT_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TSPacket
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:PIDTestpack
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:PID
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:PAYLoad
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control specifies the structure of the test transport stream 
/// HIPAR testTSPacket/packet that is fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control defines the header value. The available values depend on 
/// HIPAR pid/the setting under "PID Test Packet".
/// HIPAR prbs/This control defines the period length of the PRBS generator which 
/// HIPAR prbs/fills the payload area of the transport stream packet (test signal or 
/// HIPAR prbs/null packet).
/// HIPAR payloadTestStuff/efines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestStuff/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestStuff/packets".
ViStatus _VI_FUNC rsbtc_ConfigureISDBTSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures ISDBT coding parameters for layer A, B or C.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_CODING_PORTION
/// HIFN     RSBTC_ATTR_ISDBT_CODING_CONSTELLATION
/// HIFN     RSBTC_ATTR_ISDBT_CODING_SEGMENTS
/// HIFN     RSBTC_ATTR_ISDBT_CODING_CODE_RATE
/// HIFN     RSBTC_ATTR_ISDBT_CODING_TIME_INTERLEAVING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:PORTion
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:CONStel:A
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:CONStel:B
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:CONStel:C
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:SEGMents:A
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:SEGMents:B
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:SEGMents:C
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:RATE:A
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:RATE:B
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:RATE:C
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TIME:A
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TIME:B
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:TIME:C
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR layer/This control selects the layer for the ISDBT coder.
/// HIPAR portion/This control sets the modulation types of the respective hierarchical 
/// HIPAR portion/layers. As ARIB STD-B31 does not allow all combinations, an automatic 
/// HIPAR portion/correction is applied.
/// HIPAR constellation/This control selects the type of modulation (constellation) of layer 
/// HIPAR constellation/A, B or C.
/// HIPAR segments/This control selects the segments for layer A, B or C.
/// HIPAR codeRate/Sets the code rate of the convolutional coders of each layer 
/// HIPAR codeRate/separately. Influences the maximum data rate to be transmitted on the 
/// HIPAR codeRate/respective layer ("Max. Useful Data Rate (A|B|C)"). If more useful data 
/// HIPAR codeRate/is transmitted, i.e. if less redundancy is inserted, troubleshooting 
/// HIPAR codeRate/becomes more difficult. If less useful data is transmitted, 
/// HIPAR codeRate/transmission reliability is higher.
/// HIPAR timeInterleaving/This control sets the time interleaving depth of each layer 
/// HIPAR timeInterleaving/separately. The possible depths depend on the setting under "ISDBT 
/// HIPAR timeInterleaving/Mode". The correlation is shown in table "Possible combinations" and is 
/// HIPAR timeInterleaving/defined conforming to the ISDBT specification.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTLayerCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	layer,
	ViInt32	portion,
	ViInt32	constellation,
	ViInt32	segments,
	ViInt32	codeRate,
	ViInt32	timeInterleaving
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_layer[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_layerRepCap (instrSession, layer, rep_cap_layer));  
	
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_layer);
    

	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap_path, RSBTC_ATTR_ISDBT_CODING_PORTION, portion),
                         4, "Portion");

	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_CONSTELLATION, constellation),
                         5, "Constellation");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_SEGMENTS, segments),
                         6, "Segments");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_CODE_RATE, codeRate),
                         7, "Code Rate");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_TIME_INTERLEAVING, timeInterleaving),
                         8, "Time Interleaving");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures ISDBT coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_CODING_ISDBT_MODE
/// HIFN     RSBTC_ATTR_ISDBT_CODING_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_ISDBT_CODING_BANDWIDTH_VARIATION
/// HIFN     RSBTC_ATTR_ISDBT_CODING_CHANNEL_BANDWIDTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:FFT:MODE M1_2k | M2_4k | M3_8k
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:BANDwidth:VARiation
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:GUARd G1_4 | G1_8 | G1_16 | G1_32
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt:CHANnel[:BANDwidth] 
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR isdbtMode/Sets the ISDBT mode. This setting does not refer to individual layers 
/// HIPAR isdbtMode/but to the entire transmission. This mode is primarily used to select 
/// HIPAR isdbtMode/the length of the inverse fast Fourier transformation (IFFT), which in 
/// HIPAR isdbtMode/turn affects the OFDM symbol duration. In addition, the settings of the 
/// HIPAR isdbtMode/time interleaver are influenced ("Time Interleaving (A|B|C)").
/// HIPAR guardInterval/Sets the transmission guard interval. The guard interval is a cyclic 
/// HIPAR guardInterval/extension of the OFDM symbol by a specific factor.
/// HIPAR bandwidthVariation/Varies the bandwidth of the ISDBT spectrum by maximally +-1000 ppm. 
/// HIPAR bandwidthVariation/Any bandwidth differing from the nominal bandwidth ("Used Bandwidth") 
/// HIPAR bandwidthVariation/is marked accordingly.
/// HIPAR channelBandwidth/Sets the channel bandwidth. The display of the actual bandwidth is 
/// HIPAR channelBandwidth/updated. As the number of the OFDM carriers remains constant, the 
/// HIPAR channelBandwidth/carrier spacing and the OFDM symbol duration are adapted accordingly.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	isdbtMode,
	ViInt32	guardInterval,
	ViInt32	channelBandwidth,
	ViInt32	bandwidthVariation

)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
		
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_ISDBT_MODE, isdbtMode),
                         3, "ISDBT Mode");

	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_GUARD_INTERVAL, guardInterval),
                         4, "Guard Interval");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_CHANNEL_BANDWIDTH, channelBandwidth),
                         5, "Channel Bandwidth");

	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_CODING_BANDWIDTH_VARIATION, bandwidthVariation),
                         6, "Bandwidth Variation");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the segments for all layer.
/// HIFN     
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     SOURce<device>][:IQCoder]:ISDBt:SEGMents:ALL <num>,<num>,<num>
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR segmentsLayerA/This control selects the segments for layer A.
/// HIPAR segmentsLayerB/This control selects the segments for layer B.
/// HIPAR segmentsLayerC/This control selects the segments for layer C.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTAllSegments(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	segmentsLayerA,
	ViInt32	segmentsLayerB,
	ViInt32	segmentsLayerC
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = "";  	

    checkErr (Rs_LockSession (instrSession, NULL));

    viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
    
	sprintf (buffer,"SOUR%ld:ISDB:SEGM:ALL %ld,%ld,%ld", path, segmentsLayerA, segmentsLayerB, segmentsLayerC);	

    viCheckErr( viPrintf (instrSession, "%s\n", buffer));
    viCheckErr(rsbtc_CheckStatus (instrSession));      

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures ISDBT coding parameters for simulation of the 
/// HIFN  earthquake early warning system (EEW).
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_EEW_STATE
/// HIFN     RSBTC_ATTR_ISDBT_EEW_SIGNAL_TYPE
/// HIFN     RSBTC_ATTR_ISDBT_EEW_NUMBER_OF_EPICENTERS
/// HIFN     RSBTC_ATTR_ISDBT_EEW_AREA_INFORMATION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:EEW
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:SIGNaltype
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:AREainfo
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:NUMepicenter
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR eew/Enables or disables the earthquake early warning (EEW) system.
/// HIPAR signalType/Identifies the type of seismic motion warning.
/// HIPAR numberOfEpicenters/Identifies the total number of seismic motion information being 
/// HIPAR numberOfEpicenters/transmitted.
/// HIPAR areaInformation/Sets the target area of the seismic motion warning in hexadecimal 
/// HIPAR areaInformation/presentation. The bits are assigned according to table 'Area 
/// HIPAR areaInformation/information for seismic motion event'.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTEEWSystem (ViSession instrSession,
												 ViInt32 path, ViBoolean eew,
                                                 ViInt32 signalType,
                                                 ViInt32 numberOfEpicenters,
                                                 ViChar areaInformation[])
{
	ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[25] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_ISDBT_EEW_STATE,
                                                 eew), 3, "EEW");
														
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ISDBT_EEW_SIGNAL_TYPE,
                                                 signalType), 4, "Signal Type");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                                 RSBTC_ATTR_ISDBT_EEW_NUMBER_OF_EPICENTERS,
	                                                 numberOfEpicenters), 5, "Number Of Epicenters");
	
	viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_ISDBT_EEW_AREA_INFORMATION,
                                             areaInformation), 6, "Area Information");

Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}

/// HIFN  This function sets the individual parameters for each epicenter are 
/// HIFN  shown. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_EEW_EPICENTER_INFORMATION_TYPE
/// HIFN     RSBTC_ATTR_ISDBT_EEW_EPICENTER_WARNING_ID
/// HIFN     RSBTC_ATTR_ISDBT_EEW_EPICENTER_LATITUDE
/// HIFN     RSBTC_ATTR_ISDBT_EEW_EPICENTER_LONGITUDE
/// HIFN     RSBTC_ATTR_ISDBT_EEW_EPICENTER_DEPTH
/// HIFN     RSBTC_ATTR_ISDBT_EEW_EPICENTER_OCCURRENCE_TIME
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:INFotype<epicenter>
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:WARNid<epicenter>
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:LATitude<epicenter>
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:LONGitude<epicenter>
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:DEPTh<epicenter>
/// HIFN     [SOURce<device>:][IQCoder:]ISDBt:EEW:OCCurrence<epicenter>
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR epicenter/This control selects the epicenter .
/// HIPAR informationType/Provides information about the validity of the seismic motion warning.
/// HIPAR warningID/Sets the individual identification number of the seismic motion 
/// HIPAR warningID/warning.
/// HIPAR latitude/Indicates the geographical latitude of the epicenter of the seismic 
/// HIPAR latitude/event. Negative values indicate a southern latitude, while positive 
/// HIPAR latitude/values indicate a northern latitude.
/// HIPAR longitude/Indicates the geographical longitude of the epicenter of the seismic 
/// HIPAR longitude/event. Negative values indicate a western longitude, while positive 
/// HIPAR longitude/values indicate an eastern longitude.
/// HIPAR depth/Indicates the depth of the epicenter of the seismic event.
/// HIPAR occurrenceTime/Indicates the occurrence time of the seismic event.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTEEWParameters (ViSession instrSession,
                                                     ViInt32 path,
                                                     ViInt32 epicenter,
                                                     ViInt32 informationType,
                                                     ViInt32 warningID,
                                                     ViReal64 latitude,
                                                     ViReal64 longitude,
                                                     ViInt32 depth,
                                                     ViInt32 occurrenceTime)
{
	ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[10] = ""; 	

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	sprintf(rep_cap_1, ",EP%ld", epicenter);
	strcat (rep_cap, rep_cap_1);


	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 3, "Epicenter");  
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ISDBT_EEW_EPICENTER_INFORMATION_TYPE,
                                                 informationType), 4, "Information Type");
														
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ISDBT_EEW_EPICENTER_WARNING_ID,
                                                 warningID), 5, "Warning ID");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                                 RSBTC_ATTR_ISDBT_EEW_EPICENTER_LATITUDE,
	                                                 latitude), 6, "Latitude");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_ISDBT_EEW_EPICENTER_LONGITUDE,
                                             longitude), 7, "Longitude");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ISDBT_EEW_EPICENTER_DEPTH,
                                                 depth), 8, "Depth");
														
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ISDBT_EEW_EPICENTER_OCCURRENCE_TIME,
                                                 occurrenceTime), 9, "Occurrence Time");
Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}


/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableISDBTSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures segments for special ISDBT coding.
/// HIFN     
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt[:SPECial]:SEGMents[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR segment/This control selects the segments for layer A, B or C.
/// HIPAR state/Switches the selected segment on or off.
ViStatus _VI_FUNC rsbtc_ConfigureISDBTSpecialSegmentSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	segment,
	ViBoolean	state
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = "";  	

	checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");    
	
	viCheckParm (rsbtc_invalidViInt32Range (segment, 0, 12), 3, "Segment");    
    
	sprintf (buffer,"SOUR%ld:ISDB:SEGM %ld,%s", path, segment, stateArr[state]);	

    viCheckErr( viPrintf (instrSession, "%s\n", buffer));
    viCheckErr(rsbtc_CheckStatus (instrSession));      
 
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures special ISDBT coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_GUARD_INSERTION
/// HIFN     RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_TX_PARAM_SWITCH_INDICATOR
/// HIFN     RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_MOD_TMCC_NEXT
/// HIFN     RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_AC_DATA_AC1
/// HIFN     RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_AC_DATA_AC2
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBT[:SPECial]:GUARd:STATe
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt[:SPECial]:TXParam
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt[:SPECial]:TMCC:NEXT
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt[:SPECial]:ACData1
/// HIFN     [SOURce<hw>][:IQCoder]:ISDBt[:SPECial]:ACData2
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR guardInsertion/Enables or disables the guard interval so that the useful components 
/// HIPAR guardInsertion/of the OFDM symbols connect seamlessly.
/// HIPAR txParamSwitchingIndicator/This control defines the statical setting of transmission parameter 
/// HIPAR txParamSwitchingIndicator/switching indicator (for test purposes).
/// HIPAR tmccNext/Sets the TMCC next information bits.
/// HIPAR acData_AC1/This control sets the AC carriers modulation. The PRBS degree can be 
/// HIPAR acData_AC1/set under "PRBS".
/// HIPAR acData_AC2/This control sets the AC carriers modulation. The PRBS degree can be 
/// HIPAR acData_AC2/set under "PRBS".
ViStatus _VI_FUNC rsbtc_ConfigureISDBTSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	guardInsertion,
	ViInt32	txParamSwitchingIndicator,
	ViInt32	tmccNext,
	ViInt32	acData_AC1,
	ViInt32	acData_AC2
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
		
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_GUARD_INSERTION, guardInsertion),
                         3, "Guard Insertion");

	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_TX_PARAM_SWITCH_INDICATOR, txParamSwitchingIndicator),
                         4, "TX Param Switching Indicator");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_MOD_TMCC_NEXT, tmccNext),
                         5, "TMCC Next");
	if(acData_AC1 != RSBTC_VAL_ISDBT_AC_DATA_UNUSED)
		viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_AC_DATA_AC1, acData_AC1),
                         6, "AC Data (AC1)");
	if(acData_AC2 != RSBTC_VAL_ISDBT_AC_DATA_UNUSED)  
		viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ISDBT_SPECIAL_SETTINGS_AC_DATA_AC2, acData_AC2),
                         7, "AC Data (AC2)");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DTMB Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DTMB_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DTMB_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DTMB_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_DTMB_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_DTMB_INPUT_SIGNAL_STUFFING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce[:HIGH]
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:TESTsignal
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:STUFfing
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the modulation source.
/// HIPAR stuffing/Enables or disables the stuffing.
/// HIPAR input/Configures the external input interface. 
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR testSignal/This control configures the test signal.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DTMB_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DTMB_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DTMB_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 5, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DTMB_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_DTMB_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 7, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DTMB_INPUT_SIGNAL_MAXIMUM_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DTMB_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DTMB_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:DTMB:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:DTMB[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:DTMB:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDTMBInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DTMB_INPUT_SIGNAL_MAXIMUM_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DTMB_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DTMB_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DTMB coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DTMB_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DTMB_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DTMB_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DTMB_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_DTMB_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:TSPacket
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:PIDTestpack
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:PID
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:PAYLoad
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control specifies the structure of the test transport stream 
/// HIPAR testTSPacket/packet that is fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR payloadTestStuff/Defines the payload area content of the transport stream packet. The 
/// HIPAR payloadTestStuff/transport stream packet is the test signal ("Test TS Packet") or "null 
/// HIPAR payloadTestStuff/packets".
/// HIPAR prbs/This control sets the PRBS to be used.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN This function defines the configuration mode of the coder.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR control/Defines the configuration mode of the coder.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBControl (ViSession instrSession,
                                              ViInt32 path, 
											  ViInt32 control)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_CONTROL, control),
                         3, "Control");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures DTMB Network parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DTMB_CODING_NETWORK_MODE
/// HIFN     RSBTC_ATTR_DTMB_CODING_SINGLE_CARRIER_MODE
/// HIFN     RSBTC_ATTR_DTMB_CODING_CONTROL_FRAMES
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:NETWorkmode
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:SINGle
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:FRAMes
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR networkMode/Sets the mode of the transmitter network.
/// HIPAR singleCarrierMode/Enables or disables the single carrier mode.
/// HIPAR controlFrames/Defines whether a control frame is added to each signal frame group or 
/// HIPAR controlFrames/not.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBNetworkMode(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	networkMode,
	ViBoolean	singleCarrierMode,
	ViBoolean	controlFrames
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_NETWORK_MODE, networkMode),
                         3, "Network Mode");
  
	if (networkMode == RSBTC_VAL_NETWORK_MODE_MFN) {
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_SINGLE_CARRIER_MODE, singleCarrierMode),
				                         4, "Single Carrier Mode");
  
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_CONTROL_FRAMES, controlFrames),
			                         5, "Control Frames");
}
		

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DTMB coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DTMB_CODING_CONSTELLATION
/// HIFN     RSBTC_ATTR_DTMB_CODING_CODE_RATE
/// HIFN     RSBTC_ATTR_DTMB_CODING_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_DTMB_CODING_GUARD_INTERVAL_PN
/// HIFN     RSBTC_ATTR_DTMB_CODING_TIME_INTERLEAVER
/// HIFN     RSBTC_ATTR_DTMB_CODING_CHANNEL_BANDWIDTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:CONStel
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:RATE
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:GUARd
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:GIC
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:TIME[:INTerleaver]
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:CHANnel[:BANDwidth]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR constellation/Defines the constellation.
/// HIPAR codeRate/Sets the puncturing of the internal error protection.
/// HIPAR guardInterval/Defines the duration of the guard interval.
/// HIPAR timeInterleaver/Defines the depth of the basic delay.
/// HIPAR guardIntervalPN/Defines the initial condition of the PN sequences in the frame 
/// HIPAR guardIntervalPN/headers.
/// HIPAR channelBandwidth/Sets the bandwidth of the output signal. The carrier count remains 
/// HIPAR channelBandwidth/constant (3780), but the carrier spacing changes.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	constellation,
	ViInt32	codeRate,
	ViInt32	guardInterval,
	ViInt32	guardIntervalPN,
		ViInt32	timeInterleaver,
		ViInt32	channelBandwidth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_CONSTELLATION, constellation),
                         3, "Constellation");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_CODE_RATE, codeRate),
                         4, "Code Rate");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_GUARD_INTERVAL, guardInterval),
                         5, "Guard Interval");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_GUARD_INTERVAL_PN, guardIntervalPN),
                         6, "Guard Interval PN");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_TIME_INTERLEAVER, timeInterleaver),
                         7, "Time Interleaver");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_CODING_CHANNEL_BANDWIDTH, channelBandwidth),
                         8, "Channel Bandwidth");


Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function defines the SFN parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR SIPRestamping/If enabled, in the incoming transport stream with second frame
/// HIPAR SIPRestamping/initialization packet (SIP), the SIP is restamped with a null
/// HIPAR SIPRestamping/packet.
/// HIPAR mute1stSignalFrame/If enabled, sets the first signal frame of a super frame to zero
/// HIPAR mute1stSignalFrame/(muted).
/// HIPAR _1PPSRouting/Sets the routing of the 1PPS signal needed for SFN operation.
/// HIPAR _1PPSRouting/The setting depends on the modulation source set under 'Source'.
/// HIPAR offset/Sets the delay offset.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBSFN (ViSession instrSession,
                                          ViInt32 path, 
										  ViBoolean SIPRestamping,
                                          ViBoolean mute1stSignalFrame,
                                          ViInt32 _1PPSRouting, 
										  ViReal64 offset)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_SIP_RESTAMPING, SIPRestamping),
                         3, "SIP Restamping");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_MUTE_1ST_SIGNAL_FRAME, mute1stSignalFrame),
                         4, "Mute 1st Signal Frame");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_1PPS_ROUTING, _1PPSRouting),
                         5, "1 PPS Routing");
	if (_1PPSRouting == RSBTC_VAL_SFN_ROUTING_OUT_INT){
		viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_DELAY_OFFSET, offset),
                         6, "Offset");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
 

/// HIFN This function defines the SFN Delay parameters
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR maxDeviationTime/Sets the maximum permitted deviation of the transmission time
/// HIPAR maxDeviationTime/relative to the internally regulated reference frequency. If the
/// HIPAR maxDeviationTime/configured value is exceeded, the absolute transmission time is
/// HIPAR maxDeviationTime/recalculated. This causes a brief signal failure (mute), that
/// HIPAR maxDeviationTime/means the transmit signal is reset and transmission is
/// HIPAR maxDeviationTime/restarted.
/// HIPAR staticDelay/Sets a positive or negative offset of the transmission time
/// HIPAR staticDelay/relative to the regular transmission time preset by the 'Maximum
/// HIPAR staticDelay/Delay'.
ViStatus _VI_FUNC rsbtc_ConfigureDTMBSFNDelay (ViSession instrSession,
                                               ViInt32 path,
                                               ViReal64 maxDeviationTime,
                                               ViReal64 staticDelay)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
 
	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_MAX_DEVIATION_TIME, maxDeviationTime),
                         3, "Max Deviation Time");
	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_STATIC_DELAY, staticDelay),
                         4, "Static Delay");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Document your function here.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR type/Document parameter here.
/// HIPAR delay/Document parameter here.
ViStatus _VI_FUNC rsbtc_ReadDTMBSFNDelay (ViSession instrSession,
                                          ViInt32 path, 
										  ViInt32 type,
                                          ViReal64 *delay)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
 
	switch (type){
		case RSBTC_VAL_DTMB_SFN_DELAY_NETWORK:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_NETWORK_DELAY, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_PROCESSING:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_PROCESSING_DELAY, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_DYNAMIC:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_DYNAMIC_DELAY, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_TOTAL:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_TOTAL_DELAY, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_MAXDEV:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_MAX_DEVIATION_TIME, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_STATIC:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_STATIC_DELAY, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_MAXIMUM:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_READ_DTMB_CODING_LOCAL_MAXIMUM_DELAY, delay),
                         4, "Delay");
		break;
		case RSBTC_VAL_DTMB_SFN_DELAY_DTIME:
			viCheckParm (rsbtc_GetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DTMB_SFN_DISPATCH_TIME, delay),
                         4, "Delay");
		break;
		default:
			viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Type");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DTMB_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DTMB:[SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableDTMBSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DTMB_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures DVBS2 CM Mode parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_CM_MODE
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_NUM_INPUT_STREAMS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:CMMode
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:INPut:NIS
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR CMMode/Sets the coding and modulation (CM) mode.
/// HIPAR numInputStreams/Displays the number of input streams. Maximum 8 input streams are possible.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2CodingAndModulationMode (ViSession instrSession,
                                                               ViInt32 path,
                                                               ViInt32 CMMode,
                                                               ViInt32 numInputStreams)
{
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_INPUT_SIGNAL_CM_MODE, CMMode),
                         3, "CM Mode");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_INPUT_SIGNAL_NUM_INPUT_STREAMS, numInputStreams),
                         4, "Num Input Streams");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;	
}

/// HIFN  This function configures DVBS2 Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_STUFFING
/// HIFN     RSBTC_ATTR_DVBS2_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHanne
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:STUFfing
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:TESTsignal
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface. 
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR stuffing/Enables or disables the stuffing.
/// HIPAR testSignal/This control selects the signal source for the DVBS2 coder.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2InputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 inputStream,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)

{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (inputStream, 1, 8), 3, "Input Stream");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",IS%ld", inputStream);
	
	strcat (rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBS2_INPUT_SIGNAL_SOURCE, source
                                               ), 4, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBS2_INPUT_SIGNAL_INPUT, input
                                               ), 5, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DVBS2_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 6, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_DVBS2_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 7, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_DVBS2_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 8, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DVBS2_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBS2_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DVBS2_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:DVBS2:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:DVBS2[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:DVBS2:USEFul[:RATE]?
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDVBS2InputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 inputStream,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[5] = "";     	

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (inputStream, 1, 8), 3, "Input Stream"); 
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
		
	sprintf(rep_cap_1, ",IS%ld", inputStream);
	
	strcat (rep_cap, rep_cap_1);
	
 	switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBS2_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 5, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBS2_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 5, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_DVBS2_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 5, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Data Rate"); 
   }
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DVBS2 coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DVBS2_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_DVBS2_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_DVBS2_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_DVBS2_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:TSPacket H184 | S187
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:PIDTestpack NULL | VARiable
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:PID
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:PAYLoad PRBS | H00 | HFF
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:PRBS[:SEQuence] P23_1 | P15_1
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control specifies the structure of the test transport stream 
/// HIPAR testTSPacket/packet that is fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR payloadTestStuff/This control allows selection of the payload in the TS packets of the 
/// HIPAR payloadTestStuff/DVBS2 signal.
/// HIPAR prbs/This control sets the PRBS to be used.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2Settings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CONFIGURING_PAYLOAD_TEST_STUFF, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures DVBS2 coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_CODING_SYMBOL_RATE
/// HIFN     RSBTC_ATTR_DVBS2_CODING_ROLL_OFF
/// HIFN     RSBTC_ATTR_DVBS2_CODING_ANNEX_M
/// HIFN     RSBTC_ATTR_DVBS2_CODING_NUM_TIME_SLICE
/// HIFN     RSBTC_ATTR_DVBS2_CODING_TSN
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:SYMBols[:RATE]
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:ROLLoff
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:ANNM
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:NTSL
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:TSL<1..8>:TSN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR symbolRate/This control sets the symbol rate. In the transmission spectrum, the 
/// HIPAR symbolRate/symbol rate represents the 3 dB bandwidth
/// HIPAR rollOff/The output signals are pulse-shaped by an FIR filter, yielding a root 
/// HIPAR rollOff/raised cosine characteristic. Defines the alpha value.
/// HIPAR annexM/Enables or disables the annex M features of the standard.
/// HIPAR numTimeSlice/Sets the number of time slices.
/// HIPAR tsn/Sets the time slice number (TSN). This number is used for 
/// HIPAR tsn/identification. Each time slice should use a unique TSN. If 'VCM' is 
/// HIPAR tsn/set under 'CM Mode', all input streams use the same number as they are 
/// HIPAR tsn/grouped under time slice 1.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2Coding(  ViSession instrSession,
												ViInt32 path, ViReal64 symbolRate,
												ViInt32 rollOff, ViBoolean annexM,
												ViInt32 numTimeSlice, ViInt32 tsn)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[20] = "";
	ViChar	rep_cap_1[10] = "";	

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_SYMBOL_RATE, symbolRate),
                         3, "Symbol Rate");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_ROLL_OFF, rollOff),
                         4, "Roll Off");
	
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_ANNEX_M, annexM),
                         5, "Annex M");
	
	if (annexM == VI_TRUE) {
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_NUM_TIME_SLICE, numTimeSlice),
                         6, "Num Time Slice");
		
		sprintf(rep_cap_1, ",TSL%ld", numTimeSlice);
		strcat (rep_cap, rep_cap_1);
	
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_TSN, tsn),
                         7, "TSN");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures DVBS2 Time Slice coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_CODING_MODULATION_CODING
/// HIFN     RSBTC_ATTR_DVBS2_CODING_FECFRAME
/// HIFN     RSBTC_ATTR_DVBS2_CODING_PILOTS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:TSL<1..8>[:IS<1..8>]:MODCod
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:TSL<1..8>[:IS<1..8>]:FECFrame
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2:TSL<1..8>[:IS<1..8>]:PILots
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR inputStream/Selects the input stream.
/// HIPAR tsl/Sets the time slice number.
/// HIPAR modulationCoding/Defines the modulation coding, a combined setting of constellation and 
/// HIPAR modulationCoding/code rate.
/// HIPAR FECFrame/This control sets the length of the FEC frames.
/// HIPAR pilots/Controls the insertion of pilot symbols during the formation of the 
/// HIPAR pilots/physical layer frame. Pilot symbols generate an unmodulated carrier and 
/// HIPAR pilots/are very helpful for synchronizing receivers under difficult 
/// HIPAR pilots/transmission conditions.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2TimeSliceCoding (ViSession instrSession,
                                                       ViInt32 path,
                                                       ViInt32 inputStream,
													   ViInt32 tsl, 													   
                                                       ViInt32 modulationCoding,
                                                       ViInt32 FECFrame,
													   ViBoolean pilots )
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[30] = "";
	ViChar	rep_cap_1[10] = "";   
	ViChar	rep_cap_2[10] = "";   
		
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	sprintf(rep_cap_1, ",TSL%ld", tsl);
	strcat (rep_cap, rep_cap_1);
	sprintf(rep_cap_2, ",IS%ld", inputStream);
	strcat (rep_cap, rep_cap_2);
    


	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_MODULATION_CODING, modulationCoding),
                         5, "Modulation Coding");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_FECFRAME, FECFrame),
                         6, "FEC Frame");
	
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_PILOTS, pilots),
                         7, "Pilots");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVBS2 S2-X features.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR inputStream/Selects the input stream.
/// HIPAR s2X/Enables or disables access to all S2X features.
/// HIPAR superFrame/Enables or disables S2X super frame.
/// HIPAR channelBonding/Enables or disables S2X channel bonding.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2S2X (ViSession instrSession,
                                           ViInt32 path, 
										   ViBoolean s2X,
                                           ViBoolean superFrame,
                                           ViBoolean channelBonding)
{
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_S2_X, s2X),
                         3, "S2-X");
	if (s2X == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_S2_X_SUPER_FRAME, superFrame),
                         4, "Super Frame");
		viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CODING_S2_X_CHANNEL_BONDING, channelBonding),
                         5, "Channel Bonding");
	}

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}		

/// HIFN This function configures the CID signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR CID/Enables or disables the CID signal.
/// HIPAR hostSignal/Used for test purposes. Enables or disables the host signal.
/// HIPAR frequencyOffset/Sets the frequency offset with which the CID signal is added.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2CIDSignal (ViSession instrSession,
                                                ViInt32 path, 
												ViBoolean CID,
                                                ViBoolean hostSignal,
                                                ViInt32 frequencyOffset)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_ENABLED, CID),
                         3, "CID");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_HOST_SIGNAL, hostSignal),
                         4, "Host Signal");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_FREQUENCY_OFFSET, frequencyOffset),
                         5, "Frequency Offset");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
 


/// HIFN This function configures the CID latitude/longitude information in signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the transmission of the latitude and
/// HIPAR state/longitude information.
/// HIPAR latitude/Sets the latitude information of the transmitter.
/// HIPAR longitude/Sets the longitude information of the transmitter.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2CIDCoordinates (ViSession instrSession,
                                                     ViInt32 path,
                                                     ViBoolean state,
                                                     ViReal64 latitude,
                                                     ViReal64 longitude)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_LATITUDE_LONGITUDE_ENABLED, state),
                         3, "State");
	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_LATITUDE, latitude),
                         4, "Latitude");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_LONGITUDE, longitude),
                         5, "Longitude");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}   



/// HIFN This function configures the CID telephone content in signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the transmission of the telephone information.
/// HIPAR number/Sets the telephone number.
/// HIPAR extensionState/Enables or disables the use of the telephone number extension.
/// HIPAR extensionNumber/Sets the telephone number extension.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2CIDTelephone (ViSession instrSession,
                                                   ViInt32 path, 
												   ViBoolean state,
                                                   ViString number,
                                                   ViBoolean extensionState,
                                                   ViString extensionNumber)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_TELEPHONE_ENABLED, state),
                         3, "State");
	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViString(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_TELEPHONE_NUMBER, number),
                         4, "Number");
	
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_TELEPHONE_EXTENSION_ENABLED, extensionState),
                         5, "Extension State");
		if (extensionState == VI_TRUE)
		{
			viCheckParm (rsbtc_SetAttributeViString(instrSession, rep_cap, RSBTC_ATTR_DVBS2_CID_CONTENT_TELEPHONE_EXTENSION_NUMBER, extensionNumber),
                         6, "Extension Number");
		}
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Switches the phase noise generator on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR phaseNoise/Enables or diables the phase noise generator.
ViStatus _VI_FUNC rsbtc_EnableDVBS2PhaseNoise (ViSession instrSession,
                                              ViInt32 path, ViBoolean phaseNoise)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_PHASE_NOISE_ENABLED, phaseNoise),
                         3, "Phase Noise");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the phase noise generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR CWMode/Disables the modulation and emits a continuous wave signal.
/// HIPAR magnitude/Selects the amplitude of the phase noise generator.
/// HIPAR shape/Selects the amplitude of the phase noise generator.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2PhaseNoise (ViSession instrSession,
                                                ViInt32 path, 
												ViBoolean CWMode,
                                                ViInt32 magnitude, 
												ViInt32 shape)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_PHASE_NOISE_CW_MODE, CWMode),
                         3, "CW Mode");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_PHASE_NOISE_MAGNITUDE, magnitude),
                         4, "Magnitude");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_PHASE_NOISE_SHAPE, shape),
                         5, "Shape");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DVBS2[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableDVBS2SpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{ 
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DVBS2_SPECIAL_SETTINGS, specialSettings),
                         3, "Special Settings");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures special setting PL scramblin sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLScramblingSequence/Defines the scrambling sequence within a PL frame. 
/// HIPAR PLGoldCodeIndex/Sets the PL Gold Code Index (n).
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2SpecialPLScrambling (ViSession instrSession,
                                                           ViInt32 path,
                                                           ViInt32 PLScramblingSequence,
                                                           ViInt32 PLGoldCodeIndex)
{
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_SPECIAL_PL_SCRAMBLING_SEQUENCE_ID, 
				 PLScramblingSequence), 3, "PL Scrambling Sequence");
	if (PLScramblingSequence == 0)
	{
		viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DVBS2_SPECIAL_PL_GOLD_CODE_INDEX, 
				 PLGoldCodeIndex), 4, "PL Gold Code Index");
	}

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures special setting PL scrambling state.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DVBS2_SPECIAL_PL_SCRAMBLER
/// HIFN     RSBTC_ATTR_DVBS2_SPECIAL_PL_DATASLICES_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]DVBS2[:SPECial]:SCRamble:STATe
/// HIFN     [SOURce<device>:][IQCoder:]DVBS2[:SPECial]:DSLPrbs[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plScrambler/Enables or disables the PL scrambler.
/// HIPAR plDataslicesPRBS/If enabled, inserts PRBS into the data slices.
ViStatus _VI_FUNC rsbtc_ConfigureDVBS2SpecialPLScramblingState(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	plScrambler,
	ViBoolean	plDataslicesPRBS
)
{
    	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_DVBS2_SPECIAL_PL_SCRAMBLER, plScrambler), 3, "PL Scrambler");
	viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_DVBS2_SPECIAL_PL_DATASLICES_PRBS, plDataslicesPRBS), 4, "PL Dataslices PRBS");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Directv Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_STUFFING
/// HIFN     RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:STUFfing
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:TESTsignal TTSP
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the modulation source.
/// HIPAR input/Configures the external input interface. 
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR testSignal/Configures the data signal fed to the modulator.
/// HIPAR stuffing/Displays the stuffing setting.
ViStatus _VI_FUNC rsbtc_ConfigureDIRECTVInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_SOURCE,
                                               source), 3, "Source");
	
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  
	{ 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_INPUT,
                                                input), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  
		{
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_IP_TS_CHANNEL,
                                                ipTSChannel), 5, "IP TS Channel");	
		}
	}
	
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  
	{	
	    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_TEST_SIGNAL,
                                                testSignal), 6, "Test Signal");
	
	}
	
	if ((source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL) || (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_MMGEN))
	{	
        viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_DIRECTV_INPUT_SIGNAL_STUFFING,
                                                 stuffing), 7, "Stuffing");
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_REQ_SOURCE_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_MAXIMUM_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:DIRectv:REQuired[:RATE]?
/// HIFN     READ<hw>[:IQCoder]:DIRectv:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:DIRectv[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:DIRectv:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadDIRECTVInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	switch (dataRate)
	{ 
		 case RSBTC_VAL_REQ_SOURCE_DRATE:
    
         viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_REQ_SOURCE_DATA_RATE,
                                                result), 4, "Result");
		 break;
    
		 case RSBTC_VAL_MAX_USEFUL_DRATE:
			 
		 viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_MAXIMUM_USEFUL_DATA_RATE,
                                                result), 4, "Result");
		 break;
		 
		 case RSBTC_VAL_MEAS_DRATE:
		 
		 viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_MEASURED_DATA_RATE,
                                                result), 4, "Result");	 
		break;
		
		case RSBTC_VAL_USEFUL_DRATE:
			
		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_READ_DIRECTV_INPUT_SIGNAL_USEFUL_DATA_RATE,
                                                result), 4, "Result");	 
		break;
			
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures DIRECTV coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DIRECTV_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_DIRECTV_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:TSPacket H127 | P130
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:PRBS[:SEQuence] P23_1 | P15_1
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/Specifies the structure of the test transport stream packet that is 
/// HIPAR testTSPacket/fed to the modulator.
/// HIPAR prbs/This control defines the period length of the PRBS generator which 
/// HIPAR prbs/fills the payload area of the transport stream packet (test signal), in 
/// HIPAR prbs/compliance with ITU-T O.151.
ViStatus _VI_FUNC rsbtc_ConfigureDIRECTVSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DIRECTV_CONFIGURING_TEST_TS_PACKET,
                                               testTSPacket), 3, "Test TS Packet");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DIRECTV_CONFIGURING_PRBS,
                                               prbs), 4, "PRBS");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Directv coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DIRECTV_CODING_SYMBOL_RATE
/// HIFN     RSBTC_ATTR_DIRECTV_CODING_CONSTELLATION
/// HIFN     RSBTC_ATTR_DIRECTV_CODING_ROLL_OFF
/// HIFN     RSBTC_ATTR_DIRECTV_CODING_CODE_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:SYMBols[:RATE]
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:CONStel
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:ROLLoff
/// HIFN     [SOURce<hw>][:IQCoder]:DIRectv:RATE
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR symbolRate/This control allows setting of the symbol rate.
/// HIPAR constellation/This control sets the constellation of the modulated signal.
/// HIPAR rollOff/Defines the roll-off alpha factor. The output signals are pulse-shaped 
/// HIPAR rollOff/by an FIR filter, yielding a root raised cosine characteristic.
/// HIPAR codeRate/This control defines the puncturing rate of the convolutional coder. 
/// HIPAR codeRate/Since the convolutional coder inserts redundancy into the symbol 
/// HIPAR codeRate/stream, the code rate influences the input data rate.
ViStatus _VI_FUNC rsbtc_ConfigureDIRECTVCoding(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	symbolRate,
	ViInt32	constellation,
	ViInt32	rollOff,
	ViInt32	codeRate
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_DIRECTV_CODING_SYMBOL_RATE,
                                                symbolRate), 3, "Symbol Rate");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DIRECTV_CODING_CONSTELLATION,
                                               constellation), 4, "Constellation");
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DIRECTV_CODING_ROLL_OFF,
                                               rollOff), 5, "Roll Off");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_DIRECTV_CODING_CODE_RATE,
                                               codeRate), 6, "Code Rate");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_DIRECTV_SPECIAL_SETTINGS_STATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:DIR[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableDIRECTVSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_DIRECTV_SPECIAL_SETTINGS_STATE,
                                                 specialSettings), 3, "Special Settings");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Switches the phase noise generator on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR phaseNoise/Enables or diables the phase noise generator.
ViStatus _VI_FUNC rsbtc_EnableDIRECTVPhaseNoise (ViSession instrSession,
                                              ViInt32 path, ViBoolean phaseNoise)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    

	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DIRECTV_PHASE_NOISE, phaseNoise),
                         3, "Phase Noise");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the phase noise generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR CWMode/Disables the modulation and emits a continuous wave signal.
/// HIPAR magnitude/Selects the amplitude of the phase noise generator.
/// HIPAR shape/Selects the amplitude of the phase noise generator.
ViStatus _VI_FUNC rsbtc_ConfigureDIRECTVPhaseNoise (ViSession instrSession,
                                                ViInt32 path, 
												ViBoolean CWMode,
                                                ViInt32 magnitude, 
												ViInt32 shape)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_DIRECTV_PHASE_NOISE_CW_MODE, CWMode),
                         3, "CW Mode");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DIRECTV_PHASE_NOISE_MAGNITUDE, magnitude),
                         4, "Magnitude");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_DIRECTV_PHASE_NOISE_SHAPE, shape),
                         5, "Shape");

	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures T-DMB Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Selects the source of the ETI signal.
/// HIPAR input/Configures the external input interface.
/// HIPAR IPTSChannel/Selects the transport stream that is received over the IP interface.
ViStatus _VI_FUNC rsbtc_ConfigureTDMBInputSignal (ViSession instrSession,
                                                  ViInt32 path, ViInt32 source,
                                                  ViInt32 input,
                                                  ViInt32 IPTSChannel)
{
	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_SOURCE,
                                                 source), 3, "Source");
	
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL) {
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_INPUT,
                                                 input), 4, "Input");
	}	
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL && input == RSBTC_IQC_INPUT_IP)
	{
		
       viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_IP_TS_CHANNEL,
                                                 IPTSChannel), 5, "IP TS Channel"); 
	}
	
Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}

/// HIFN  This function reads Info STC/SSTC parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_SUBCHANNEL_ID
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_PROTECTION_PROFILE
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_PROTECTION_LEVEL
/// HIFN     RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_DATA_RATE
/// HIFN     
/// HIFN    Remote-control command(s):
/// HIFN    READ<hw>[:IQCoder]:TDMB:SCID<1..64>?
/// HIFN    READ<hw>[:IQCoder]:TDMB:PROTection:PROFile<1..64>?
/// HIFN    READ<hw>[:IQCoder]:TDMB:PROTection:LEVel<1..64>??
/// HIFN    READ<hw>[:IQCoder]:TDMB:DATarate<1..64>?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subchannel/This control selects the subchannel.
/// HIPAR subchannelID_Hex/Displays the subchannel identifiers (SCID).
/// HIPAR protectionProfile/Allows a query of the protection profile of the subchannel whose number will be included.
/// HIPAR protectionLevel/Displays the protection level. The displayed levels depend on the setting under 'Protection Profile (3rd column).
/// HIPAR dataRate/Displays the uncoded data rate expressed in the unit kbit/s.
ViStatus _VI_FUNC rsbtc_ReadTDMBInfoSTCSSTC (ViSession instrSession,
                                             ViInt32 path, ViInt32 subchannel,
                                             ViChar subchannelID_Hex[],
                                             ViInt32 *protectionProfile,
                                             ViInt32 *protectionLevel,
                                             ViInt32 *dataRate)
{
	ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	sprintf (rep_cap_1,",S%ld", subchannel);
	strcat (rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_GetAttributeViString (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_SUBCHANNEL_ID, 1024,
                                                 subchannelID_Hex), 4, "Sub Channel ID Hex");
	
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_PROTECTION_PROFILE,
                                                 protectionProfile), 5, "Protection Profile");
	
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_PROTECTION_LEVEL,
                                                 protectionLevel), 6, "Protection Level");
	
	viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_INPUT_SIGNAL_INFO_DATA_RATE,
                                                 dataRate), 7, "Data Rate");
		
		
Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}

/// HIFN  This function configures T-DMB network settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_TDMB_NETWORK_MODE
/// HIFN     RSBTC_ATTR_TDMB_NETWORK_TTI
/// HIFN     RSBTC_ATTR_TDMB_NETWORK_TII_MAIN_ID
/// HIFN     RSBTC_ATTR_TDMB_NETWORK_TII_SUB_ID
/// HIFN     
/// HIFN    Remote-control command(s):
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB:NET
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB:TII:STATe
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB:TII:MAIN
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB:TII:SUB
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR networkMode/Selects the network of the T-DMB/DAB signal.
/// HIPAR TTI/The TII (transmitter identification information) signal is used to identify each individual transmitter.
/// HIPAR TIIMainID/Defines the TII (transmitter identification information) main ID.
/// HIPAR TIISubID/This command allows to set TII Sub ID data.
ViStatus _VI_FUNC rsbtc_TDMBNetworkConfiguration (ViSession instrSession,
                                                  ViInt32 path,
                                                  ViInt32 networkMode,
                                                  ViBoolean TTI,
                                                  ViInt32 TIIMainID,
                                                  ViInt32 TIISubID)
{
	ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_NETWORK_MODE,
                                                 networkMode), 3, "Network Mode");
	
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_NETWORK_TTI,
                                                 TTI), 4, "TTI");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_NETWORK_TII_MAIN_ID,
                                                 TIIMainID), 5, "TII Main ID");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_NETWORK_TII_SUB_ID,
                                                 TIISubID), 6, "TII Sub ID");

	
Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}

	
/// HIFN  This function enables use of special T-DMB coding parameters.
/// HIFN     
/// HIFN    Attribute(s):
/// HIFN    RSBTC_ATTR_TDMB_SPECIAL_SETTINGS
/// HIFN     
/// HIFN    Remote-control command(s):
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableTDMBSpecialSettings (ViSession instrSession,
                                                   ViInt32 path, ViBoolean state)
{
	ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_SPECIAL_SETTINGS,
                                                 state), 3, "State");
Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}

/// HIFN  This function configures special T-DMB coding parameters.
/// HIFN     
/// HIFN    Attribute(s):
/// HIFN    RSBTC_ATTR_TDMB_SPECIAL_TRANSMISSION_MODE
/// HIFN    RSBTC_ATTR_TDMB_SPECIAL_SELECT_TRANSMISSION_MODE
/// HIFN    RSBTC_ATTR_TDMB_SPECIAL_PRBS_TEST_SIGNAL
/// HIFN    RSBTC_ATTR_TDMB_SPECIAL_PRBS_TEST_SIGNAL_SETTINGS
/// HIFN    RSBTC_ATTR_TDMB_SPECIAL_TEST_SIGNAL_SCID
/// HIFN
/// HIFN    Remote-control command(s):
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB[:SPECial]:TRANSmission:MODE
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB[:SPECial]:TRANSmission:MODE:SELect
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB[:SPECial]:TESTsignal[:STATe]
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB:PRBS[:SEQuence]
/// HIFN    [SOURce<hw>][:IQCoder]:TDMB[:SPECial]:TESTsignal:SCID
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR transmissionMode/This control selects between manual setting of the transmission mode or the use of the MID information inside the ETI input datastream to set the transmission mode.
/// HIPAR selectTransmissionMode/Allows the transmission mode to be set manually.
/// HIPAR PRBSTestSignal/Sets PRBS Test Signal.
/// HIPAR PRBSTestSignalSettings/Under "PRBS", select the PRBS test signal that is transmitted in the subchannel.
/// HIPAR testSignalSCID/Selects the subchannel (stream) where a test signal (PRBS) is transmitted instead of data.
ViStatus _VI_FUNC rsbtc_ConfigureTDMBSpecialSettings (ViSession instrSession,
                                                      ViInt32 path,
                                                      ViInt32 transmissionMode,
                                                      ViInt32 selectTransmissionMode,
                                                      ViBoolean PRBSTestSignal,
                                                      ViInt32 PRBSTestSignalSettings,
                                                      ViInt32 testSignalSCID)
{
	ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_SPECIAL_TRANSMISSION_MODE,
                                                 transmissionMode), 3, "Transmission Mode");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_SPECIAL_SELECT_TRANSMISSION_MODE,
                                                 selectTransmissionMode), 4, "Select Transmission Mode");
	
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_SPECIAL_PRBS_TEST_SIGNAL,
                                                 PRBSTestSignal), 5, "PRBSTestSignal");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_SPECIAL_PRBS_TEST_SIGNAL_SETTINGS,
                                                 PRBSTestSignalSettings), 6, "PRBS Test Signal Settings");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_TDMB_SPECIAL_TEST_SIGNAL_SCID,
                                                 testSignalSCID), 7, "Test Signal SC ID");
	
	
Error:
	Rs_UnlockSession(instrSession, NULL);    
	return error;
}

/// HIFN  This function configures ATSC-M/H Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_INPUT
/// HIFN     RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_IP_TS_CHANNEL
/// HIFN     RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_TEST_SIGNAL
/// HIFN     RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_STUFFING
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:SOURce
/// HIFN     [SOURce<hw>][:IQCoder]:INPut
/// HIFN     [SOURce<hw>][:IQCoder]:INPut:TSCHannel
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:STUFfing
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:TESTsignal
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/This control selects the signal source for the ATSC-M/H coder.
/// HIPAR input/Configures the external input interface. 
/// HIPAR ipTSChannel/Selects the transport stream that is received over the IP interface
/// HIPAR stuffing/Sets the stuffing.
/// HIPAR testSignal/This control selects the signal source for the coder.
ViStatus _VI_FUNC rsbtc_ConfigureATSCMHInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	input,
	ViInt32	ipTSChannel,
	ViInt32	testSignal,
	ViBoolean	stuffing)
{
    ViStatus	error = VI_SUCCESS;  
	ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (input == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		
		if (input == RSBTC_IQC_INPUT_IP)  {
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
	                                               ), 5, "IP TS Channel");		
			}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
	 	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,  
                                               RSBTC_ATTR_ATSCMH_INPUT_SIGNAL_STUFFING, stuffing
                                               ), 7, "Stuffing");			
	
 
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_ATSCMH_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_ATSCMH_INPUT_SIGNAL_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_ATSCMH_INPUT_SIGNAL_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<hw>[:IQCoder]:ATSM:USEFul[:RATE]:MAX?
/// HIFN     READ<hw>[:IQCoder]:ATSM[:INPut]:DATarate?
/// HIFN     READ<hw>[:IQCoder]:ATSM:USEFul[:RATE]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
ViStatus _VI_FUNC rsbtc_ReadATSCMHInputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
   switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:															
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ATSCMH_INPUT_SIGNAL_MAX_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ATSCMH_INPUT_SIGNAL_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ATSCMH_INPUT_SIGNAL_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 

   }
  Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures ATSC-M/H coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSCMH_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_ATSCMH_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_ATSCMH_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_ATSCMH_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_ATSCMH_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:TSPacket
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:PIDTestpack
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:PID
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:PAYLoad
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control specifies the structure of the test transport stream 
/// HIPAR testTSPacket/packet that is fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR payloadTestStuff/This control allows selection of the payload in the TS packets of the 
/// HIPAR payloadTestStuff/ATSCMH signal.
/// HIPAR prbs/This control sets the PRBS to be used.
ViStatus _VI_FUNC rsbtc_ConfigureATSCMHSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSCMH_CONFIGURING_TEST_TS_PACKET,
                                                testTSPacket), 3, "Test TS Packet");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSCMH_CONFIGURING_PID_TEST_PACKET,
                                               pidTestPacket), 4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSCMH_CONFIGURING_PID,
                                                pid), 5, "PID");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ATSCMH_CONFIGURING_PAYLOAD_TEST_STUFF,
                                                 payloadTestStuff), 6, "Payload Test/Stuff");
	
	if(payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS)
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ATSCMH_CONFIGURING_PRBS,
                                                 prbs), 7, "PRBS");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures network settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_MHE_PID
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_RF_WATERMARK
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_TX_ADDRESS
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_ID
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_BURY_RATIO
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:MHEPid
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:WATermark
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:TX:ADDRess
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:NETWork:ID
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:BURY:RATio
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR rfWatermark/Enables or disables the RF watermark. The ATSC A/110B standard 
/// HIPAR rfWatermark/specifies that the RF signal can be overlayed with a watermark. For 
/// HIPAR rfWatermark/this purpose, the modulator calculates a specific Kasami sequence from 
/// HIPAR rfWatermark/the TX address and the network ID. This sequence modulates BPSK and is 
/// HIPAR rfWatermark/added to the payload signal as buried spread spectrum. Thus, a unique 
/// HIPAR rfWatermark/watermark is provided for each transmitter.
/// HIPAR txAddress/This control sets the Tx address for the watermark.
/// HIPAR networkID/This control sets the network ID of the watermark.
/// HIPAR buryRatio/This control sets the power of the watermark. 
/// HIPAR mhePID/Determines the PID of the MPEG2 packets that contain M/H data. Since 
/// HIPAR mhePID/these packets must be treated separately in the postprocessor, the 
/// HIPAR mhePID/correct specification is essential. This is an important parameter for 
/// HIPAR mhePID/the M/H transmission.
ViStatus _VI_FUNC rsbtc_ConfigureATSCMHNetworkSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mhePID,
	ViBoolean	rfWatermark,
	ViInt32	txAddress,
	ViInt32	networkID,
	ViInt32	buryRatio
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSCMH_CODING_NETWORK_MHE_PID,
                                                mhePID), 3, "MHE PID");
	
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSCMH_CODING_NETWORK_RF_WATERMARK,
                                               rfWatermark), 4, "RF Watermark");
	
	if (rfWatermark == VI_TRUE) {
	    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                                RSBTC_ATTR_ATSCMH_CODING_NETWORK_TX_ADDRESS,
	                                                txAddress), 5, "TX Address");
	
	    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                                 RSBTC_ATTR_ATSCMH_CODING_NETWORK_ID,
	                                                 networkID), 6, "Network ID");
	
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                                 RSBTC_ATTR_ATSCMH_CODING_NETWORK_BURY_RATIO,
	                                                 buryRatio), 7, "Bury Ratio");
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures ATSC-M/H MTXID Transmission parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_MTXID_TRANSMISSION
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORK_TRANSMITTER_ID
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_NETWORKMARKET_ID
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:MTXid:TRANsmission
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:MTXid:TID
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:MTXid:MID
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mtxIDTransmission/Enables or disables the MTXID transmission. The transmission of the 
/// HIPAR mtxIDTransmission/MTXID in the frame sync signal is a technique for detecting the 
/// HIPAR mtxIDTransmission/respective transmitter that is complementary to the RF watermark 
/// HIPAR mtxIDTransmission/technique. The MTXID comprises the transmitter ID and the market ID. 
/// HIPAR mtxIDTransmission/The main advantage of this method is that the error vector of the 
/// HIPAR mtxIDTransmission/useful signal is not enlarged. Furthermore, the information transmitted 
/// HIPAR mtxIDTransmission/in this case is to be used for highly accurate position-finding.
/// HIPAR transmitterID/This control sets the transmitter ID for the MTXID transmission.
/// HIPAR marketID/This control sets the market ID for the transmission. 
ViStatus _VI_FUNC rsbtc_ConfigureATSCMHMTXIDTransmission(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	mtxIDTransmission,
	ViInt32	transmitterID,
	ViInt32	marketID
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSCMH_CODING_NETWORK_MTXID_TRANSMISSION,
                                                mtxIDTransmission), 3, "MTX ID Transmission");
	if (mtxIDTransmission == VI_TRUE)
	{
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSCMH_CODING_NETWORK_TRANSMITTER_ID,
                                               transmitterID), 4, "Transmitter ID");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSCMH_CODING_NETWORK_MARKET_ID,
                                                marketID), 5, "Market ID");
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures ATSC-M/H coding parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_MH_STATE
/// HIFN     RSBTC_ATTR_ATSCMH_CODING_SYMBOL_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:MHSTate
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM:SYMBols[:RATE]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR symbolRate/This control allows setting of the symbol rate.
/// HIPAR mhState/Enables or disables all ATSC-M/H elements of the FEC together.
ViStatus _VI_FUNC rsbtc_ConfigureATSCMHCodingParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	symbolRate,
	ViBoolean	mhState
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSCMH_CODING_SYMBOL_RATE,
                                                symbolRate), 3, "Symbol Rate");
	
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_ATSCMH_CODING_MH_STATE,
                                                 mhState), 4, "MH State");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function enables or disables all special settings. This is useful 
/// HIFN  if you want to quickly switch back to a standard-compliant channel 
/// HIFN  coding without losing your customized special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSCMH_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>][:IQCoder]:ATSM[:SPECial]:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableATSCMHSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_ATSCMH_SPECIAL_SETTINGS,
                                                 state), 3, "State");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*****************************************************************************
 *--------------------------------- ATSC 3.0 --------------------------------*
 *****************************************************************************/

/// HIFN  This function enables or disables the studio to transmitter link (STL) 
/// HIFN  interface.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STL_INTERFACE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:STL:INTerface
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR stlInterface/Enables or disables the studio to transmitter link (STL) interface.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3STLInterface(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	stlInterface
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STL_INTERFACE, stlInterface), 3, "STL Interface");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function sets channel bandwidth.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_OFDM_CHANNEL_BANDWIDTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:CHANnel[:BANDwidth]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR channelBandwidth/A fixed channel bandwidth of 6 MHz is set. 
ViStatus _VI_FUNC rsbtc_ConfigureATSC3ChannelBandwidth(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	channelBandwidth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_OFDM_CHANNEL_BANDWIDTH, channelBandwidth), 3, "Channel Bandwidth");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  Queries the status information.
/// HIFN     
/// HIFN     Attribute:
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STATUS_INFO
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:STATus?
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR bufferSize/Sets the size of memory allocated for Status Info.
/// HIPAR statusInfo/Queries the status information.
ViStatus _VI_FUNC rsbtc_GetATSC3StatusInfo (ViSession instrSession,
                                                 ViInt32 path,
                                                 ViInt32 bufferSize,
                                                 ViChar statusInfo[])
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
        
    viCheckParm (rsbtc_GetAttributeViString(instrSession, rep_cap,
                                               RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STATUS_INFO, bufferSize, statusInfo), 
											   4, "Status Info");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures ATSC 3.0 PLP ID.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_PLP_ID
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:ID
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR plpID/Sets the PLP ID.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3PLPID(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	plpID
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_plp[15] = "";
					  
    checkErr (Rs_LockSession (instrSession, NULL));

	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_PLP_ID, plpID), 4, "PLP ID");	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}	
			 
/// HIFN  This function configures ATSC 3.0 Input Signal parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_CONFORMANCE_CHECK
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STL_INTERFACE
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_DESTINATION_IP_ADDRESS
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_DESTINATION_IP_PORT
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_INPUT_TYPE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:CCHeck
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:STL:INTerface
/// HIFN     [SOURce<device>:][IQCoder:]SOURce[:HIGH]
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:DESTination:IP:ADDRess
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:DESTination:IP:PORT
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:TYPE
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR conformanceCheck/Conformance Check.
/// HIPAR source/This control selects the signal source for the ATSC-M/H coder.
/// HIPAR destinationIPAddress/Sets the destination IP address of the IP connection.
/// HIPAR destinationIPPort/Sets the destination UDP port of the connection.
/// HIPAR inputType/Specifies the input type.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3InputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	conformanceCheck,
	ViInt32	source,
	ViString	destinationIPAddress,
	ViInt32	destinationIPPort,
	ViInt32	inputType
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
        
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_CONFORMANCE_CHECK, conformanceCheck), 3, "Conformance Check");
		
		
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_SOURCE, source), 4, "Source");

	if (source != RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST) {
	
	    viCheckParm(rsbtc_SetAttributeViString(instrSession, rep_cap,
	        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_DESTINATION_IP_ADDRESS, destinationIPAddress), 5, "Destination IP Address");
		
		
	    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
	        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_DESTINATION_IP_PORT, destinationIPPort), 6, "Destination IP Port");
		
		
	    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
	        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_INPUT_TYPE, inputType), 7, "Input Type");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the type of test signal.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_PLP_TEST_SIGNAL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:INPut:TESTsignal?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR testSignal/Sets the type of test signal.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3InputTestSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	testSignal
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_PLP_TEST_SIGNAL, testSignal), 4, "Test Signal");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function resets the log file.
/// HIFN     
/// HIFN     Attribute:
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STL_RESET_LOG_FILE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:STL:RESetlog
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
ViStatus _VI_FUNC rsbtc_ResetATSC3InputSignalLogFile(
	ViSession	instrSession,
	ViInt32	path
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
      
    viCheckParm(rsbtc_SetAttributeViString(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_STL_RESET_LOG_FILE, NULL), 3, "Reset Log File");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the number of PLPs in the frame.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_NUMBER_OF_PLPS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:NPLP?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfPLPs/This control returns the number of PLPs in the frame.
ViStatus _VI_FUNC rsbtc_ReadATSC3InputSignalNumberOfPLP(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	*numberOfPLPs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_GetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ATSC3_INPUT_SIGNAL_NUMBER_OF_PLPS,
                                            numberOfPLPs), 3, "Number Of PLPs");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;

}


/// HIFN  This function queries the packet length of the external transport 
/// HIFN  stream.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_PACKET_LENGTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<device>[:IQCoder]:A3TSc:PLP<plp>:PACKetlength?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR packetLength/Queries the packet length of the external transport stream.
ViStatus _VI_FUNC rsbtc_ReadATSC3InputSignalPacketLength(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32*	packetLength
)
{
   ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_PACKET_LENGTH, packetLength), 4, "Packet Length");
		
    checkErr (rsbtc_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the used protocol.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_INPUT_PROTOCOL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INPut:PROTocol?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR protocol/This control returns the used protocol.
ViStatus _VI_FUNC rsbtc_ReadATSC3InputSignalProtocol(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	protocol
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";  
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_INPUT_PROTOCOL, protocol), 3, "Protocol");
		Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function reads selected data rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_MAX_USEFUL_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_MEASURED_DATA_RATE
/// HIFN     RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_USEFUL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     READ<device>[:IQCoder]:A3TSc:PLP<plp>:USEFul[:RATE]:MAX?
/// HIFN     READ<device>[:IQCoder]:A3TSc:PLP<plp>[:INPut]:DATarate?
/// HIFN     READ<device>[:IQCoder]:A3TSc:PLP<plp>:USEFul[:RATE]?
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected data rate value [Mbit/s].
/// HIPAR plp/This control selects the PLP number.
ViStatus _VI_FUNC rsbtc_ReadATSC3InputSignalDataRate(
	ViSession	instrSession,
	ViInt32	path,	ViInt32	plp, 
	ViInt32	dataRate,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_plp[15] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_plp);
	
   switch (dataRate){
        case RSBTC_VAL_MAX_USEFUL_DRATE:															
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_MAX_USEFUL_DATA_RATE, 
	            result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_MEASURED_DATA_RATE, 
                result), 4, "Result");
        break;
		case RSBTC_VAL_USEFUL_DRATE:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ATSC3_INPUT_SIGNAL_PLP_USEFUL_DATA_RATE, 
                result), 4, "Result");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Data Rate"); 
   }
  Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
  
/// HIFN  This function configures ATSC-M/H coding settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_CONFIGURING_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_ATSC3_CONFIGURING_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_ATSC3_CONFIGURING_TEST_IP_PACKET
/// HIFN     RSBTC_ATTR_ATSC3_CONFIGURING_PID
/// HIFN     RSBTC_ATTR_ATSC3_CONFIGURING_PAYLOAD_TEST_STUFF
/// HIFN     RSBTC_ATTR_ATSC3_CONFIGURING_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:TSPacket
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PIDTestpack
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:IPPacket
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PID
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PAYLoad
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/This control specifies the structure of the test transport stream 
/// HIPAR testTSPacket/packet that is fed to the modulator.
/// HIPAR pidTestPacket/Specifies the PID, if a header was set for the test TS packet, that 
/// HIPAR pidTestPacket/means if "Head/184 Payload" is set under "Test TS Packet".
/// HIPAR pid/This control sets PID for a variable test packet.
/// HIPAR testIPPacket/Specifies the structure of the test IP packet that is fed to the 
/// HIPAR testIPPacket/modulator.
/// HIPAR payloadTest/Stuff/This control allows selection of the payload in the TS packets of the 
/// HIPAR payloadTest/Stuff/ATSC3.0 signal.
/// HIPAR prbs/This control sets the PRBS to be used.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3Settings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	ipTestPacket,
	ViInt32	pid,
	ViInt32	payloadTestStuff,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSC3_CONFIGURING_TEST_TS_PACKET,
                                                testTSPacket), 3, "Test TS Packet");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSC3_CONFIGURING_PID_TEST_PACKET,
                                               pidTestPacket), 4, "PID Test Packet");
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_ATSC3_CONFIGURING_TEST_IP_PACKET,
                                               ipTestPacket), 5, "IP Test Packet");

	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_ATSC3_CONFIGURING_PID,
                                                pid), 6, "PID");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ATSC3_CONFIGURING_PAYLOAD_TEST_STUFF,
                                                 payloadTestStuff), 7, "Payload Test/Stuff");
	
	if(payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS)
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_ATSC3_CONFIGURING_PRBS,
                                                 prbs), 8, "PRBS");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures parameters for encapsulating and formatting 
/// HIFN  that are defined by the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_ENCAPS_BB_FRAME_COUNTER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:BBFCounter
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR bbFrameCounter/Enables or disables the baseband frame counter.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3EncapsAndFormat(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViBoolean	bbFrameCounter
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

	viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_ENCAPS_BB_FRAME_COUNTER, bbFrameCounter), 3, "BB Frame Counter");
		
    checkErr (rsbtc_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function returns parameters for encapsulating and formatting that 
/// HIFN  are defined by the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_INPUT_SIGNAL_PLP_ID
/// HIFN     RSBTC_ATTR_ATSC3_ALP_ENCAPSULATION_TYPE
/// HIFN     RSBTC_ATTR_ATSC3_ENCAPS_BB_FRAME_PADDING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:ID?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:ALPType?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:BBFPadding?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR plpID/Displays the value from "PLP ID"
/// HIPAR alpEncapsulationType/Displays the input source type of the ALP encapsulation, either a 
/// HIPAR alpEncapsulationType/transport stream or an IP stream.
/// HIPAR bbFramePadding/Queries whether baseband frame padding is used.
ViStatus _VI_FUNC rsbtc_ReadATSC3EncapsAndFormat(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32*	plpID,
	ViInt32*	alpEncapsulationType,
	ViBoolean*	bbFramePadding
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_INPUT_SIGNAL_PLP_ID, plpID), 4, "PLP ID");
		
		
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_ALP_ENCAPSULATION_TYPE, alpEncapsulationType), 5, "ALP Encapsulation Type");
		

	viCheckParm(rsbtc_GetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_ENCAPS_BB_FRAME_PADDING, bbFramePadding), 6, "BB Frame Padding");
		
    checkErr (rsbtc_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures ATSC 3.0 Bit Interleaved Coding and 
/// HIFN  Modulation subitem parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_FEC_TYPE
/// HIFN     RSBTC_ATTR_ATSC3_BICM_CODE_RATE
/// HIFN     RSBTC_ATTR_ATSC3_BICM_CONSTELLATION
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:FECType
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:RATE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:CONStel
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR fecType/Defines the forward error correction (FEC) used for encoding.
/// HIPAR constellation/Defines the constellation.
/// HIPAR codeRate/Sets the code rate.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3BICMParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	fecType,
	ViInt32	codeRate,	
	ViInt32	constellation
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_FEC_TYPE, fecType), 4, "FEC Type");
		
		
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_CODE_RATE, codeRate), 5, "Code Rate");
		
		
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_CONSTELLATION, constellation), 6, "Constellation");
		
    checkErr (rsbtc_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads ATSC 3.0 Bit Interleaved Coding and Modulation 
/// HIFN  subitem parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_LOW_LEVEL_SIGNALING
/// HIFN     RSBTC_ATTR_ATSC3_BICM_LAYER
/// HIFN     RSBTC_ATTR_ATSC3_BICM_LDM_INJECTION_LEVEL
/// HIFN     RSBTC_ATTR_ATSC3_BICM_SIZE
/// HIFN     RSBTC_ATTR_ATSC3_BICM_SCRAMBLER_TYPE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:LLS?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:LAYer:LAYer?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:LAYer:LEVel?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:SIZE?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:SCRambler?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR lowLevelSignaling/Queries whether low-level signaling is present.
/// HIPAR layer/Displays which layer is used in layered division multiplexing (LDM).
/// HIPAR ldmInjectionLevel/Displays the enhanced layer injection levels relative to the core PLP 
/// HIPAR ldmInjectionLevel/in dB.
/// HIPAR size/Displays the number of data cells allocated to the PLP.
/// HIPAR scramblerType/Fixed setting. Further scrambler types are reserved for future use.
ViStatus _VI_FUNC rsbtc_ReadATSC3BICMParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32*	lowLevelSignaling,
	ViInt32*	layer,
	ViInt32*	ldmInjectionLevel,
	ViInt32*	size,
	ViInt32*	scramblerType
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_LOW_LEVEL_SIGNALING, lowLevelSignaling), 3, "Low Level Signaling");
		
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_LAYER, layer), 4, "Layer");
		
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_LDM_INJECTION_LEVEL, ldmInjectionLevel), 5, "LDM Injection Level");
		
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_SIZE, size), 6, "Size");
		
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_SCRAMBLER_TYPE, scramblerType), 7, "Scrambler Type");
    checkErr (rsbtc_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures subslice parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_SUBSLICING_TYPE
/// HIFN     RSBTC_ATTR_ATSC3_BICM_NUMBER_OF_SUBSLICES
/// HIFN     RSBTC_ATTR_ATSC3_BICM_SUBSLICE_INTERVAL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TYPE:TYPE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TYPE:NSUBslices
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TYPE:SUBSlice[:
/// HIFN     INTerval]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR type/Defines the PLP type if the PLP is not an LDM enhanced layer.
/// HIPAR subsliceInterval/Defines the difference between the lowest data cell index allocated to 
/// HIPAR subsliceInterval/a subslice and the highest data cell index allocated to the immediately 
/// HIPAR subsliceInterval/preceding subslice within a dispersed PLP.
/// HIPAR numberOfSubslices/Defines the number of subslices for a dispersed PLP.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3BICMSubslicing(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	type,
	ViInt32	numberOfSubslices,
	ViInt32	subsliceInterval
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_SUBSLICING_TYPE, type), 4, "Subslicing Type");
		
	if (type == RSBTC_VAL_ATSC3_BICM_TYPE_DISPERSED) {
		viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
		        RSBTC_ATTR_ATSC3_BICM_NUMBER_OF_SUBSLICES, numberOfSubslices), 5, "Number Of Subslices");
		
	    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
		        RSBTC_ATTR_ATSC3_BICM_SUBSLICE_INTERVAL, subsliceInterval), 6, "Subslice Interval");
	}		
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures Interleaved Coding and Modulation subitem 
/// HIFN  parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_MODE
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_DEPTH
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_NUMBER_OF_TI_BLOCKS
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_CELL_INTERLEAVER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:TIL
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:DEPTh
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:NTIBlocks
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:CIL
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR timeInterleaverMode/Sets the time interleaver mode.
/// HIPAR depth/Defines the time interleaving depths.
/// HIPAR numberOfTIBlocks/The behavior depends on the setting under "Inter Subframe"
/// HIPAR cellInterleaver/Enables or disables the interleaver operating at the cell level.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3BICMTimeInterleaver(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32	timeInterleaverMode,
	ViInt32	depth,
	ViInt32	numberOfTIBlocks,
	ViBoolean	cellInterleaver
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_MODE, timeInterleaverMode), 4, "Time Interleaver Mode");
		
   	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_DEPTH, depth), 5, "Depth");
		
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_NUMBER_OF_TI_BLOCKS, numberOfTIBlocks),6, "Number Of TI Blocks");
		
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_CELL_INTERLEAVER, cellInterleaver), 7, "Cell Interleaver");
		
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures interleaving frame content and mapping.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTER_SUBFRAME
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:INTer
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR interSubframe/Defines the interleaving frame content and mapping.
	ViStatus _VI_FUNC rsbtc_ConfigureATSC3BICMInterSubframe(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViBoolean	interSubframe
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTER_SUBFRAME, interSubframe), 4, "Time Inter Subframe");
		
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Interleaved Coding and Modulation subitem 
/// HIFN  parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_EXTENDED_INTERLEAVING
/// HIFN     
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) Only available if:
/// HIFN     - CTI or HTI is set under "Time Interleaver Mode"
/// HIFN     
/// HIFN     - QPSK is set under "Constellation"
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:EXTended
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control selects the PLP number.
/// HIPAR extendedInterleaving/If enabled, increases the time interleaving depth.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3BICMExtendedInterleaving(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViBoolean	extendedInterleaving
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_EXTENDED_INTERLEAVING, extendedInterleaving), 4, "Extended Interleaving");
		
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function displays the number of forward error correction (FEC) 
/// HIFN  blocks contained in the current interleaving frame and 
/// HIFN     the maximum number of forward error correction (FEC) blocks per 
/// HIFN  interleaving frame
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_NUMBER_OF_FEC_BLOCKS
/// HIFN     RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_MAX_NUMBER_OF_FEC_BLOCKS
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) Only available if "HTI" is set under "Time Interleaver Mode"
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:BLOCks?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PLP<plp>:TIL:MAXBlocks?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR plp/This control sets the PLP number (NPLP = 1: single PLP).
/// HIPAR numberOfFECBlocks/Displays the number of forward error correction (FEC) blocks contained 
/// HIPAR numberOfFECBlocks/in the current interleaving frame.
/// HIPAR maxNumberOfFECBlocks/Displays the maximum number of forward error correction (FEC) blocks 
/// HIPAR maxNumberOfFECBlocks/per interleaving frame.
ViStatus _VI_FUNC rsbtc_ReadATSC3BICMNumberOfFECBlocks(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	plp,
	ViInt32*	maxNumberOfFECBlocks,
	ViInt32*	numberOfFECBlocks
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_plp[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3plpRepCap (instrSession, plp, rep_cap_plp)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_plp);

    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_NUMBER_OF_FEC_BLOCKS, numberOfFECBlocks), 4, "Number Of FEC Blocks");
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_BICM_TIME_INTERLEAVER_MAX_NUMBER_OF_FEC_BLOCKS, maxNumberOfFECBlocks), 5, "Max Number Of FEC Blocks");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures the framing and OFDM parameters that are 
/// HIFN  defined by the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_MISO
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_FFT_SIZE
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_REDUCED_CARRIER_MODE
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_TOTAL_NUMBER_OF_DATA_OFDM_SYMBOLS
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_BOUNDARY_SYMBOL_FIRST
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_FREQUENCY_INTERLEAVER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:MISO
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:FFT:MODE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:CARRier:MODE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:GUARd:INTerval
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:NDATa
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:SBS:FIRSt
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:FIL
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subframe/This control sets the subframe number.
/// HIPAR miso/Defines the multiple inputs and single output (MISO) option.
/// HIPAR fftSize/Sets the FFT size.
/// HIPAR reducedCarrierMode/Sets a coefficient for reducing the maximum number of carriers. The 
/// HIPAR reducedCarrierMode/coefficient is multiplied by a control unit value that depends on the 
/// HIPAR reducedCarrierMode/FFT size used for the subframe. The resulting number is subtracted from 
/// HIPAR reducedCarrierMode/the maximum number of carriers.
/// HIPAR guardInterval/Sets the guard interval length used for the OFDM symbols.
/// HIPAR totalNumbOfDataOFDMSymbos/Sets the number of data symbols per subframe, including the subframe 
/// HIPAR totalNumbOfDataOFDMSymbos/boundary symbols, excluding the preamble OFDM symbols
/// HIPAR firstSubframeBoundarySymbol/Defines whether the first symbol of a subframe is a subframe boundary 
/// HIPAR firstSubframeBoundarySymbol/symbol.
/// HIPAR frequencyInterleaver/Enables or disables the frequency interleaver.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SubframingOFDMParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subframe,
	ViInt32	miso,
	ViInt32	fftSize,
	ViInt32	reducedCarrierMode,
	ViInt32	guardInterval,
	ViInt32	totalNumbOfDataOFDMSymbos,
	ViInt32	firstSubframeBoundarySymbol,
	ViBoolean frequencyInterleaver
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_subframe[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3SubfRepCap (instrSession, subframe, rep_cap_subframe)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_subframe);

	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_MISO, miso), 4, "MISO");

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_FFT_SIZE, fftSize), 5, "FFT Size");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_REDUCED_CARRIER_MODE, reducedCarrierMode), 6, "Reduced Carrier Mode");

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_GUARD_INTERVAL, guardInterval), 7, "Guard Interval");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_TOTAL_NUMBER_OF_DATA_OFDM_SYMBOLS, totalNumbOfDataOFDMSymbos), 8, "Total Number Of Data OFDM Symbols");

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
       RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_BOUNDARY_SYMBOL_FIRST, firstSubframeBoundarySymbol), 9, "Boundary Symbol First");
	
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_FREQUENCY_INTERLEAVER, frequencyInterleaver), 10, "Frequency Interleaver");
	

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the framing and OFDM pilot parameters that 
/// HIFN  are defined by the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SISO_PILOT_PATTERN
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_PILOT_BOOST_MODE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:PILot:SISO
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:PILot:BOOSt
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subframe/This control sets the subframe number.
/// HIPAR sisoPilotPattern/Sets the scattered pilot pattern for single input and single output 
/// HIPAR sisoPilotPattern/(SISO).
/// HIPAR pilotBoostMode/Sets the power boost mode for the scattered pilots.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SubframingOFDMPilot(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subframe,
	ViInt32	sisoPilotPattern,
	ViInt32	pilotBoostMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_subframe[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3SubfRepCap (instrSession, subframe, rep_cap_subframe)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_subframe);

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SISO_PILOT_PATTERN, sisoPilotPattern), 3, "SISO Pilot Pattern");    
    
	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_PILOT_BOOST_MODE, pilotBoostMode), 4, "Pilot Boost Mode");	
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries whether multiple input and multiple output 
/// HIFN  (MIMO) are used.
/// HIFN     
/// HIFN     Attribute:
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_MIMO
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:MIMO?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subframe/This control sets the subframe number.
/// HIPAR mimo/Queries whether multiple input and multiple output (MIMO) are used.
ViStatus _VI_FUNC rsbtc_ReadATSC3SubframingOFDMMIMO(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subframe,
	ViBoolean*	mimo
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_subframe[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3SubfRepCap (instrSession, subframe, rep_cap_subframe)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_subframe);

	viCheckParm(rsbtc_GetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_MIMO, mimo), 4, "MIMO");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function queries whether the last symbol of a subframe is a 
/// HIFN  subframe boundary symbol and number of null cells in the subframe 
/// HIFN  boundary symbols.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_BOUNDARY_SYMBOL_LAST
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_BOUNDARY_SYMBOL_NULL_CELLS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:SBS:LAST?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:SBS:NULL?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subframe/This control sets the subframe number.
/// HIPAR subframeBoundarySymbol_Last/Queries whether the last symbol of a subframe is a subframe boundary 
/// HIPAR subframeBoundarySymbol_Last/symbol.
/// HIPAR boundarySymbol_NullCells/Queries the number of null cells in the subframe boundary symbols.
ViStatus _VI_FUNC rsbtc_ReadATSC3SubframingOFDMBoundarySymbol(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subframe,
	ViInt32*	subframeBoundarySymbolLast,
	ViInt32*	boundarySymbolNullCells
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_subframe[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3SubfRepCap (instrSession, subframe, rep_cap_subframe)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_subframe);

    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_BOUNDARY_SYMBOL_LAST, subframeBoundarySymbolLast), 4, "Subframe Boundary Symbol Last");
	   
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_SUBFRAME_BOUNDARY_SYMBOL_NULL_CELLS, boundarySymbolNullCells), 5, "Boundary Symbol Null Cells");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function returns the duration of the subframe and the used 
/// HIFN  bandwidth.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) Bandwidth depending on the following:
/// HIFN     - Channel Bandwidth
/// HIFN     - FFT Size
/// HIFN     - Reduced Carrier Mode
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_USED_BANDWIDTH
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_DURATION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:DURation?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:USED[:BANDwidth]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subframe/This control sets the subframe number.
/// HIPAR duration/Queries the duration of the subframe.
/// HIPAR usedBandwidth/Queries the used bandwidth.
ViStatus _VI_FUNC rsbtc_ReadATSC3SubframingOFDMUsedBandwidth(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subframe,
	ViReal64*	duration,
	ViReal64*	usedBandwidth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_subframe[15] = ""; 		
		
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3SubfRepCap (instrSession, subframe, rep_cap_subframe)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_subframe);

		
	viCheckParm(rsbtc_GetAttributeViReal64(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_DURATION, duration), 4, "Duration");
		  
    viCheckParm(rsbtc_GetAttributeViReal64(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_USED_BANDWIDTH, usedBandwidth), 5, "Used Bandwidth");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function returns the number of PLPs and PLPs mapped to the 
/// HIFN  subframe.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) If "Off" is set under "STL Interface", the number of PLPs is 
/// HIFN  restricted to "1". Therefore, only one PLP ID is displayed.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_NUMBER_OF_PLPS_IN_SUBFRAME
/// HIFN     RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_PLP_IDS_IN_SUBFRAME
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:PLP:NPLP?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SUBFrame<subf>:PLP:NIDPlp?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subframe/This control sets the subframe number.
/// HIPAR numberofPLPsinSubframe/Queries the number of PLPs in the subframe.
/// HIPAR plpIDsinSubframe/Queries all IDs of the PLPs mapped to the subframe.
ViStatus _VI_FUNC rsbtc_ReadATSC3SubframingOFDMPLPs(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subframe,
	ViInt32*	numberofPLPsinSubframe,
	ViInt32 bufferSize,
	ViChar	plpIDsinSubframe[]
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";  
	ViChar	rep_cap_subframe[15] = ""; 		
																
    checkErr (Rs_LockSession (instrSession, NULL));   
	
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	checkErr(rsbtc_A3SubfRepCap (instrSession, subframe, rep_cap_subframe)); 
	
	strcat (rep_cap, ",");
	strcat (rep_cap, rep_cap_subframe);

		
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_NUMBER_OF_PLPS_IN_SUBFRAME, numberofPLPsinSubframe), 4, "Number Of PLPs In Subframe");
		  
    viCheckParm(rsbtc_GetAttributeViString(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SUBFRAMING_OFDM_PLP_IDS_IN_SUBFRAME, bufferSize, plpIDsinSubframe), 6, "PLP IDs In Subframe");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures the network parameters that are defined by 
/// HIFN  the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_MODE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TIME_INFO
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:NETWorkmode
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:TIME
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR timeInfo/Configures the time information.
/// HIPAR numberofTransmitters_NTX/Sets the number of transmitters for MISO transmission.
/// HIPAR transmitterIndex_x/Sets the transmitter index for MISO transmission.
/// HIPAR txidMode/Controls the setting of TxID Address and TxID Injection Level.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SystemNetworkParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	networkMode,
	ViInt32	timeInfo)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_MODE, networkMode), 3, "Mode");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TIME_INFO, timeInfo), 4, "Time Info");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the network MISO parameters that are defined 
/// HIFN  by the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_NUMBER_OF_TRANSMITTERS
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TRANSMITTER_INDEX
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:MISO:NTX
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:MISO:IDX
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberofTransmitters_NTX/Sets the number of transmitters for MISO tr
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SystemNetworkMISOParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberofTransmittersNTX,
	ViInt32	transmitterIndexX
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_NUMBER_OF_TRANSMITTERS, numberofTransmittersNTX), 3, "Number Of Transmitters");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TRANSMITTER_INDEX, transmitterIndexX), 4, "Transmitter Index");	

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the TxID network parameters that are defined 
/// HIFN  by the standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TXID_MODE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TXID_ADDRESS
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TXID_INJECTION_LEVEL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:TXID:MODE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:TXID:ADDRess
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:TXID:LEVel
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR txidMode/Controls the setting of TxID Address and TxID Injection Level.
/// HIPAR txidAddress/Sets the transmitter identification address.
/// HIPAR txidInjectionLevel/Sets the injection level for injecting the TxID signal into the host 
/// HIPAR txidInjectionLevel/preamble. The TxID injection level is defined by the dB values.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SystemNetworkTxID(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	txidMode,
	ViInt32	txidAddress,
	ViInt32	txidInjectionLevel
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TXID_MODE, txidMode), 3, "TxID Mode");
	
	if (txidMode != RSBTC_VAL_ATSC3_SYSTEM_TXID_OFF) {
    	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TXID_ADDRESS, txidAddress), 4, "TxID Address");
		
		if (txidMode ==  RSBTC_VAL_ATSC3_SYSTEM_TXID_MANUAL) {
	    	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        	RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_TXID_INJECTION_LEVEL, txidInjectionLevel), 5, "TxID Injection Level");
		}
	}
		
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures the ID of the broadcast stream.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) Only available if a value > 0 is set under "L1 Detail Version".
/// HIFN     
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_BROADCAST_STREAM_ID
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:BSID
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR broadcastStreamID/Sets the ID of the broadcast stream. Only available if a value > 0 is 
/// HIPAR broadcastStreamID/set under L1 Detail Version
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SystemNetworkBroadcastStreamID(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	broadcastStreamID
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
       viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_BROADCAST_STREAM_ID, broadcastStreamID), 3, "Broadcast Stream ID");
	   
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries whether parameters are present in the system.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_LOW_LEVEL_SIGNALING
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_RETURN_CHANNEL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:LLS?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:RETurn[:CHANnel]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR lowLevelSignaling/Displays whether low-level signaling is present in the system.
/// HIPAR returnChannel/Queries whether a dedicated return channel (DRC) is present.
ViStatus _VI_FUNC rsbtc_ReadATSC3SystemNetwork(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	lowLevelSignaling,
	ViInt32*	returnChannel
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_LOW_LEVEL_SIGNALING, lowLevelSignaling), 3, "Low Level Signaling");
    
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_NETWORK_RETURN_CHANNEL, returnChannel), 4, "Return Channel");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures the frame parameters that are defined by the 
/// HIFN  standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_PEAK_TO_AVERAGE_POWER_RATIO
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_MODE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_LENGTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:PAPR
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:MODE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:LENGth
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR frameLength/Sets the time period measured from the beginning of the first sample 
/// HIPAR frameLength/of the bootstrap to the end of the final sample of the frame. The 
/// HIPAR frameLength/resolution is 5 ms.
/// HIPAR peakToAveragePowerRatio/Sets the technique to reduce the peak-to-average power ratio within 
/// HIPAR peakToAveragePowerRatio/the frame.
/// HIPAR frameMode/Sets how the frame length is aligned.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SystemFrameParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	peakToAveragePowerRatio,
	ViInt32	frameMode,
	ViInt32	frameLength)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_PEAK_TO_AVERAGE_POWER_RATIO, peakToAveragePowerRatio), 3, "Peak To Average Power Ratio");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_MODE, frameMode), 4, "Frame Mode");
	
	if (frameMode == RSBTC_VAL_ATSC3_SYSTEM_FRAME_MODE_TIME) {
    	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_LENGTH, frameLength), 5, "Frame Length");
	}
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the frame parameters that are defined by the 
/// HIFN  standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_EXCESS_SAMPLES_PER_SYMBOL
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_FINAL_EXCESS_SAMPLES
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:EXSYmbol?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:EXFinal?
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR excessSamplesperSymbol/Queries the additional number of excess samples included in the guard 
/// HIPAR excessSamplesperSymbol/interval of each non-preamble OFDM symbol of the post-bootstrap 
/// HIPAR excessSamplesperSymbol/portion.
/// HIPAR finalExcessSamples/Queries the excess samples that are inserted immediately following the 
/// HIPAR finalExcessSamples/final OFDM symbol of the final subframe.
ViStatus _VI_FUNC rsbtc_ReadATSC3SystemFrameTimeParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	excessSamplesperSymbol,
	ViInt32*	finalExcessSamples
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_EXCESS_SAMPLES_PER_SYMBOL, excessSamplesperSymbol), 3, "Excess Samples Per Symbol");
	    
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_FINAL_EXCESS_SAMPLES, finalExcessSamples), 4, "Final Excess Samples");
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function queries the frame parameters that are defined by the 
/// HIFN  standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_TIME_OFFSET
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_FRAME_ADDITIONAL_SAMPLES
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:TIME[:OFFSet]?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:ADDitional[:SAMPles]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR timeOffset/Queries the number of sample periods between the nearest preceding or 
/// HIPAR timeOffset/coincident millisecond boundary and the leading edge of the frame.
/// HIPAR additionalSamples/Queries the number of additional samples added at the end of a frame 
/// HIPAR additionalSamples/to facilitate sampling clock alignment.
ViStatus _VI_FUNC rsbtc_ReadATSC3SystemFrameSymbolParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	timeOffset,
	ViInt32*	additionalSamples
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
  
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_TIME_OFFSET, timeOffset), 3, "Time Offset");	    
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_FRAME_ADDITIONAL_SAMPLES, additionalSamples), 3, "Additional Samples");
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the number of subframes present within the 
/// HIFN  current frame.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_NUMBER_OF_SUBFRAMES
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:FRAMe:NSUBframes?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfSubframes/Displays the number of subframes present within the current frame.
ViStatus _VI_FUNC rsbtc_ReadATSC3SystemNumberOfSubframes(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	numberOfSubframes
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
  
  	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_NUMBER_OF_SUBFRAMES, numberOfSubframes), 3, "Number Of Subframes");
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

     
/// HIFN  This function queries the version of the L1 basic signaling structure 
/// HIFN  that is used for the current frame.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_BASIC_VERSION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:BASic:VERSion?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR l1BasicVersion/Queries the version of the L1 basic signaling structure that is used 
/// HIPAR l1BasicVersion/for the current frame.
ViStatus _VI_FUNC rsbtc_ReadATSC3SystemL1BasicVersion(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	l1BasicVersion
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
  
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_BASIC_VERSION, l1BasicVersion), 3, "AL1 Basic Version");
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures the L1 parameters that are defined by the 
/// HIFN  standard.
/// HIFN     
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_BASIC_FEC_TYPE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_REDUCED_CARRIER_MODE_PREAMBLE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_PILOT_PATTERN_DX_PREAMBLE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_DETAIL_VERSION
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_DETAIL_FEC_TYPE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:BASic:FECType
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:CARRier:MODE
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:PILot:DX
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:DETail:VERSion
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:DETail:FECType
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR l1BasicFECType/Sets the protection level of L1 basic signaling.
/// HIPAR reducedCarrierModePreamble/Sets a coefficient for reducing the maximum number of carriers.
/// HIPAR pilotPattern_DxPreamble/Sets the pilot pattern used for the preamble symbols.
/// HIPAR l1DetailVersion/Sets the version of the L1 detail signaling structure that is used for 
/// HIPAR l1DetailVersion/the current frame.
/// HIPAR l1DetailFECType/Sets the protection level of L1 detail signaling.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SystemL1Parameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	l1BasicFECType,
	ViInt32	reducedCarrierModePreamble,
	ViInt32	pilotPatternDxPreamble,
	ViInt32	l1DetailVersion,
	ViInt32	l1DetailFECType
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_BASIC_FEC_TYPE, l1BasicFECType), 3, "L1 Basic FEC Type");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_REDUCED_CARRIER_MODE_PREAMBLE, reducedCarrierModePreamble), 4, "L1 Reduced Carrier Mode Preamble");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_PILOT_PATTERN_DX_PREAMBLE, pilotPatternDxPreamble), 5, "L1 Pilot Pattern Dx Preamble");
	
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_DETAIL_VERSION, l1DetailVersion), 6, "L1 Detail Version");
	
    viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_DETAIL_FEC_TYPE, l1DetailFECType), 7, "L1 Detail FEC Type");
Error:	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the L1 parameters that are defined by the 
/// HIFN  standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_NUMBER_OF_PREAMBLE_SYMBOLS
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_DETAIL_ADDITIONAL_PARITY_MODE
/// HIFN     RSBTC_ATTR_ATSC3_SYSTEM_L1_NUMBER_OF_RFS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:NPReamble[:SYMBols]?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:L:DETail:ADDitional[:PARity]?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:NRF?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfPreambleSymbols/Queries the total number of OFDM symbols contained within the 
/// HIPAR l1NumberOfPreambleSymbols/preamble.
/// HIPAR l1DetailAdditParityMode/If enabled, additional parity bits for the L1 detail signaling of the 
/// HIPAR l1DetailAdditParityMode/current frame are transmitted in the closest (in time) previous frame 
/// HIPAR l1DetailAdditParityMode/that has the same bootstrap major/ minor version.
/// HIPAR numberofRFs/Displays the number of radio frequencies involved in channel bonding. 
ViStatus _VI_FUNC rsbtc_ReadATSC3SystemL1Parameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	numberOfPreambleSymbols,
	ViInt32*	l1DetailAdditParityMode,
	ViInt32*	numberofRFs
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
  
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_NUMBER_OF_PREAMBLE_SYMBOLS, numberOfPreambleSymbols), 3, "Number Of Preamble Symbols");
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_DETAIL_ADDITIONAL_PARITY_MODE, l1DetailAdditParityMode), 4, "Detail Additional Parity Mode");
	
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SYSTEM_L1_NUMBER_OF_RFS, numberofRFs), 5, "Number of RFs");
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the frame duration.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_FRAME_DURATION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:FRAMe:DURation?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR frameDuration/Displays the frame duration.
ViStatus _VI_FUNC rsbtc_ReadATSC3FrameInfoFrameDuration(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64*	frameDuration
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm(rsbtc_GetAttributeViReal64(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_FRAME_DURATION, frameDuration), 3, "Frame Duration");  

Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the signaling length parameters of the common 
/// HIFN  layer 1 (L1).
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_L1_BASIC_BYTES
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_L1_BASIC_CELLS
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_L1_DETAIL_BYTES
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_L1_DETAIL_CELLS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:L:BASic:BYTes?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:L:BASic:CELLs?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:L:DETail:BYTes?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:L:DETail:CELLs?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR l1BasicBytes/Queries the L1 basic signaling length.
/// HIPAR l1BasicCells/Queries the L1 basic signaling length.
/// HIPAR l1DetailBytes/Queries the L1 detail signaling length.
/// HIPAR l1DetailCells/Queries the L1 detail signaling length.
ViStatus _VI_FUNC rsbtc_ReadATSC3FrameInfoL1SignalingParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	l1BasicBytes,
	ViInt32*	l1BasicCells,
	ViInt32*	l1DetailBytes,
	ViInt32*	l1DetailCells
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_L1_BASIC_BYTES, l1BasicBytes), 3, "L1 Basic Bytes");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_L1_BASIC_CELLS, l1BasicCells), 4, "L1 Basic Cells");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_L1_DETAIL_BYTES, l1DetailBytes), 5, "L1 Detail Bytes");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_L1_DETAIL_CELLS, l1DetailCells), 6, "L1 Detail Cells");
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function queries the parameters that characterize the bootstrap 
/// HIFN  signal. The bootstrap signals the information for identifying and 
/// HIFN  initial decoding of the associated signal.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_DURATION
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_EMERGENCY_ALERT_SIGNALING
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_MIN_TIME_TO_NEXT
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_SYSTEM_BANDWIDTH
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_BSR_COEFFICIENT
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_STRUCTURE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:DURation?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:EAS?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:TIME:NEXT?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:BANDwidth?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:BSR:COEFficient?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:PREamble[:STRucture]?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR bootstrapDuration/Queries the duration of the bootstrap signal.
/// HIPAR emergencyAlertSignaling/Queries the signaling for emergency alert.
/// HIPAR minTimetoNext/Queries minimum time interval to the next frame that matches the same 
/// HIPAR minTimetoNext/major and minor version number of the current frame.
/// HIPAR systemBandwidth/Queries the system bandwidth used for the post-bootstrap portion of 
/// HIPAR systemBandwidth/the current physical layer frame.
/// HIPAR bsrCoefficient/Queries the sample rate used for the post-bootstrap portion of the 
/// HIPAR bsrCoefficient/current physical layer frame.
/// HIPAR preambleStructure/Queries the structure of the preamble symbols following the last 
/// HIPAR preambleStructure/bootstrap symbol.
ViStatus _VI_FUNC rsbtc_ReadATSC3FrameInfoBootstrapParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64*	bootstrapDuration,
	ViInt32*	emergencyAlertSignaling,
	ViInt32*	minTimetoNext,
	ViInt32*	systemBandwidth,
	ViInt32*	bsrCoefficient,
	ViInt32*	preambleStructure
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
    viCheckParm(rsbtc_GetAttributeViReal64(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_DURATION, bootstrapDuration), 3, "Bootstrap Duration");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_EMERGENCY_ALERT_SIGNALING, emergencyAlertSignaling), 4, "Emergency Alert Signaling");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_MIN_TIME_TO_NEXT, minTimetoNext), 5, "Min Time to Next");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_SYSTEM_BANDWIDTH, systemBandwidth), 6, "System Bandwidth");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_BSR_COEFFICIENT, bsrCoefficient), 7, "BSR Coefficient");
	
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_STRUCTURE, preambleStructure), 8, "Preamble Structure");
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function queries major and minor version number of the bootstrap.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_MAJOR_VERSION
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_MINOR_VERSION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:MAJor?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:MINor?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR majorVersion/Queries the major version number of the bootstrap.
/// HIPAR minorVersion/Queries the minor version number of the bootstrap.
ViStatus _VI_FUNC rsbtc_ReadATSC3FrameInfoBootstrapVersion(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	majorVersion,
	ViInt32*	minorVersion
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_MAJOR_VERSION, majorVersion), 3, "Major Version");	

	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_MINOR_VERSION, minorVersion), 4, "Minor Version");	

Error:																	  
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function queries the parameters that characterize the bootstrap 
/// HIFN  signal. The bootstrap signals the information for identifying and 
/// HIFN  initial decoding of the associated signal.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_FFT_SIZE
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_GUARD_INTERVAL
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_PILOT_PATTERN_DX
/// HIFN     RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_L1_BASIC_FEC_TYPE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:FFT:MODE?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:GUARd:INTerval?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:PILot:DX?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:INFO:BOOTstrap:BASic:FECType?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fftSize/Queries the FFT size of the preamble symbols.
/// HIPAR guardInterval/Queries the number of guard interval samples of the preamble symbols.
/// HIPAR pilotPattern_Dx/Queries the pilot pattern used for the preamble symbols.
/// HIPAR l1BasicFECType/Queries the FEC type used for the L1 basic signaling in the preamble 
/// HIPAR l1BasicFECType/symbol.
ViStatus _VI_FUNC rsbtc_ReadATSC3FrameInfoBootstrapPreambleParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32*	fftSize,
	ViInt32*	guardInterval,
	ViInt32*	pilotPattern_Dx,
	ViInt32*	l1BasicFECType
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_FFT_SIZE, fftSize), 3, "FFT Size");
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_GUARD_INTERVAL, guardInterval), 4, "Guard Interval");
	
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_PILOT_PATTERN_DX, pilotPattern_Dx), 5, "Pilot Pattern Dx");
	
    viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_FRAME_INFO_BOOTSTRAP_PREAMBLE_L1_BASIC_FEC_TYPE, l1BasicFECType), 6, "L1 Basic FEC Type");
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the SFN parameters that are defined by the 
/// HIFN  standard.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SFN_MUTE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:MUTE[:BOOTstrap]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mute/
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SFNMute(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	mute
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SFN_MUTE, mute), 3, "Mute");
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries selected delay value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SFN_MAX_DEVIATION_TIME
/// HIFN     RSBTC_ATTR_ATSC3_SFN_STATIC_DELAY
/// HIFN     RSBTC_ATTR_ATSC3_SFN_PROCESSING_DELAY
/// HIFN     RSBTC_ATTR_ATSC3_SFN_DYNAMIC_DELAY
/// HIFN     RSBTC_ATTR_ATSC3_SFN_TOTAL_DELAY
/// HIFN     RSBTC_ATTR_ATSC3_SFN_NETWORK_DELAY
/// HIFN     RSBTC_ATTR_ATSC3_SFN_NETWORK_DELAY_JITTER
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:DEViation?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:STATic?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:PROCess?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:DYNamic?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:TOTal?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:NETWork?
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:DELay:DEJitter?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR delayParameter/Selects the delay parameter.
/// HIPAR timeValue/This control returns the selected delay value, if the modulator 
/// HIPAR timeValue/operates in SFN network mode.
ViStatus _VI_FUNC rsbtc_ReadATSC3SFNDelayParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	delayParameter,
	ViReal64*	timeValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	switch (delayParameter){
        case RSBTC_VAL_ATSC3_SFN_MAX_DEVIATION_TIME:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_MAX_DEVIATION_TIME, 
	            timeValue), 4, "Time Value");
        break;
		  
		case RSBTC_VAL_ATSC3_SFN_STATIC_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_STATIC_DELAY, 
	            timeValue), 4, "Time Value");
        break;
			
		case RSBTC_VAL_ATSC3_SFN_DYNAMIC_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_DYNAMIC_DELAY, 
	            timeValue), 4, "Time Value");
        break;
				  
		case RSBTC_VAL_ATSC3_SFN_TOTAL_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_TOTAL_DELAY, 
	            timeValue), 4, "Time Value");
        break;
		
		case RSBTC_VAL_ATSC3_SFN_PROCESS_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_PROCESSING_DELAY, 
	            timeValue), 4, "Time Value");
        break;
		
		case RSBTC_VAL_ATSC3_SFN_NETWORK_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_NETWORK_DELAY, 
	            timeValue), 4, "Time Value");
        break;

		case RSBTC_VAL_ATSC3_SFN_JITTER_DELAY:
    		viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_ATSC3_SFN_NETWORK_DELAY_JITTER, 
	            timeValue), 4, "Time Value");
        break;


		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Delay Parameter"); 
	}
  Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function enables or disables all special settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SPECIAL_SETTINGS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SPECial:SETTings[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables the special settings.
ViStatus _VI_FUNC rsbtc_EnableATSC3SpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SPECIAL_SETTINGS, state), 3, "State");
	
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures the compatibility mode.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SPECIAL_PREAMBLE_COMPATIBILITY_MODE
/// HIFN     RSBTC_ATTR_ATSC3_SPECIAL_TMP_COMPATIBILITY_MODE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SPECial:STL:PREamble
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SPECial:STL:TMP
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR preambleCompatibilityMode/This control sets the preamble compatibility mode.
/// HIPAR tmpCompatibilityMode/This control sets the TMP compatibility mode. 
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SpecialSTLInterface(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	preambleCompatibilityMode,
	ViBoolean	tmpCompatibilityMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SPECIAL_PREAMBLE_COMPATIBILITY_MODE, preambleCompatibilityMode), 3, "Preamble Compatibility Mode");
   
	viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SPECIAL_TMP_COMPATIBILITY_MODE, tmpCompatibilityMode), 4, "TMP Compatibility Mode");	

Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the special bootstrap parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SPECIAL_BOOTSTRAP_MINOR_VERSION
/// HIFN     RSBTC_ATTR_ATSC3_SPECIAL_BOOTSTRAP_EMERGENCY_ALERT_SIGNALING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SPECial:BOOTstrap:MINor
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SPECial:BOOTstrap:EAS
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR minorVersion/Sets the minor version number of the bootstrap.
/// HIPAR emergencyAlertSignaling/Sets the signaling for emergency alert.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SpecialBootstrap(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	minorVersion,
	ViInt32	emergencyAlertSignaling
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
     viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SPECIAL_BOOTSTRAP_MINOR_VERSION, minorVersion), 3, "Minor Version");

	viCheckParm(rsbtc_SetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SPECIAL_BOOTSTRAP_EMERGENCY_ALERT_SIGNALING, emergencyAlertSignaling), 4, "Emergency Alert Signaling");
		 
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the LMP compatibility mode.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ATSC3_SPECIAL_LMT_COMPATIBILITY_MODE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]A3TSc:SPECial:ALP:LMT
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR lmtCompatibilityMode/This control sets the LMP compatibility mode.
ViStatus _VI_FUNC rsbtc_ConfigureATSC3SpecialALPEncapsulation(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	lmtCompatibilityMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_ATSC3_SPECIAL_LMT_COMPATIBILITY_MODE, lmtCompatibilityMode), 3, "LMT Compatibility Mode");
		 
Error:																	   
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*****************************************************************************
 *--------------------------------- ISDB-Tmm --------------------------------*
 *****************************************************************************/
 /*============================================================================/
 * Function: Configure ISDBTmm Input Signal
 * Purpose:  This function configures ISDBTmm Input Signal parameters.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureISDBTmmInputSignal (ViSession instrSession,
											  ViInt32	path,
                                              ViInt32 layer, ViInt32 source,
                                              ViInt32 input, 	ViInt32	ipTSChannel,
											  ViInt32 testSignal, ViBoolean stuffing)
{
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_segLayer[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_segLayerRepCap (instrSession, layer, rep_cap_segLayer));    

	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_segLayer);

     viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_INPUT_SIGNAL_SOURCE, source), 
                    4, "Source"); 

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
   		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap_path, RSBTC_ATTR_ISDBTMM_INPUT_SIGNAL_INPUT, input), 
                    5, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap_path,
                                               RSBTC_ATTR_ISDBTMM_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 6, "IP TS Channel");		
		}
	}
   
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST){   
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap_path, RSBTC_ATTR_ISDBTMM_INPUT_SIGNAL_TEST_SIGNAL, testSignal), 
                    7, "Test Signal"); 
		}
	
		else   {
    	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap_path, RSBTC_ATTR_ISDBTMM_INPUT_SIGNAL_STUFFING, stuffing), 
                    8, "Stuffing");  
}
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
} 


/*============================================================================/
 * Function: Read ISDBTmm Input SignalData Rate
 * Purpose:  This function reads selected coding value.
/============================================================================*/ 
ViStatus _VI_FUNC rsbtc_ReadISDBTmmInputSignalDataRate (ViSession instrSession,
													ViInt32	path, ViInt32 layer,
                                         ViInt32 value, ViReal64* result)
{
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_segLayer[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_segLayerRepCap (instrSession, layer, rep_cap_segLayer));    

	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_segLayer);


    if ((layer < RSBTC_VAL_IQC_ISDBTMM_LAYER_A1A) || (layer > RSBTC_VAL_IQC_ISDBTMM_LAYER_B7))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Layer"); 

     
    if ((value < RSBTC_VAL_MAX_USEFUL_DRATE) || (value > RSBTC_VAL_MAX_USEFUL_DRATE))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Value");


    if (!result) viCheckParm (RS_ERROR_INVALID_PARAMETER, 5, "Result");
    
    switch (value){ 
        
        case RSBTC_VAL_MAX_USEFUL_DRATE:
            viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_ISDBTMM_MAX_USEFUL_DATA_RATE,
            result), 4, "Result");                 
        break;                                                    
    }
   
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
} 

/*============================================================================/
 * Function: Configure ISDBTmm Coding Parameters
 * Purpose:  This function configures ISDB-Tmm coding parameters.
/============================================================================*/    
ViStatus _VI_FUNC rsbtc_ConfigureISDBTmmCodingParameters (ViSession instrSession,
											      	    ViInt32	path, 	
	        											ViInt32 control, 
	        											  ViInt32 coder,
                                                          ViBoolean partialReception,
                                                          ViInt32 numberSuperSegments)
{    
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap[15] = "";
	ViChar	rep_cap_2[10] = "";   	

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));

    sprintf (rep_cap_2, ",A%ld", coder);
	strcpy (rep_cap, rep_cap_path); 
	strcat (rep_cap, rep_cap_2);


   
    if ((coder < RSBTC_VAL_IQC_TMM_RECEPTION_CODER_A1) || (coder > RSBTC_VAL_IQC_TMM_RECEPTION_CODER_A2))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Coder"); 
   
      
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap_path, RSBTC_ATTR_ISDBTMM_CODING_CONTROL,
    				control), 3, "Control");
    if (control == RSBTC_VAL_IQC_CONTROL_MODE_MANUAL) {
	
    	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_PARTIAL_RECEPTION, 
				partialReception), 4, "Partial Reception");
  
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap_path, RSBTC_ATTR_ISDBTMM_CODING_NUMBER_OF_SUPER_SEGMENTS,
    				numberSuperSegments), 5, "Number Super Segments");				  
	}
	
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/*============================================================================/
 * Function: Configure ISDBTmm Coding Segment Parameters
 * Purpose:  This function configures the ISDB-Tmm segment-specific
 *           parameters.
/============================================================================*/    
ViStatus _VI_FUNC rsbtc_ConfigureISDBTmmCodingSegmentParameters
             (ViSession instrSession, 
				ViInt32	path, ViInt32 superSegments,
              ViInt32 superSegmentsType, ViInt32 numSegments)
{    
    ViStatus    error = VI_SUCCESS;
	ViChar	    rep_cap[20] = "";
	ViChar		rep_cap_2[10] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (superSegments, 1, 5), 3, "Super Segment");
    
    sprintf (rep_cap_2, ",SSG%ld", superSegments);
	
	strcat (rep_cap, rep_cap_2);
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_SUPER_SEGMENTS_TYPE,
    				superSegmentsType), 4, "Super Segments Type");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_NUMBER_SEGMENTS,
    				numSegments), 5, "Num Segments");				  
  
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*============================================================================/
 * Function: Configure ISDBTmm Coding Layer Parameters
 * Purpose:  This function configures the ISDB-Tmm layer-specific parameters.
/============================================================================*/    
ViStatus _VI_FUNC rsbtc_ConfigureISDBTmmCodingLayerParameters
             (ViSession instrSession,
			ViInt32	path, ViInt32 layer,
              ViInt32 OFDMSegments, ViInt32 centerSubchannel, ViInt32 constellation,
              ViInt32 codeRate, ViInt32 timeInterleaving)
{    
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap[15] = ""; 
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_segLayer[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_segLayerRepCap (instrSession, layer, rep_cap_segLayer));    

	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_segLayer);

  
    if (layer < RSBTC_VAL_IQC_ISDBTMM_LAYER_B1) {  
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_LAYER_OFDM_SEGMENTS,
    				OFDMSegments), 4, "OFDM Segments");
	}
	
	if (layer >= RSBTC_VAL_IQC_ISDBTMM_LAYER_B1) {    
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_LAYER_CENTER_SUBCHANNEL,
    				centerSubchannel), 5, "Center Subchannel");
	}
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_LAYER_CONSTELLATION,
    				constellation), 6, "Constellation");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_LAYER_CODE_RATE,
    				codeRate), 6, "Code Rate");
	
	 if ((layer < RSBTC_VAL_IQC_ISDBTMM_LAYER_A1A) || (layer > RSBTC_VAL_IQC_ISDBTMM_LAYER_A2C)) {
	 	if (timeInterleaving  == RSBTC_VAL_IQC_ISDBT_TIME_INTER_32 )
        	viCheckParm( RS_ERROR_INVALID_PARAMETER, 7, "Time Interleaving"); 
	 }
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_LAYER_TIME_INTERLEAVING,
    				timeInterleaving), 7, "Time Interleaving");
  
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*============================================================================/
 * Function: Configure ISDBTmm Coding
 * Purpose:  This function configures ISDB-Tmm coding parameters.
/============================================================================*/    
ViStatus _VI_FUNC rsbtc_ConfigureISDBTmmCoding (ViSession instrSession,
												ViInt32	path, 
                                                ViBoolean emergencyAlarm,
                                                ViInt32 ISDBTMode,
                                                ViInt32 guardInterval,
                                                ViInt32 referenceChannel)
{    
    ViStatus    error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
   
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_EMERGENCY_ALARM, 
				emergencyAlarm), 3, "Emergency Alarm");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_ISDBT_MODE,
    				ISDBTMode), 4, "ISDBT Mode");				  
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_GUARD_INTERVAL,
    				guardInterval), 5, "Guard Interval");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CODING_REFERENCE_CHANNEL,
    				referenceChannel), 6, "Reference Channel");
  
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/*============================================================================/
 * Function: Enable ISDBTmm Special Settings
 * Purpose:  This function enables use of special ISDBTmm coding parameters.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_EnableISDBTmmSpecialSettings (ViSession instrSession,
													ViInt32	path, 
                                               ViBoolean state)
{
    ViStatus    error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_SPECIAL_SETTINGS, state),
                         3, "State");
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}                                               


    
  
/*============================================================================/
 * Function: Configure ISDBTmm Settings
 * Purpose:  This function configures ISDBTmm coding settings.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_confISDBTmmSettings (ViSession instrSession,
											ViInt32	path, 	
                                           ViInt32 testTSPacket,
                                           ViInt32 pidTestPacket, ViInt32 pid,
                                           ViInt32 payloadTestStuff, ViInt32 prbs)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CONFIGURING_TEST_TS_PACKET, testTSPacket),
                         3, "Test TS Packet");
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CONFIGURING_PID_TEST_PACKET, pidTestPacket),
			                         4, "PID Test Packet");
	
	if  (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE)
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CONFIGURING_PID, pid),
				                         5, "PID"); 

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CONFIGURING_PAYLOAD_TEST_TS_PACKET, payloadTestStuff),
		                         6, "Payload Test Stuff"); 
  
	if  (payloadTestStuff == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_ISDBTMM_CONFIGURING_PRBS, prbs),
								 7, "PRBS"); 

Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
 

/*****************************************************************************
 *----------------------------- CMMB ----------------------------------------*
 *****************************************************************************/

/*============================================================================/
 * Function: Configure CMMB Input Signal
 * Purpose:  This function configures CMMB Input Signal parameters.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureCMMBInputSignal(ViSession instrSession,
                                                  ViInt32 path, ViInt32 source,
                                                  ViInt32 input,
                                                  ViInt32 ipTSChannel,
                                                  ViInt32 testSignal,
                                                  ViBoolean stuffing)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_CMMB_INPUT_SIGNAL_SOURCE, source
                                               ), 3, "Source");

	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_EXTERNAL)  { 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_CMMB_INPUT_SIGNAL_INPUT, input
                                               ), 4, "Input");
		if (input == RSBTC_IQC_INPUT_IP)  {
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_CMMB_INPUT_SIGNAL_IP_TS_CHANNEL, ipTSChannel
                                               ), 5, "IP TS Channel");		
		}
	}
			   		
	if (source == RSBTC_VAL_DTV_SIGNAL_SOURCE_TEST)  {  
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                               RSBTC_ATTR_CMMB_INPUT_SIGNAL_TEST_SIGNAL, testSignal
	     										   ), 6, "Test Signal");  
	}
	else
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
		                                               RSBTC_ATTR_CMMB_INPUT_SIGNAL_STUFFING, stuffing
		                                               ), 7, "stuffing");	
Error:
	
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*============================================================================/
 * Function: Read CMMB Values
 * Purpose:  This function reads selected coding value.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ReadCMMBInputSignalDataRate(ViSession instrSession, ViInt32	path,
                                        ViInt32 value,
                                        ViReal64* result)
{
    ViStatus    error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    switch (value){                                                       
        case RSBTC_VAL_REQ_SOURCE_DRATE:
            viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_CMMB_MEASURED_REQUIRED_DATA_RATE,
                                                     result), 4, "Result");
        break;
        case RSBTC_VAL_MEAS_DRATE:
            viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_READ_CMMB_MEASURED_DATA_RATE,
                                                     result), 4, "Result");
        break;
    	default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Value");  
	}           
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/*============================================================================/
 * Function: Configure CMMB Coding
 * Purpose:  This function configures CMMB coding parameters.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureCMMBCoding (ViSession instrSession, ViInt32	path,
                                        ViInt32 control, ViInt32 bandwidth) 

{
    ViStatus    error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_CMMB_CODING_CONTROL, control),
                         3, "Control");
	
    if (control == RSBTC_VAL_IQC_CONTROL_MODE_MANUAL)
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_CMMB_CODING_BANDWIDTH, bandwidth),
                         4, "Bandwidth");
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}                                         



/*============================================================================/
 * Function: Configure CMMB PLCH Table
 * Purpose:  This function configures CMMB coding PLCH table parameters.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureCMMBPLCHTable(ViSession instrSession, ViInt32	path, ViInt32 PLCH,
                                           ViInt32 RS, ViInt32 byteIL, ViInt32 LDPC,
                                           ViInt32 constel, ViInt32 SCRMode,
                                           ViInt32 startTS, ViInt32 stopTS)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
  
    if (Rs_Simulating(instrSession) == 0){                /* call only when locked */
   
	if ((PLCH < 0) || (PLCH > 39))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "PLCH");
	
	if ((RS < RSBTC_VAL_IQC_CMMB_RS_0) || (RS > RSBTC_VAL_IQC_CMMB_RS_3))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "RS");
        
    if ((byteIL < 1) || (byteIL > 3))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 5, "Byte IL");     
    
    if ((LDPC < RSBTC_VAL_IQC_CMMB_LDPC_R1_2) || (LDPC > RSBTC_VAL_IQC_CMMB_LDPC_R3_4))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 6, "LDPC");     

	if ((constel < RSBTC_VAL_IQC_CMMB_CONST_C2) || (constel > RSBTC_VAL_IQC_CMMB_CONST_C16))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 7, "Constel");   
	
	if ((SCRMode < 0) || (SCRMode > 7))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 8, "SCR Mode");
	
	if ((startTS < 0) || (startTS > 39))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 9, "Start TS");  
		
	if ((stopTS < 0) || (stopTS > 39))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 10, "Stop TS");  
		
    sprintf (buffer,"SOUR%ld:CMMB:RS %ld,%s;BYIM %ld,%ld;LDPC %ld,%s;CONS %ld,%s;SCRM %ld,%ld;STAR %ld,%ld;STOP %ld,%ld\n",
		path,
		PLCH,cmmbPlchRsArr[RS],PLCH,byteIL,
		PLCH,cmmbPlchLdpdArr[LDPC],
		PLCH,cmmbPlchConstArr[constel],PLCH,SCRMode,
		PLCH,startTS,PLCH,stopTS);
  
	viCheckErr( viPrintf (instrSession, "%s", buffer));  
    }   
    
    viCheckErr(rsbtc_CheckStatus (instrSession));    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
} 
  

/*============================================================================/
 * Function: Enable CMMB Special Settings
 * Purpose:  This function enables use of special AVSB coding parameters.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_EnableCMMBSpecialSettings(ViSession instrSession, ViInt32 path,
                                             ViBoolean state)
{
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_CMMB_SPECIAL_SETTINGS_STATE, state),
                         3, "State");
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

  
/*============================================================================/
 * Function: Configure CMMB Settings
 * Purpose:  This function configures CMMB coding settings.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureCMMBSettings (ViSession instrSession, ViInt32 path,
                                          ViInt32 transmitterID, ViInt32 areaID,
                                          ViInt32 payloadTestSignal, ViInt32 PRBS)
{
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));


    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_CMMB_CONFIGURING_TRANSMITTER_ID, transmitterID),
                         3, "Transmitter ID");
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_CMMB_CONFIGURING_AREA_ID, areaID),
                         4, "Area ID"); 
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_CMMB_CONFIGURING_PAYLOAD_TEST_SIGNAL, payloadTestSignal),
                         5, "Payload Test Signal"); 
    switch (payloadTestSignal){
        case  RSBTC_VAL_DTV_PAYLOAD_PRBS:
            viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_CMMB_CONFIGURING_PRBS, PRBS),
                         6, "PRBS"); 
    }   
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}







/// HIFN  This function configures the parameters for the vision signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR visionPicture/Vision Picture defines a test pattern.
/// HIPAR videoInputSignal/This control selects the video source.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvVideo(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	videoInputSignal,
	ViInt32	visionPicture
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_VIDEO_INPUT_SIGNAL,
                                            videoInputSignal), 3, "Video Input Signal");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_VIDEO_VISION_PICTURE,
                                            visionPicture), 4, "Vision Picture");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects the video file. 
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) If the file is not in the default path, the path must be specified 
/// HIFN  at the same time. If no file of the specified name exists, it is 
/// HIFN  created. The file extension may be omitted. Only files with the file 
/// HIFN  extension *.CCVS will be created or loaded.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR loadLibrary/This control selects the video pattern. Only available if From ATV 
/// HIPAR loadLibrary/Video Lib is selected in rsbtc_ConfigureAnalogTvVideo.
ViStatus _VI_FUNC rsbtc_LoadAnalogTvVideoLibrary(
	ViSession	instrSession,
	ViInt32	path,
	ViString	loadLibrary
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_VIDEO_LOAD_FILE,
                                             loadLibrary), 3, "Load Library");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads out the files in the default directory. 
/// HIFN     The default directory is set with the command MMEM:CDIRectory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_AnalogTvVideoLibraryCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory));
    
    viCheckErr( viPrintf(instrSession, "SOUR%ld:IQC:RATV:VIDG:LIBR:CAT?\n", path));
    
    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) 
    {
        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
        strncpy(output, pbuffer, len);
        output[len] = '\0';
    }
    
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function reads out the number of files in the default directory 
/// HIFN  (D:\ATVVIDEOLIB).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR catalogLength/This control reads out the number of files in the default directory.
ViStatus _VI_FUNC rsbtc_AnalogTvVideoLibraryCatalogLength(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32*	catalogLength
)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Catalog Length");
    
    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
        
    sprintf (buffer,"SOUR%ld:IQC:RATV:VIDG:LIBR:CAT:LENG?\n", path);
    
    viCheckErr( viQueryf (instrSession, buffer, "%ld", catalogLength));
    
    viCheckErr(rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function selects the audio source. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR audioInputSignal/Selects the audio signal source.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvAudioInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	audioInputSignal
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_AUDIO_INPUT_SIGNAL,
                                            audioInputSignal), 3, "Audio Input Signal");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function switches audio source 1 or 2 ON or OFF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR audioSource/This control selects the audio source to be set.
/// HIPAR state/This control switches the selected audio source to ON or OFF.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvAudioAF(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	audioSource,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_ANALOG_TV_AUDIO_AF_1, RSBTC_ATTR_ANALOG_TV_AUDIO_AF_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (audioSource, RSBTC_VAL_ATV_AUDIO_GEN_AF1, RSBTC_VAL_ATV_AUDIO_GEN_AF2), 3, "Audio Source");
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              attr[audioSource],
                                              state), 4, "State");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures analog TV audio parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR frequencyParameter/This control selects the parameter to be set. Depends on the selected 
/// HIPAR frequencyParameter/SOUND MODE.
/// HIPAR frequencyValue/Sets the AF frequency value of selected parameter.
/// HIPAR levelParameter/This control selects the parameter to be set .Depends on the selected 
/// HIPAR levelParameter/SOUND MODE.
/// HIPAR levelValue/Sets the AF level value of selected parameter.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvAudio(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	frequencyParameter,
	ViReal64	frequencyValue,
	ViInt32	levelParameter,
	ViReal64	levelValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      freq_attr[] = {RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_FREQUENCY_SOUND_MONO,
							   RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_FREQUENCY_SOUND_LEFT,
							   RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_FREQUENCY_SOUND_RIGHT,
							   RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_FREQUENCY_SOUND_CHANNEL_1,
							   RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_FREQUENCY_SOUND_CHANNEL_2};
	ViAttr      level_attr[] = {RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_LEVEL_SOUND_MONO,
								RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_LEVEL_SOUND_LEFT,
								RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_LEVEL_SOUND_RIGHT,
								RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_LEVEL_SOUND_CHANNEL_1,
								RSBTC_ATTR_ANALOG_TV_AUDIO_GENERATOR_LEVEL_SOUND_CHANNEL_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (frequencyParameter, RSBTC_VAL_ATV_AUDIO_SOUND_FREQ_MONO, 
                                            RSBTC_VAL_ATV_AUDIO_SOUND_FREQ_CH2), 3, "Frequency Parameter");
	
    viCheckParm (rsbtc_invalidViInt32Range (levelParameter, RSBTC_VAL_ATV_AUDIO_SOUND_LEVEL_MONO, 
                                            RSBTC_VAL_ATV_AUDIO_SOUND_LEVEL_CH2), 5, "Level Parameter");
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             freq_attr[frequencyParameter],
                                             frequencyValue), 4, "Frequency Value");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             level_attr[levelParameter],
                                             levelValue), 6, "Level Value");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects the audio player file.
/// HIFN      
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) If the file is not in the default path, the path must be specified 
/// HIFN  at the same time. If no file of the specified name exists, it is 
/// HIFN  created. The file extension may be omitted. Only files with the file 
/// HIFN  extension *.wv will be created or loaded.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR loadLibrary/This control selects audio file from the D:/AUDIOPLAYER directory.
ViStatus _VI_FUNC rsbtc_LoadAnalogTvAudioLibrary(
	ViSession	instrSession,
	ViInt32	path,
	ViString	loadLibrary
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_AUDIO_PLAYER_LOAD_FILE,
                                             loadLibrary), 3, "Load Library");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads out the files in the default directory. 
/// HIFN     The default directory is set with the command MMEM:CDIRectory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_AnalogTvAudioLibraryCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory));
    
    viCheckErr( viPrintf(instrSession, "SOUR%ld:IQC:RATV:APL:LIBR:CAT?\n", path));
    
    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) 
    {
        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
        strncpy(output, pbuffer, len);
        output[len] = '\0';
    }
    
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function queries the number of files in the default directory for 
/// HIFN  audio player files (D:\AUDIOPLAYER). 
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) A path can also be specified, in this case the number of files in 
/// HIFN  the specified directory is read. Only files with the file extension 
/// HIFN  *.wv will be listed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR catalogLength/This control reads out the number of files in the default directory.
ViStatus _VI_FUNC rsbtc_AnalogTvAudioLibraryCatalogLength(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32*	catalogLength
)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Catalog Length");
    
    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
        
    sprintf (buffer,"SOUR%ld:IQC:RATV:APL:LIBR:CAT:LENG?\n", path);
    
    viCheckErr( viQueryf (instrSession, buffer, "%ld", catalogLength));
    
    viCheckErr(rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function reads selected value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR result/This control returns selected coding value.
/// HIPAR levelParameter/This control selects the parameter to be queried. Depends on the 
/// HIPAR levelParameter/selected SOUND MODE.
ViStatus _VI_FUNC rsbtc_ReadAnalogTvAudioPlayerValues(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	levelParameter,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_ANALOG_TV_AUDIO_PLAYER_LEVEL_SOUND_MONO,
                          RSBTC_ATTR_ANALOG_TV_AUDIO_PLAYER_LEVEL_SOUND_LEFT,
						  RSBTC_ATTR_ANALOG_TV_AUDIO_PLAYER_LEVEL_SOUND_RIGHT,
                          RSBTC_ATTR_ANALOG_TV_AUDIO_PLAYER_LEVEL_SOUND_CHANNEL_1,
                          RSBTC_ATTR_ANALOG_TV_AUDIO_PLAYER_LEVEL_SOUND_CHANNEL_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (levelParameter, RSBTC_VAL_ATV_AUDIO_SOUND_FREQ_MONO, 
                                            RSBTC_VAL_ATV_AUDIO_SOUND_FREQ_CH2), 3, "Level Parameter");
	
    viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                             attr[levelParameter],
                                             result), 4, "Result");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects the NICAM signal source. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Selects the NICAM signal source.
/// HIPAR nicamSoundMode/Defines the mode of the NICAM data stream.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvNICAMSource(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	nicamSoundMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_NICAM_SOURCE,
                                            source), 3, "Source");
	
	if (source != RSBTC_VAL_ATV_NICAM_SOURCE_PRBS)
	{
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_SOUND_MODE,
                                            nicamSoundMode), 4, "NICAM Sound Mode");
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function switches NICAM audio source 1 or 2 ON or OFF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR audioSource/This control selects the NICAM audio source to be set.
/// HIPAR state/This control switches the selected audio source to ON or OFF.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvNICAMAF(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	audioSource,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_AF_1, RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_AF_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (audioSource, RSBTC_VAL_ATV_AUDIO_GEN_AF1, RSBTC_VAL_ATV_AUDIO_GEN_AF2), 3, "Audio Source");
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              attr[audioSource],
                                              state), 4, "State");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures analog TV NICAM parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR frequencyParameter/This control selects the parameter to be set. Depends on the selected 
/// HIPAR frequencyParameter/SOUND MODE.
/// HIPAR frequencyValue/Sets the AF frequency value of selected parameter.
/// HIPAR levelParameter/This control selects the parameter to be set .Depends on the selected 
/// HIPAR levelParameter/SOUND MODE.
/// HIPAR levelValue/Sets the AF level value of selected parameter.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvNICAM(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	frequencyParameter,
	ViReal64	frequencyValue,
	ViInt32	levelParameter,
	ViReal64	levelValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      freq_attr[] = {RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_FREQ_SOUND_MONO,
							   RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_FREQ_SOUND_LEFT,
							   RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_FREQ_SOUND_RIGHT,
							   RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_FREQ_SOUND_CHANNEL_1,
							   RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_FREQ_SOUND_CHANNEL_2};
	ViAttr      level_attr[] = {RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_LEVEL_SOUND_MONO,
								RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_LEVEL_SOUND_LEFT,
								RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_LEVEL_SOUND_RIGHT,
								RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_LEVEL_SOUND_CHANNEL_1,
								RSBTC_ATTR_ANALOG_TV_NICAM_GENERATOR_LEVEL_SOUND_CHANNEL_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (frequencyParameter, RSBTC_VAL_ATV_AUDIO_SOUND_FREQ_MONO, 
                                            RSBTC_VAL_ATV_AUDIO_SOUND_FREQ_CH2), 3, "Frequency Parameter");
	
    viCheckParm (rsbtc_invalidViInt32Range (levelParameter, RSBTC_VAL_ATV_AUDIO_SOUND_LEVEL_MONO, 
                                            RSBTC_VAL_ATV_AUDIO_SOUND_LEVEL_CH2), 5, "Level Parameter");
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             freq_attr[frequencyParameter],
                                             frequencyValue), 4, "Frequency Value");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             level_attr[levelParameter],
                                             levelValue), 6, "Level Value");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the sound modulation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/Sets the desired sound method.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSoundModulation(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_SOUND_MODULATION_MODE,
                                            mode), 3, "Mode");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads selected value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR parameter/This control selects the value to be read from instrument.
/// HIPAR result/This control returns selected coding value.
ViStatus _VI_FUNC rsbtc_ReadAnalogTvSoundModulationValues(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	parameter,
	ViReal64*	result
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_ANALOG_TV_SOUND_MOD_FREQ_DEVIATION_MONO,
                          RSBTC_ATTR_ANALOG_TV_SOUND_MOD_FREQ_DEVIATION_SUBCARRIER_1,
                          RSBTC_ATTR_ANALOG_TV_SOUND_MOD_FREQ_DEVIATION_SUBCARRIER_2,
                          RSBTC_ATTR_ANALOG_TV_SOUND_MOD_FREQ_DEVIATION_PILOT};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (parameter, RSBTC_VAL_ATV_SOUND_FREQ_DEV_MONO, 
                                            RSBTC_VAL_ATV_SOUND_FREQ_DEV_PILOT), 3, "Parameter");
	
    viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                             attr[parameter],
                                             result), 4, "Result");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects the BTSC player file. 
/// HIFN     
/// HIFN     Note:
/// HIFN     If no file of the specified name exists, an error message is 
/// HIFN  displayed. Only files with the *.btsc file extension are loaded.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ANALOG_TV_BTSC_LOAD_FILE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]RATV:BTSC:LIBRary:SELect
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR loadLibrary/Selects the BTSC player file.
ViStatus _VI_FUNC rsbtc_LoadAnalogTVBTSCLibrary(
	ViSession	instrSession,
	ViInt32	path,
	ViString	loadLibrary
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_BTSC_LOAD_FILE,
                                             loadLibrary), 3, "Load Library");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads out the *.btsc files in the default directory. Use 
/// HIFN  D:\AUDIOPLAYER\BTSC as default directory for BTSC player files. The 
/// HIFN  default directory is set with the command MMEM:CDIRectory.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     none
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]RATV:BTSC:LIBRary:CATalog?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_AnalogTVBTSCLibraryCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory));
    
    viCheckErr( viPrintf(instrSession, "SOUR%ld:RATV:BTSC:LIBR:CAT?\n", path));
    
    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) 
    {
        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
        strncpy(output, pbuffer, len);
        output[len] = '\0';
    }
    
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function reads out the number of files in the default directory 
/// HIFN  (D:\AUDIOPLAYER\BTSC).
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     none
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:][IQCoder:]RATV:BTSC:LIBRary:CATalog:LENGth?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR catalogLength/This control reads out the number of files in the default directory.
ViStatus _VI_FUNC rsbtc_AnalogTVBTSCLibraryCatalogLength(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32*	catalogLength
)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Catalog Length");
    
    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
        
    sprintf (buffer,"SOUR%ld:RATV:BTSC:LIBR:CAT:LENG?\n", path);
    
    viCheckErr( viQueryf (instrSession, buffer, "%ld", catalogLength));
    
    viCheckErr(rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/*----*/

/// HIFN  This function enables use of special Analog TV coding parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables all special settings. This is useful if you want 
/// HIPAR state/to quickly switch back to the default values of a specific standard 
/// HIPAR state/without losing your customized special settings.
ViStatus _VI_FUNC rsbtc_EnableAnalogTvSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_SETTINGS,
                                              state), 3, "State");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures special Analog TV coding parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR video/Enables or disables the video signal.
/// HIPAR carrier/Enables or disables the carrier signal (vision carrier).
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSpecialVideoCarrier(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	video,
	ViBoolean	carrier
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_VIDEO,
                                              video), 3, "Video");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_CARRIER,
                                              carrier), 4, "Carrier");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures special Analog TV coding parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR vsbFilter/Enables or disables the vestigial sideband modulation.
/// HIPAR gdPrecorrection/GD PrecorrectionEnables or disables the video group delay 
/// HIPAR gdPrecorrection/precorrection
/// HIPAR residualCarrier/Sets the residual carrier (resolution of 0.1 %)
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	vsbFilter,
	ViBoolean	gdPrecorrection,
	ViReal64	residualCarrier
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_VSB_FILTER,
                                              vsbFilter), 3, "VSB Filter");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_GD_PRECORRECTION,
                                              gdPrecorrection), 4, "GD Precorrection");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_SPECIAL_RESIDUAL_CARRIER,
                                             residualCarrier), 5, "Residual Carrier");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the vestigial sideband characteristic of the 
/// HIFN  respective standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR vsbCharacteristic/This control selects the vestigial sideband characteristic of the 
/// HIPAR vsbCharacteristic/respective standard. 
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSpecialVsbCharacteristic(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	vsbCharacteristic
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_SPECIAL_VSB_CHARACTERISTIC,
                                            vsbCharacteristic), 3, "VSB Characteristic");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the preemphasis for the AF sound channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR preemphasis/This control sets the preemphasis for the AF sound channels.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvPreemphasis(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	preemphasis
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_SPECIAL_PREEMPHASIS,
                                            preemphasis), 3, "Preemphasis");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures special Analog TV coding parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR subcarrier/This control selects the value.
/// HIPAR nom_Freq_Dev/This control sets the frequency deviation of the sound subcarrier.
/// HIPAR subcarrierState/Switches the sound subcarrier ON or OFF.
/// HIPAR frequencySubcarrier/This control sets RF frequency of the sound subcarrier.
/// HIPAR levelSubcarrier/This control sets the level of sound subcarrier.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSubcarrierSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	subcarrier,
	ViReal64	nom_Freq_Dev,
	ViBoolean	subcarrierState,
	ViReal64	frequencySubcarrier,
	ViReal64	levelSubcarrier
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      nom_Freq_Dev_Attr[] = {RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_NOM_FREQUENCY_DEVIATION_MONO,
                                       RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_NOM_FREQUENCY_DEVIATION_SUBCARRIER_1,
                                       RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_NOM_FREQUENCY_DEVIATION_SUBCARRIER_2};
	ViAttr      subcarrierState_Attr[] = {RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_SUBCARRIER_MONO,
                                          RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_SUBCARRIER_1,
                                          RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_SUBCARRIER_2};
	ViAttr      frequencySubcarrier_Attr[] = {RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_FREQUENCY_SUBCARRIER_MONO,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_FREQUENCY_SUBCARRIER_1,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_FREQUENCY_SUBCARRIER_2};
	ViAttr      levelSubcarrier_Attr[] = {RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_LEVEL_SUBCARRIER_MONO,
                                          RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_LEVEL_SUBCARRIER_1,
                                          RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_MODULATION_LEVEL_SUBCARRIER_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (subcarrier, RSBTC_VAL_ATV_SOUND_SPEC_SUBCAR_MONO,
                                            RSBTC_VAL_ATV_SOUND_SPEC_SUBCAR2), 3, "Subcarrier");
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             nom_Freq_Dev_Attr[subcarrier],
                                             nom_Freq_Dev), 4, "Nom. Freq. Dev.");
    
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                             subcarrierState_Attr[subcarrier],
                                             subcarrierState), 5, "Subcarrier State");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                              frequencySubcarrier_Attr[subcarrier],
                                              frequencySubcarrier), 6, "Frequency Subcarrier");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             levelSubcarrier_Attr[subcarrier],
                                             levelSubcarrier), 7, "Level Subcarrier");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the pilot carrier on sound subcarrier 2.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR pilot/Enables or disables the pilot carrier on sound subcarrier 2.
/// HIPAR nom_Freq_Dev_Pilot/Sets the frequency deviation caused by the pilot carrier modulated on 
/// HIPAR nom_Freq_Dev_Pilot/sound subcarrier 2.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvPilot(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	pilot,
	ViReal64	nom_Freq_Dev_Pilot
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_PILOT,
                                              pilot), 3, "Pilot");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_NOMINAL_FREQUENCY_DEVIATION_PILOT,
                                             nom_Freq_Dev_Pilot), 4, "Nom. Freq. Dev. Pilot");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the modulation depth of the L standard 
/// HIFN  amplitude-modulated sound.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR amModulationDepth/Sets the modulation depth of the amplitude-modulated sound subcarrier. 
/// HIPAR amModulationDepth/The selected modulation depth applies to an audio level of 6 dBu.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSpecialAMModulationDepth(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	amModulationDepth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_SPECIAL_SOUND_AM_MODULATION_DEPTH,
                                            amModulationDepth), 3, "AM Modulation Depth");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures special NICAM parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR preemphasis/Sets the preemphasis for the NICAM AF sound channels.
/// HIPAR rollOff/Selects the cosine roll off factor for the NICAM data shaping filter.
/// HIPAR gainAdjustAF1/Changes the headroom for the NICAM sound channels differ from the 
/// HIPAR gainAdjustAF1/standard. For a sine wave test signal with a frequency of 400 Hz, the 
/// HIPAR gainAdjustAF1/sound level, 0 dBu0 shall be 22 dB below the maximum of the digital 
/// HIPAR gainAdjustAF1/coding range in the B/G, D/K and L standards and 24.3 dB for the I 
/// HIPAR gainAdjustAF1/standard.
/// HIPAR gainAdjustAF2/Changes the headroom for the NICAM sound channels differ from the 
/// HIPAR gainAdjustAF2/standard. For a sine wave test signal with a frequency of 400 Hz, the 
/// HIPAR gainAdjustAF2/sound level, 0 dBu0 shall be 22 dB below the maximum of the digital 
/// HIPAR gainAdjustAF2/coding range in the B/G, D/K and L standards and 24.3 dB for the I 
/// HIPAR gainAdjustAF2/standard.
ViStatus _VI_FUNC rsbtc_ConfigureAnalogTvSpecialNICAM(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	preemphasis,
	ViInt32	rollOff,
	ViReal64	gainAdjustAF1,
	ViReal64	gainAdjustAF2
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_ANALOG_TV_SPECIAL_NICAM_PREEMPHASIS,
                                              preemphasis), 3, "Preemphasis");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_ANALOG_TV_SPECIAL_NICAM_ROLL_OFF,
                                            rollOff), 4, "Roll Off");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_SPECIAL_NICAM_GAIN_ADJUST_1,
                                             gainAdjustAF1), 5, "Gain Adjust AF 1");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_ANALOG_TV_SPECIAL_NICAM_GAIN_ADJUST_2,
                                             gainAdjustAF2), 6, "Gain Adjust AF 2");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio Broadcasting FM Input Signal 
/// HIFN  parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Selects the source.
/// HIPAR inputSignal/Sets the audio source.
/// HIPAR afMode/Sets the relationship of the two audio channels with respect to each 
/// HIPAR afMode/other.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	inputSignal,
	ViInt32	afMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_AUDIO_BC_FM_INPUT_SIGNAL_SOURCE_1,
                          RSBTC_ATTR_AUDIO_BC_FM_INPUT_SIGNAL_SOURCE_1,
                          RSBTC_ATTR_AUDIO_BC_FM_INPUT_SIGNAL_SOURCE_2};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (source, RSBTC_VAL_AUDIO_BC_SOURCE_MONO, RSBTC_VAL_AUDIO_BC_SOURCE_RIGHT), 3, "Source");
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            attr[source],
                                            inputSignal), 4, "Input Signal");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_FM_AF_MODE,
                                            afMode), 5, "AF Mode");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio BC FM parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Selects the source.
/// HIPAR audio/Enables or disables the audio channel.
/// HIPAR frequency/Sets the frequency of the internal audio generator.
/// HIPAR level/Sets the level of the internal audio generator.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMGeneratorSource(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViBoolean	audio,
	ViReal64	frequency,
	ViReal64	level
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      audio_attr[] = {RSBTC_ATTR_AUDIO_BC_FM_AUDIO_CHANNEL_1,
                                RSBTC_ATTR_AUDIO_BC_FM_AUDIO_CHANNEL_1,
                                RSBTC_ATTR_AUDIO_BC_FM_AUDIO_CHANNEL_2};
	ViAttr      freq_attr[] = {RSBTC_ATTR_AUDIO_BC_FM_GENERATOR_FREQUENCY_MONO,
                               RSBTC_ATTR_AUDIO_BC_FM_GENERATOR_FREQUENCY_LEFT,
                               RSBTC_ATTR_AUDIO_BC_FM_GENERATOR_FREQUENCY_RIGHT};
	ViAttr      level_attr[] = {RSBTC_ATTR_AUDIO_BC_FM_GENERATOR_LEVEL_MONO,
                                RSBTC_ATTR_AUDIO_BC_FM_GENERATOR_LEVEL_LEFT,
                                RSBTC_ATTR_AUDIO_BC_FM_GENERATOR_LEVEL_RIGHT};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (source, RSBTC_VAL_AUDIO_BC_SOURCE_MONO, RSBTC_VAL_AUDIO_BC_SOURCE_RIGHT), 3, "Source");
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                            audio_attr[source],
                                            audio), 4, "Audio");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                            freq_attr[source],
                                            frequency), 5, "Frequency");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                            level_attr[source],
                                            level), 6, "Level");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio BC FM player parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Selects the source.
/// HIPAR audio/Enables or disables the audio channel.
/// HIPAR attenuation/Sets the attenuation.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMPlayerSource(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViBoolean	audio,
	ViReal64	attenuation
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      audio_attr[] = {RSBTC_ATTR_AUDIO_BC_FM_AUDIO_CHANNEL_1,
                                RSBTC_ATTR_AUDIO_BC_FM_AUDIO_CHANNEL_1,
                                RSBTC_ATTR_AUDIO_BC_FM_AUDIO_CHANNEL_2};
	ViAttr      attenuation_attr[] = {RSBTC_ATTR_AUDIO_BC_FM_AUDIO_PLAYER_ATTENUATION_1,
                                      RSBTC_ATTR_AUDIO_BC_FM_AUDIO_PLAYER_ATTENUATION_1,
                                      RSBTC_ATTR_AUDIO_BC_FM_AUDIO_PLAYER_ATTENUATION_2};
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (source, RSBTC_VAL_AUDIO_BC_SOURCE_MONO, RSBTC_VAL_AUDIO_BC_SOURCE_RIGHT), 3, "Source");
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                            audio_attr[source],
                                            audio), 4, "Audio");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                            attenuation_attr[source],
                                            attenuation), 5, "Attenuation");
    
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  Selects the audio player file.
/// HIFN     
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) If the file is not in the default path, the path must be specified 
/// HIFN  at the same time. If no file of the specified name exists, it is 
/// HIFN  created. The file extension may be omitted. Only files with the file 
/// HIFN  extension *.wv will be created or loaded.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR loadLibrary/This control selects audio file from the D:/AUDIOPLAYER directory.
ViStatus _VI_FUNC rsbtc_LoadAudioBCFMPlayerFile(
	ViSession	instrSession,
	ViInt32	path,
	ViString	loadLibrary
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_FM_AUDIO_PLAYER_LOAD_FILE,
                                             loadLibrary), 3, "Load Library");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads out the files in the default directory. 
/// HIFN     The default directory is set with the command MMEM:CDIRectory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_AudioBCFMLibraryCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory));
    
    viCheckErr( viPrintf(instrSession, "SOUR%ld:IQC:FM:APL:LIBR:CAT?\n", path));
    
    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) 
    {
        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
        strncpy(output, pbuffer, len);
        output[len] = '\0';
    }
    
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function queries the number of files in the default directory for 
/// HIFN  audio player files (D:\AUDIOPLAYER). 
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) A path can also be specified, in this case the number of files in 
/// HIFN  the specified directory is read. Only files with the file extension 
/// HIFN  *.wv will be listed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR catalogLength/This control reads out the number of files in the default directory.
ViStatus _VI_FUNC rsbtc_AudioBCFMCatalogLength(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32*	catalogLength
)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Catalog Length");
    
    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
        
    sprintf (buffer,"SOUR%ld:IQC:FM:APL:LIBR:CAT:LENG?\n", path);
    
    viCheckErr( viQueryf (instrSession, buffer, "%ld", catalogLength));
    
    viCheckErr(rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function configures Audio Broadcasting modulation parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/Selects the signal type (FM).
/// HIPAR preemphasis/During frequency modulation, the signal/noise ratio can be improved 
/// HIPAR preemphasis/significantly by boosting the high frequency components at the 
/// HIPAR preemphasis/modulator while at the same time reducing them at the demodulator.
/// HIPAR nomFreqDevAudio/Defines the signal deviation, that means only the deviation that is 
/// HIPAR nomFreqDevAudio/caused by the audio signals.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAudioModulator(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mode,
	ViInt32	preemphasis,
	ViReal64	nomFreqDevAudio
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_FM_MODULATION_MODE,
                                            mode), 3, "Mode");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_FM_MODULATION_PREEMPHASIS,
                                            preemphasis), 4, "Preemphasis");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_FM_MODULATION_NOM_FREQ_DEV_AUDIO,
                                             nomFreqDevAudio), 5, "Nom Freq Dev Audio");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures audio modulation coding parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR rds/Switches the RDS on or off (FM).
/// HIPAR freqDevRDS/Sets the resulting frequency deviation of the radio data system (FM).
/// HIPAR freqDevPilot/Sets the resulting 19 kHz frequency deviation of the pilot tone (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMModulationRDS(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	rds,
	ViReal64	freqDevRDS,
	ViReal64	freqDevPilot
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_FM_MODULATION_RDS,
                                              rds), 3, "RDS");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_FM_MODULATION_FREQ_DEV_RDS,
                                             freqDevRDS), 4, "Freq Dev RDS");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_FM_MODULATION_FREQ_DEVIATION_PILOT,
                                             freqDevPilot), 5, "Freq Dev Pilot");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio Broadcasting FM RDS/RBDS parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR groupSequence/Defines the group sequence which the RDS data must contain. The input 
/// HIPAR groupSequence/line accepts up to 38 groups. If a group number is entered without 
/// HIPAR groupSequence/specifying version A or B, version A is automatically added.
/// HIPAR rdsPI/Sets the programme identification PI.
/// HIPAR ps/Sets the programme service name PS.
/// HIPAR tp/A program carrying regular traffic reports is identified by the 
/// HIPAR tp/traffic program bit (TP). It specifies that the traffic announcement 
/// HIPAR tp/flag (TA) is set in the event of a traffic announcement. This 
/// HIPAR tp/information is transmitted in block 2 of each group.
/// HIPAR ta/Traffic announcement (TA).
/// HIPAR pty/Program type (PTY)
/// HIPAR ptyn/Program type name (PTYN)
/// HIPAR rt/This control sets the radio text RT.
/// HIPAR ms/Identifies whether the present transmission contains music or speech. 
/// HIPAR ms/Use this flag to actuate different volume settings in the receiver 
/// HIPAR ms/depending on the music/speech switch.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMRDSRBDS(
	ViSession	instrSession,
	ViInt32	path,
	ViString	groupSequence,
	ViInt32	rdsPI,
	ViString	ps,
	ViBoolean	tp,
	ViBoolean	ta,
	ViInt32	pty,
	ViString	ptyn,
	ViString	rt,
	ViInt32	ms
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_RDS_GROUP_SEQUENCE,
                                             groupSequence), 3, "Group Sequence");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_RDS_PI,
                                            rdsPI), 4, "RDS PI");
    
	viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_RDS_PS,
                                             ps), 5, "PS");
    
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_TP,
                                              tp), 6, "TP");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_TA,
                                              ta), 7, "TA");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_RDS_PTY,
                                            pty), 8, "PTY");
    
	viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_RDS_PTYN,
                                             ptyn), 9, "PTYN");
    
	viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_RDS_RT,
                                             rt), 10, "RT");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_RDS_MS,
                                            ms), 11, "MS");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio Broadcasting FM RDS/RBDS Decoder 
/// HIFN  Identification parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR diDynamicPTY/Used in decoder identification (DI) to specify whether the program 
/// HIPAR diDynamicPTY/type code (PTY) of the current program or the program referenced via 
/// HIPAR diDynamicPTY/EON (enhanced other network) in group type "14A", variant 13 is being 
/// HIPAR diDynamicPTY/dynamically toggled.
/// HIPAR diCompressed/Used in decoder identification to specify whether the current program 
/// HIPAR diCompressed/or the program referenced via EON (enhanced other network) in group 
/// HIPAR diCompressed/type "14A", variant 13 is being transmitted with compressed content.
/// HIPAR diArtHead/Used in decoder identification to specify whether the current program 
/// HIPAR diArtHead/or the program referenced via EON (enhanced other network) in group 
/// HIPAR diArtHead/type "14A", variant 13 is an artificial head transmission (also known 
/// HIPAR diArtHead/as a dummy head transmission).
/// HIPAR diStereo/Used in decoder identification to specify whether the current program 
/// HIPAR diStereo/or the program referenced via EON (enhanced other network) in group 
/// HIPAR diStereo/type "14A", variant 13 is a stereo or mono transmission.
/// HIPAR ct/Clock time (CT)
/// HIPAR ctOffset/For certain test transmissions, you can advance the clock time (CT). 
/// HIPAR ctOffset/The entered offset is added to the set system time and time zone.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMRDSRBDSDecoderIdentification(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	diDynamicPTY,
	ViBoolean	diCompressed,
	ViBoolean	diArtHead,
	ViBoolean	diStereo,
	ViBoolean	ct,
	ViString	ctOffset
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_DI_DYNAMIC_PTY,
                                              diDynamicPTY), 3, "DI Dynamic PTY");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_DI_COMPRESSED,
                                              diCompressed), 4, "DI Compressed");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_DI_ART_HEAD,
                                              diArtHead), 5, "DI Art Head");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_DI_STEREO,
                                              diStereo), 6, "DI Stereo");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_RDS_DI_CT,
                                              ct), 7, "CT");

	viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_RDS_DI_CT_OFFSET,
                                             ctOffset), 8, "CT Offset");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the alternative frequencies (AF) method.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR afMethod/Sets AF METHOD to A or B(FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAFMethod(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	afMethod
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_AF_METHOD,
                                            afMethod), 3, "AF Method");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the NUMBER OF FREQ. in AF method A (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfFrequencies/Defines the number of alternative frequencies.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAFANumberOfFrequencies(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOfFrequencies
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_AF_A_NUMBER_OF_FREQUENCIES,
                                            numberOfFrequencies), 3, "Number Of Frequencies");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the alternative frequencies 1 to 25 in AF method A 
/// HIFN  (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR af/This control selects the NUMBER OF FREQ. in AF method A (FM).
/// HIPAR frequency/This control sets the alternative frequencies 1 to 25 in AF method A 
/// HIPAR frequency/(FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAFAFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	af,
	ViReal64	frequency
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	    rep_cap[20] = "";
	ViChar		rep_cap_2[10] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (af, 1, 25), 3, "AF");
    
    sprintf (rep_cap_2, ",AF%ld", af);
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AF_A_FREQUENCY,
                                             frequency), 4, "Frequency");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the NUMBER OF LISTS in AF method B (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfLists/This control sets the NUMBER OF LISTS in AF method B (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAFBNumberOfLists(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOfLists
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_AF_B_NUMBER_OF_LISTS,
                                            numberOfLists), 3, "Number Of Lists");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the NUMBER OF FREQ. and TUNING FREQ of a list in AF 
/// HIFN  method B (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR selectEditList/This control sets the NUMBER OF LISTS in AF method B (FM).
/// HIPAR numberOfFrequencies/This control defines the number of individual frequencies for each 
/// HIPAR numberOfFrequencies/list. In method B, transmission is not specifically identified in the 
/// HIPAR numberOfFrequencies/RDS coder. The receiver is able to recognize this method by the tuning 
/// HIPAR numberOfFrequencies/frequency contained in each frequency pair.
/// HIPAR tuningFrequency/Defines the tuning frequency. The specified tuning frequency is 
/// HIPAR tuningFrequency/transmitted so as to form a frequency pair with each entered frequency.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAFBList(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	selectEditList,
	ViInt32	numberOfFrequencies,
	ViReal64	tuningFrequency
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[20] = "";
	ViChar	rep_cap_2[10] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (selectEditList, 1, 5), 3, "Select Edit List");
    
    sprintf (rep_cap_2, ",L%ld", selectEditList);  
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_AF_B_NUMBER_OF_FREQUENCIES,
                                            numberOfFrequencies), 4, "Number Of Frequencies");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AF_B_TUNING_FREQUENCY,
                                             tuningFrequency), 5, "Tuning Frequency");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets ascending or descendin alternative frequency of a 
/// HIFN  list in AF method B (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR selectEditList/This control sets the NUMBER OF LISTS in AF method B (FM).
/// HIPAR af/This control selects the NUMBER OF FREQ. of a list in AF method B 
/// HIPAR af/(FM).
/// HIPAR frequency/This control sets the individual frequencies and indicates whether the 
/// HIPAR frequency/specified alternative frequency carries a different regional program.
/// HIPAR order/This control sets the alternative frequencies in AF method B to 
/// HIPAR order/ascending or descending (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMAFBFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	selectEditList,
	ViInt32	af,
	ViReal64	frequency,
	ViInt32	order
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[30] = "";
	ViChar	rep_cap_2[20] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (selectEditList, 1, 5), 3, "Select Edit List");
    viCheckParm (rsbtc_invalidViInt32Range (af, 1, 25), 3, "AF");
    
    sprintf (rep_cap_2, ",L%ld,AF%ld", selectEditList, af);  
	
	strcat (rep_cap, rep_cap_2);

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AF_B_AF_FREQUENCY,
                                             frequency), 5, "Frequency");
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_AF_B_AF_ORDER,
                                            order), 6, "Order");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio Broadcasting FM EON parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR eonPI/Enhanced other network program identification (EON PI).
/// HIPAR eonPS/Enhanced other network program service name (EON PS)
/// HIPAR eonTP/Enhanced other network traffic program (EON TP).
/// HIPAR eonTA/Enhanced other network traffic announcement (EON TA).
/// HIPAR eonLA/Enhanced other network linkage actuator (EON LA)
/// HIPAR eonEG/Enhanced other network extended generic indicator (EON EG)
/// HIPAR eonILS/Switches the linkage information 'International Linkage Set Indicator 
/// HIPAR eonILS/ILS' on or off (FM).
/// HIPAR eonLSN/Enhanced other network linkage set number (EON LSN).
/// HIPAR eonPTY/Enhanced other network program type (EON PTY)
/// HIPAR eonPIN/The program identification number code specifies the planned day, hour 
/// HIPAR eonPIN/and minute for the start of the EON program transmission, as published 
/// HIPAR eonPIN/by the broadcaster.
/// HIPAR eonAFMethod/The alternative frequencies table gives information about the 
/// HIPAR eonAFMethod/transmission frequencies belonging to the program identification code 
/// HIPAR eonAFMethod/in group type "14A", block 4.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMEONParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	eonPI,
	ViString	eonPS,
	ViBoolean	eonTP,
	ViBoolean	eonTA,
	ViBoolean	eonLA,
	ViBoolean	eonEG,
	ViBoolean	eonILS,
	ViInt32	eonLSN,
	ViInt32	eonPTY,
	ViInt32	eonPIN,
	ViInt32	eonAFMethod
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_PI,
                                            eonPI), 3, "EON PI");
    
	viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_EON_PS,
                                             eonPS), 4, "EON PS");
    
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_EON_TP,
                                              eonTP), 5, "EON TP");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_EON_TA,
                                              eonTA), 6, "EON TA");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_EON_LA,
                                              eonLA), 7, "EON LA");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_EON_EG,
                                              eonEG), 8, "EON EG");

	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_EON_ILS,
                                              eonILS), 9, "EON ILS");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_LSN,
                                            eonLSN), 10, "EON LSN");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_PTY,
                                            eonPTY), 11, "EON PTY");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_PIN,
                                            eonPIN), 12, "EON PIN");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_AF_METHOD,
                                            eonAFMethod), 13, "EON AF Method");
    
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the NUMBER OF FREQ. and TUNING FREQ of EON, AF 
/// HIFN  method MAPPED FREQ. (FM)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfFrequencies/This control sets the NUMBER OF FREQ. in EON, AF method MAPPED FREQ. 
/// HIPAR numberOfFrequencies/(FM)
/// HIPAR tuningFrequency/This control defines the tuning frequency. The specified tuning 
/// HIPAR tuningFrequency/frequency is transmitted so as to form a frequency pair with each 
/// HIPAR tuningFrequency/frequency entered.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMEONAFMappedNumberOfFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOfFrequencies,
	ViReal64	tuningFrequency
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_NUMBER_OF_FREQUENCIES,
                                            numberOfFrequencies), 3, "Number Of Frequencies");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_TUNING_FREQUENCY,
                                             tuningFrequency), 4, "Tuning Frequency");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets an alternative frequency in EON, AF method MAPPED 
/// HIFN  FREQ. (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR af/This control selects the NUMBER OF FREQ. in EON, AF method MAPPED 
/// HIPAR af/FREQ. (FM)
/// HIPAR frequency/This control sets an alternative frequency in EON, AF method MAPPED 
/// HIPAR frequency/FREQ. (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMEONAFMappedFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	af,
	ViReal64	frequency
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[20] = "";
	ViChar	rep_cap_2[10] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (af, 1, 4), 3, "AF");
    
    sprintf (rep_cap_2, ",AF%ld", af);  
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_AF_FREQUENCY,
                                             frequency), 4, "Frequency");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the NUMBER OF FREQ. in EON AF method A (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOfFrequencies/This control sets the NUMBER OF FREQ. in EON AF method A (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMEONAFANumberOfFrequencies(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOfFrequencies
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_EON_AF_A_NUMBER_OF_FREQUENCIES,
                                            numberOfFrequencies), 3, "Number Of Frequencies");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets one of 25 alternative frequencies in AF method A 
/// HIFN  (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR af/This control selects the NUMBER OF FREQ. in EON AF method A (FM).
/// HIPAR frequency/This control sets the alternative frequencies 1 to 25 in AF method A 
/// HIPAR frequency/(FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMEONAFAFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	af,
	ViReal64	frequency
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[20] = "";
	ViChar	rep_cap_2[10] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (af, 1, 25), 3, "AF");
    
    sprintf (rep_cap_2, ",AF%ld", af);  
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_EON_AF_A_FREQUENCY,
                                             frequency), 4, "Frequency");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the TMC group 3A VAR 1 or VAR 2 (FM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR group3AVAR00/This control sets the TMC group 3A VAR 00 (FM).
/// HIPAR group3AVAR01/This control sets the TMC group 3A VAR 1 (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCTMCGroup3AVARParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	group3AVAR00,
	ViInt32	group3AVAR01
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_TMC_GROUP_3A_VAR_00,
                                            group3AVAR00), 3, "Group 3A VAR 00");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_TMC_GROUP_3A_VAR_01,
                                            group3AVAR01), 4, "Group 3A VAR 01");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets NUMBER OF 8A-GROUPS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR numberOf8AGroups/This control sets NUMBER OF 8A-GROUPS.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCTMCNumberOf8AGroups(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	numberOf8AGroups
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_TMC_NUMBER_OF_8A_GROUPS,
                                            numberOf8AGroups), 3, "Number Of 8A Groups");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures TMC group 8A.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR group8A/This control selects NUMBER OF 8A-GROUPS.
/// HIPAR block/This control selects 8A Block.
/// HIPAR value/Sets TMC group 8A 1 to 6 block 2, 3 or 4.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMTMC8ABlock(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	group8A,
	ViInt32	block,
	ViInt32	value
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (group8A, 1, 6), 3, "Group 8A");
	viCheckParm (rsbtc_invalidViInt32Range (block, 2, 4), 4, "Block");
    
    sprintf (rep_cap_2, ",G8A%ld,B%ld", group8A, block);  
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_TMC_8A_BLOCK,
                                            value), 5, "Value");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures open format Group A.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR groupA/This control selects NUMBER OF A-GROUPS.
/// HIPAR block/This control selects the block.
/// HIPAR value/Contains the group types defined under "Group Sequence".
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCOpenFormatGroupA(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	groupA,
	ViInt32	block,
	ViInt32	value
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (groupA, 1, 15), 3, "Group A");
	viCheckParm (rsbtc_invalidViInt32Range (block, 2, 4), 4, "Block");
    
    sprintf (rep_cap_2, ",G%ldA,B%ld", groupA, block);  
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_A,
                                            value), 5, "Value");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures open format Group B.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR groupB/This control selects NUMBER OF A-GROUPS.
/// HIPAR block/This control selects the block.
/// HIPAR value/Contains the group types defined under "Group Sequence".
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCOpenFormatGroupB(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	groupB,
	ViInt32	block,
	ViInt32	value
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (groupB, 1, 13), 3, "Group B");
	viCheckParm (rsbtc_invalidViInt32Range (block, 2, 4), 4, "Block");
    
    sprintf (rep_cap_2, ",G%ldB,B%ld", groupB, block);  
	
	strcat (rep_cap, rep_cap_2);

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_B,
                                            value), 5, "Value");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures special Audio BC coding parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR specialSettings/Enables the special settings.
/// HIPAR pilot/Switches the 19 kHz pilot tone on or off (FM).
/// HIPAR phaseOffsetPilot19kHz/This control sets the phase offset of the 19 kHz pilot tone relative 
/// HIPAR phaseOffsetPilot19kHz/to the suppressed 38 kHz carrier (FM).
/// HIPAR phaseOffsetRDS/This control sets the phase offset of the suppressed 57 kHz RDS 
/// HIPAR phaseOffsetRDS/carrier (FM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCFMSpecialSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	specialSettings,
	ViBoolean	pilot,
	ViReal64	phaseOffsetPilot19kHz,
	ViReal64	phaseOffsetRDS
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_FM_SPECIAL_SETTINGS,
                                              specialSettings), 3, "Special Settings");

	if (specialSettings == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
	                                              RSBTC_ATTR_AUDIO_BC_FM_SPECIAL_PILOT,
	                                              pilot), 4, "Pilot");

		if (pilot == VI_TRUE)
		{
			viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
		                                             RSBTC_ATTR_AUDIO_BC_FM_SPECIAL_PHASE_OFFSET_PILOT,
		                                             phaseOffsetPilot19kHz), 5, "Phase Offset Pilot 19 kHz");
    
			viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
		                                             RSBTC_ATTR_AUDIO_BC_FM_SPECIAL_PHASE_OFFSET_RDS,
		                                             phaseOffsetRDS), 6, "Phase Offset RDS");
		}
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio Broadcasting AM input signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR inputSignal/Selects the input signal source (AM).
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCAMInputSignal(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	inputSignal
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_AUDIO_BC_AM_INPUT_SIGNAL_SOURCE,
                                            inputSignal), 3, "Input Signal");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio BC AM parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR audio/Enables or disables the audio channel.
/// HIPAR frequency/Sets the frequency.
/// HIPAR level/Sets the level of the internal audio generator.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCAMGeneratorSource(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	audio,
	ViReal64	frequency,
	ViReal64	level
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_AM_AUDIO_CHANNEL,
                                              audio), 3, "Audio");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AM_AUDIO_GENERATOR_FREQUENCY,
                                             frequency), 4, "Frequency");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AM_AUDIO_GENERATOR_LEVEL,
                                             level), 5, "Level");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Audio BC AM player parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR audio/Enables or disables the audio channel.
/// HIPAR attenuation/Sets the attenuation.
ViStatus _VI_FUNC rsbtc_ConfigureAudioBCAMPlayerSource(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	audio,
	ViReal64	attenuation
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_AUDIO_BC_AM_AUDIO_CHANNEL,
                                              audio), 3, "Audio");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AM_AUDIO_PLAYER_ATTENUATION,
                                             attenuation), 4, "Attenuation");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects the audio player file. 
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) If the file is not in the default path, the path must be specified 
/// HIFN  at the same time. If no file of the specified name exists, it is 
/// HIFN  created. The file extension may be omitted. Only files with the file 
/// HIFN  extension *.wv will be created or loaded.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR loadLibrary/This control selects audio file from the D:/AUDIOPLAYER directory.
ViStatus _VI_FUNC rsbtc_LoadAudioBCAMPlayerFile(
	ViSession	instrSession,
	ViInt32	path,
	ViString	loadLibrary
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AM_AUDIO_PLAYER_LOAD_FILE,
                                             loadLibrary), 3, "Load Library");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function reads out the files in the default directory. 
/// HIFN     The default directory is set with the command MMEM:CDIRectory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_AudioBCAMLibraryCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory));
    
    viCheckErr( viPrintf(instrSession, "SOUR%ld:IQC:AM:APL:LIBR:CAT?\n", path));
    
    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) 
    {
        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
        strncpy(output, pbuffer, len);
        output[len] = '\0';
    }
    
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function queries the number of files in the default directory for 
/// HIFN  audio player files (D:\AUDIOPLAYER). 
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) A path can also be specified, in this case the number of files in 
/// HIFN  the specified directory is read. Only files with the file extension 
/// HIFN  *.wv will be listed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR catalogLength/This control reads out the number of files in the default directory.
ViStatus _VI_FUNC rsbtc_AudioBCAMCatalogLength(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32*	catalogLength
)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
  
    if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Catalog Length");
    
    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
        
    sprintf (buffer,"SOUR%ld:IQC:AM:APL:LIBR:CAT:LENG?\n", path);
    
    viCheckErr( viQueryf (instrSession, buffer, "%ld", catalogLength));
    
    viCheckErr(rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function configures the nominal modulation depth (AM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR nominalModulationDepth/Sets the nominal modulation depth (AM).
ViStatus _VI_FUNC rsbtc_confAudioBCAMModulationDepth(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	nominalModulationDepth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_AUDIO_BC_AM_NOMINAL_MODULATION_DEPTH,
                                             nominalModulationDepth), 3, "Nominal Modulation Depth");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function selects the waveform to be loaded.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ARBITRARY_WAVEFORM_GENERATION_WAVEFORM
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:ARB[1..8]:WAVeform:SELect
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR loadWaveform/This control selects the waveform to be loaded.
ViStatus _VI_FUNC rsbtc_LoadARBWaveform(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	arb, 
	ViString	loadWaveform
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_arb[5] = "";


    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_arbRepCap (instrSession, arb, rep_cap_arb)); 	
    
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_arb);
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_ARBITRARY_WAVEFORM_GENERATION_WAVEFORM,
                                                loadWaveform), 3, "");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function deletes the specified waveform file.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_ARB_WAVEFORM_DELETE
/// HIFN     
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) If the file is not on the default path, the path must be specified 
/// HIFN  at the same time. The file extension may be omitted. Only files with 
/// HIFN  the file extension *.wv will be deleted.
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:ARB[1..8]:WAVeform:DELete
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR arb/This control selects the ARB.
/// HIPAR deleteWaveform/This control deletes the specified waveform file.
ViStatus _VI_FUNC rsbtc_DeleteARBWaveform(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	arb,
	ViString	deleteWaveform
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_path[5] = "";
	ViChar	rep_cap_arb[5] = "";


    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_arbRepCap (instrSession, arb, rep_cap_arb)); 	
    
	strcpy (rep_cap, rep_cap_path);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_arb);
	
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_ARB_WAVEFORM_DELETE,
                                                deleteWaveform), 4, "");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}




/// HIFN  This function queries the content of the specified tag of the selected 
/// HIFN  Waveform file.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:ARB[1..8]:WAVeform:DATA?
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR arb/This control selects the ARB.
/// HIPAR waveformFileName/This control selects the waveform file.
/// HIPAR tag/This control selects the tag.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns content of the specified tag of the selected 
/// HIPAR output/Waveform file.
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_ARBWaveformFileTag(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	arb,
	ViString	waveformFileName,
	ViInt32	tag,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, NULL));

    viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
	viCheckParm (rsbtc_invalidViInt32Range (arb, 1, 8), 3, "ARB"); 
    
	    if (bufferSize != 0 && output == NULL)
	        return VI_ERROR_PARAMETER6;

	    viCheckErr( viPrintf(instrSession, ":SOUR%ld:BB:ARB%ld:WAV:DATA? '%s','%s'\n",
	        path, arb, waveformFileName, waveformFileTagArr[tag]));
   
    
	    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
	    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
	    if (output != NULL) 
	    {
	        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
	        strncpy(output, pbuffer, len);
	        output[len] = '\0';
	    }
    
	    free(pbuffer);
	    if (returnedValues) *returnedValues = (ViInt32) count;
	    
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;   
}

/// HIFN  This function reads out the files in the default directory. 
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) The default directory is set using command MMEM:CDIRectory. A path 
/// HIFN  can also be specified, in which case the files in the specified 
/// HIFN  directory are read. When the names of the waveform files are returned 
/// HIFN  they are separated by commas. Only files with the file extension *.wv 
/// HIFN  will be listed.
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:ARB[1..8]:WAVeform:CATalog?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR arb/This control selects the ARB.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_ARBWaveformCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	arb,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

	checkErr (Rs_LockSession (instrSession, NULL));

    if (bufferSize != 0 && output == NULL)
	        return VI_ERROR_PARAMETER5;

	    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
	    viCheckErr( viPrintf (instrSession, "SOUR%ld:BB:ARB%ld:WAV:CAT?\n", path, arb));
	   // viCheckErr( viPrintf(instrSession, ":BB:ARB:WAV:CAT? '%s'\n", directory));
   
    
	    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
	    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
	    if (output != NULL) 
	    {
	        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
	        strncpy(output, pbuffer, len);
	        output[len] = '\0';
	    }
    
	    free(pbuffer);
	    if (returnedValues) *returnedValues = (ViInt32) count;
		
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;   
}


/// HIFN  This function reads out the number of files in the default directory 
/// HIFN  for waveform files (D: ARBWaveforms).
/// HIFN     
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) A path can also be specified, in which case the number of files in 
/// HIFN  the specified directory is read. Only files with the file extension 
/// HIFN  *.wv will be listed.
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:ARB[1..8]:WAVeform:CATalog:LENGth?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR arb/This control selects the ARB.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR catalogLength/This control reads out the number of files in the default directory.
ViStatus _VI_FUNC rsbtc_ARBWaveformCatalogLength(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	arb,
	ViString	directory,
	ViInt32*	catalogLength
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr (Rs_LockSession (instrSession, NULL));

	if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 5, "Catalog Length");
    
	    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
	    //sprintf (buffer,":BB:ARB:WAV:CAT:LENG? '%s'", directory);
	    sprintf (buffer,"SOUR%ld:BB:ARB%ld:WAV:CAT:LENG?\n", path, arb);    
    
	    viCheckErr( viQueryf (instrSession, buffer, "%ld", catalogLength));
	     
   
    viCheckErr(rsbtc_CheckStatus (instrSession));
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}                                                    

/// HIFN This function returns the number of samples that the loaded
/// HIFN waveform file contains.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR ARB/This control selects the ARB.
/// HIPAR points/Returns the number of samples that the loaded waveform file
/// HIPAR points/contains.
ViStatus _VI_FUNC rsbtc_ARBWaveformPoints (ViSession instrSession,
                                           ViInt32 path, 
										   ViInt32 ARB,
                                           ViInt32 *points)
{
    ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[10] = "";
	ViChar		rep_cap_path[5] = ""; 
	ViChar		rep_cap_arb[5] = ""; 

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap_path));
    checkErr(rsbtc_arbRepCap(instrSession, ARB, rep_cap_arb));
	sprintf(rep_cap,"%s,%s",rep_cap_path, rep_cap_arb);
	
	viCheckParm (rsbtc_GetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_ARBITRARY_WAVEFORM_GENERATION_POINTS, points),
                         4, "Points");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures IQ Digital In parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_STATE
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_IQ_SWAP
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_IQ_AUTO_SETTINGS
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_MEASUREMENT_PERIOD
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_CREST_FACTOR
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_PEAK
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:IQ:DIN:STATe
/// HIFN     [SOURce<hw>]:IQ:DIN:IQSWap
/// HIFN     [SOURce<hw>]:IQ:DIN:ASETting:STATe
/// HIFN     [SOURce<hw>]:IQ:DIN:MPERiod
/// HIFN     [SOURce<hw>]:IQ:DIN:CFACtor
/// HIFN     [SOURce<hw>]:IQ:DIN:POWer:PEAK
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the digital I/Q input.
/// HIPAR iqSwap/Enables or disables the swapping of the I and Q signal components, 
/// HIPAR iqSwap/which mirrors the spectrum at the f = 0 line and inverts the sign of 
/// HIPAR iqSwap/the frequency.
/// HIPAR measurementPeriod/Sets the recording duration for measuring the baseband input signal. 
/// HIPAR measurementPeriod/For accurate level measurements, the measurement period should be set 
/// HIPAR measurementPeriod/to a time value that is long enough to capture several periods of the 
/// HIPAR measurementPeriod/input signal.
/// HIPAR crestFactor/Displays the crest factor of the external baseband signal.
/// HIPAR digitalIQAutoSettings/Enables or disables the automatic adjustment of the baseband input 
/// HIPAR digitalIQAutoSettings/signal.
/// HIPAR peakLevel/Displays the peak level of the external baseband signal relative to 
/// HIPAR peakLevel/full scale of 0.5 V, in terms of dB full scale.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalInputLevel(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViBoolean	iqSwap,
	ViBoolean	digitalIQAutoSettings,
	ViReal64	measurementPeriod,
	ViReal64	crestFactor,
	ViReal64	peakLevel
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	state;
	/*viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
	                                              RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_STATE,
	                                              state), 3, "State");
	*/										  
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
	                                              RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_IQ_SWAP,
	                                              iqSwap), 4, "IQ Swap");
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
	                                              RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_IQ_AUTO_SETTINGS,
                                              digitalIQAutoSettings), 5, "Digital IQ Auto Settings");
	
	if (digitalIQAutoSettings == VI_FALSE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_CREST_FACTOR, crestFactor),
                         5, "Crest Factor");

											  
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_MEASUREMENT_PERIOD, measurementPeriod),
                         6, "Measurement Period");	
	
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_LEVEL_PEAK, peakLevel),
                         7, "Peak Level");
    }
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures the IQ Digital In sample rate value.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_SAMPLE_RATE_SOURCE
/// HIFN     RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_SAMPLE_RATE_VALUE
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:IQ:DIN:SRATe:SOURce
/// HIFN     [SOURce<hw>]:IQ:DIN:SRATe:ACTual
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Defines how the sample rate is set.
/// HIPAR sampleRateValue/Sets the sample rate of the external digital baseband input signal. 
/// HIPAR sampleRateValue/The maximum sample rate depends on the connected transmitting device.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalInSampleRate(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViReal64 sampleRateValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_SAMPLE_RATE_SOURCE, source),
                         3, "Source");
	
	if (source == RSBTC_VAL_DIG_IQ_SAMPLE_RATE_USER)
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_AUDIO_BC_DIGITAL_IQ_INPUT_SAMPLE_RATE_VALUE, sampleRateValue),
                         4, "Sample Rate Value");	
  
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Enables or disables the digital I/Q output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the digital I/Q output.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalOutState (ViSession instrSession,
                                                    ViInt32 path,
                                                    ViBoolean state)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_ENABLED, state),
                         3, "State");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Enables or disables the swapping of the I and Q signal components.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR IQSwap/Document parameter here.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalOutIQSwap (ViSession instrSession,
                                                     ViInt32 path,
                                                     ViBoolean IQSwap)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_IQ_SWAP, IQSwap),
                         3, "IQ Swap");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures IQ Digital In parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR setLevelVia/Sets how the signal level is expressed.
/// HIPAR level/Sets the level or peak level of the output signal relative to
/// HIPAR level/full scale of 0.5 V (in terms of dB full scale).
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalOutLevel (ViSession instrSession,
                                                    ViInt32 path,
                                                    ViInt32 setLevelVia,
                                                    ViReal64 level)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_SET_LEVEL_VIA, setLevelVia),
                         3, "Set Level Via");
	switch(setLevelVia){
		case RSBTC_VAL_BASEBAND_IQ_DIGITAL_PEAK_LEVEL:
				viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_PEAK_LEVEL, level),
                         4, "Level");	
		break;
		case RSBTC_VAL_BASEBAND_IQ_DIGITAL_LEVEL:
				viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_LEVEL, level),
                         4, "Level");	
		break;
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN This function configures the IQ Digital Out sample rate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the sample rate source.
/// HIPAR sampleRateValue/Sets the sample rate of the external digital baseband input
/// HIPAR sampleRateValue/signal. The maximum sample rate depends on the connected
/// HIPAR sampleRateValue/transmitting device.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalOutSampleRate (ViSession instrSession,
                                                         ViInt32 path,
                                                         ViInt32 source,
                                                         ViReal64 sampleRateValue)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_SAMPLE_RATE_SOURCE, source),
                         3, "Source");
	switch (source){
		case RSBTC_VAL_BB_IQ_DIGITAL_USER:
		case RSBTC_VAL_BB_IQ_DIGITAL_SIGN:	
			viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_BASEBAND_DIGITAL_IQ_OUTPUT_SAMPLE_RATE, sampleRateValue),
                         4, "Sample Rate Value");	
		break;
		case RSBTC_VAL_BB_IQ_DIGITAL_OUT:
		break;
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
   

/// HIFN  This function configures Tx modulator interferer.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_INTERFERER_SIGNAL_SOURCE
/// HIFN     RSBTC_ATTR_INTERFERER_SIGNAL_ROUTING
/// HIFN     RSBTC_ATTR_INTERFERER_SIGNAL_FREQUENCY_OFFSET
/// HIFN     RSBTC_ATTR_INTERFERER_SIGNAL_REFERENCE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:DM:ISRCe
/// HIFN     [SOURce<hw>]:DM:IADDition
/// HIFN     [SOURce<hw>]:DM:IFRequency
/// HIFN     [SOURce<hw>]:DM:IREFerence
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the interferer signal generator source.
/// HIPAR routing/Adds the interferer signal to the internal data stream.
/// HIPAR frequencyOffset/Shifts the frequency of the interferer signal. Reference point for the 
/// HIPAR frequencyOffset/shift is the RF frequency set under "Frequency".
/// HIPAR reference/This control determines how the level of the interferer signal is set.
ViStatus _VI_FUNC rsbtc_ConfigureInterferer(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViInt32	routing,
	ViReal64	frequencyOffset,
	ViInt32	reference
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_INTERFERER_SIGNAL_SOURCE,
                                                source), 3, "Source");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_INTERFERER_SIGNAL_ROUTING,
                                               routing), 4, "Routing");
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_INTERFERER_SIGNAL_FREQUENCY_OFFSET,
                                                frequencyOffset), 5, "Frequency Offset");

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_INTERFERER_SIGNAL_REFERENCE,
                                                reference), 6, "Reference");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function selects the file.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:]DISTortion:TX:NLINearity:LOAD
/// HIFN     [SOURce<device>:]DISTortion:RX:NLINearity:LOAD
/// HIFN     [SOURce<device>:]DISTortion:TX:NLINearity:STORe
/// HIFN     [SOURce<device>:]DISTortion:RX:NLINearity:STORe
/// HIFN     [SOURce<device>:]DISTortion:TX:FREQuency:RESPonse:LOAD
/// HIFN     [SOURce<device>:]DISTortion:TX:FREQuency:RESPonse:STORe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR operation/Selects operation.
/// HIPAR filename/This control specifies the filename.
ViStatus _VI_FUNC rsbtc_DistortionFileOperations (ViSession instrSession,
                                                  ViInt32 path, ViInt32 operation,
                                                  ViString filename)
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");

    if (!filename) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Filename");
    
           switch (operation){
            case RSBTC_VAL_DISTORTION_FREQ_RESPONSE:
                sprintf (buffer,"SOUR%ld:DIST:TX:FREQ:RESP:LOAD \"%s\"", path, filename);   
            break;
        
            case RSBTC_VAL_DISTORTION_NONLINEARITY:
                sprintf (buffer,"SOUR%ld:DIST:TX:NLIN:LOAD \"%s\"", path, filename);
            break;
	
            case RSBTC_VAL_DISTORTION_LOAD_RX_NONLINEARITY:
                sprintf (buffer,"SOUR%ld:DIST:RX:NLIN:LOAD \"%s\"", path, filename);      
            break;
			
            case RSBTC_VAL_DISTORTION_SAVE_FREQ_RESPONSE:
                sprintf (buffer,"SOUR%ld:DIST:TX:FREQ:RESP:STOR \"%s\"", path, filename);
            break;
        
            case RSBTC_VAL_DISTORTION_SAVE_TX_NONLINEARITY:
                sprintf (buffer,"SOUR%ld:DIST:TX:NLIN:STOR \"%s\"", path, filename);
            break;
			
			case RSBTC_VAL_DISTORTION_SAVE_RX_NONLINEARITY:
                sprintf (buffer,"SOUR%ld:DIST:RX:NLIN:STOR \"%s\"", path, filename);      
            break;
        
			default:
           		viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Operation"); 
        } 
    
    viCheckErr(rsbtc_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function loads the nonlinear characteristics file. 
/// HIFN     save the nonlinear characteristics in a file to reuse them.
/// HIFN     
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_TX_DISTORTION_LIMITER
/// HIFN     RSBTC_ATTR_TX_DISTORTION_LIMITER_POSITION
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:]DISTortion:TX:NLINearity:LIMiter:STATe
/// HIFN     [SOURce<device>:]DISTortion:TX:NLINearity:LIMiter:POSition
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR txDistortionLimiter/Enables or disables the limiter that clips all amplitude components 
/// HIPAR txDistortionLimiter/above the level defined under 'Limiter Position'.
/// HIPAR limiterPosition/Defines the limit level in % referenced to full scale. The unit circle 
/// HIPAR limiterPosition/corresponds to 100 %.
ViStatus _VI_FUNC rsbtc_ConfigureDistortionLimiter (ViSession instrSession,
                                                    ViInt32 path,
                                                    ViBoolean txDistortionLimiter,
													ViReal64 limiterPosition)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_TX_DISTORTION_LIMITER,
                                                txDistortionLimiter), 3, "Tx Distortion Limiter");
	
	if (txDistortionLimiter == VI_TRUE)
    /*	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_TX_DISTORTION_LIMITER_POSITION,
                                               (ViInt32) limiterPosition), 4, "Limiter Position"); */
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_TX_DISTORTION_LIMITER_POSITION,
                                               limiterPosition), 4, "Limiter Position");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables/disables the selected path for the selected 
/// HIFN  fading configuration.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_SIMULATOR_STATE
/// HIFN     RSBTC_ATTR_FADING_BIRTH_DEATH_PROPAGATION_STATE
/// HIFN     RSBTC_ATTR_FADING_MOVING_PROPAGATION_STATE
/// HIFN     RSBTC_ATTR_FADING_2_CHANNEL_INTERFERER_STATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:STATe ON | OFF
/// HIFN     [SOURce<hw>]:FSIMulator:BIRThdeath:STATe ON | OFF
/// HIFN     [SOURce<hw>]:FSIMulator:MDELay:STATe ON | OFF
/// HIFN     [SOURce<hw>]:FSIMulator:P2DYN:STATe ON | OFF
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR configuration/This control selects the fading configuration.
/// HIPAR state/Enables/disables the selected path for the fading configurations.
ViStatus _VI_FUNC rsbtc_FadingConfiguration(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	configuration,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    switch (configuration)
	{
		case RSBTC_VAL_FADING_STANDARD_DELAY:
			
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_SIMULATOR_STATE,
                                                 state), 4, "State");
		break;
		
		case RSBTC_VAL_FADING_BIRTH_DEATH_PROP:
		
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_BIRTH_DEATH_PROPAGATION_STATE,
                                                 state), 4, "State");
		break;
		
		case RSBTC_VAL_FADING_MOVING_PROPAGATION:
			
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_MOVING_PROPAGATION_STATE,
                                                 state), 4, "State");
		break;
		
		case RSBTC_VAL_FADING_2CH_INTERFERER:
			
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_2_CHANNEL_INTERFERER_STATE,
                                                 state), 4, "State");
		break;
		
		default:
		    viCheckParm (RS_ERROR_INVALID_PARAMETER, 3,"Configuration");
        break;
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the fading mode configuration.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_CONFIGURATION
/// HIFN     RSBTC_ATTR_FADING_SIMULATOR_SIGNAL_ROUTING
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:CONFig
/// HIFN     [SOURce<hw>]:SCONfig:FADing
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/This control selects the fading configuration.
/// HIPAR signalRouting/Defines the signal routing. The available values depend on the number 
/// HIPAR signalRouting/of paths, required option.
ViStatus _VI_FUNC rsbtc_ConfigureFadingMode(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mode,
	ViInt32	signalRouting
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_CONFIGURATION, mode
                                               ), 3, "Mode");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_SIMULATOR_SIGNAL_ROUTING, signalRouting
                                               ), 4, "Signal Routing");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function stores or recalls fading simulator settings in the 
/// HIFN  specified file.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_LOAD_FILE
/// HIFN     RSBTC_ATTR_FADING_STORE_FILE
/// HIFN     RSBTC_ATTR_FADING_DELETE_FILE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:LOAD
/// HIFN     [SOURce<hw>]:FSIMulator:STORe
/// HIFN     [SOURce<hw>]:FSIMulator:DELete
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR operation/Selects operation.
/// HIPAR source/This control specifies the source of the operation to be performed. If 
/// HIPAR source/the operation requires a single parameter, this control specifies that 
/// HIPAR source/parameter.
ViStatus _VI_FUNC rsbtc_StoreAndLoadFadingProfile(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	operation,
	ViString	source
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    switch (operation)
	{
		case RSBTC_VAL_SAVE:
		
        viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_LOAD_FILE,
                                                source), 4, "");
			
		break;
		
		case RSBTC_VAL_RECALL:
		
		viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_STORE_FILE,
                                                source), 4, "");
			
		break;	
		
		case RSBTC_VAL_DELETE:
		
		viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_DELETE_FILE,
                                                source), 4, "");
			
		break;	
		
		default:
		viCheckParm (RS_ERROR_INVALID_PARAMETER,3,"operation");
		
        break;
	}
   
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads out the files with fading settings in the default 
/// HIFN  directory. 
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) The default directory is set with the command MMEM:CDIRectory. A 
/// HIFN  path can also be specified in command :SOUR:CORR:CSET:CAT?, in which 
/// HIFN  case the files in the specified directory are read. Only files with the 
/// HIFN  file ending *.fad are read out.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:CATalog?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the default directory. 
/// HIPAR returnedValues/Returns the size of string returned from the instrument.
ViStatus _VI_FUNC rsbtc_FadingCatalog(
	ViSession	instrSession,
	ViInt32	path,
	ViString	directory,
	ViInt32	bufferSize,
	ViChar	output[],
	ViInt32*	returnedValues
)
{
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0, len = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
      
    if (Rs_Simulating(instrSession) == 0){                /* call only when locked */

	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");

    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    viCheckErr( viPrintf (instrSession, ":MMEM:CDIR '%s'\n", directory)); 
    viCheckErr( viPrintf (instrSession, "SOUR%ld:FSIM:CAT?\n", path));
   
    
    viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) 
    {
        len = (ViUInt32) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize);
        strncpy(output, pbuffer, len);
        output[len] = '\0';
    }
    
    free(pbuffer);
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    }
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function selects a predefined fading simulator setting which 
/// HIFN  complies with the test specifications found in the common Broadcast 
/// HIFN  standards. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_STANDARD_PARAMETER_SET
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:STANdard
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR standardParameterSet/This control selects fading simulator standard set.
ViStatus _VI_FUNC rsbtc_ConfigureFadingStandardSet(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	standardParameterSet
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_STANDARD_PARAMETER_SET, standardParameterSet
                                               ), 3, "Standard Parameter Set");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function enables/disables the selected path for the selected 
/// HIFN  fading configuration.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_STATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:STATe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR configuration/This control selects the fading configuration.
/// HIPAR group/Selects the group.
/// HIPAR fadingPath/Selects the path.
/// HIPAR state/Enables/disables the selected path for selected fading configuration.
ViStatus _VI_FUNC rsbtc_EnableFadingPath(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	configuration,
	ViInt32	group,
	ViInt32	fadingPath,
	ViBoolean	state
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (group, 1, 8), 4, "Group");
    
    sprintf (rep_cap_1, "G%ld", group);  
	
	viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 5), 5, "Fading Path");
    
    sprintf (rep_cap_2, ",P%ld", fadingPath);  
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);
	
	switch (configuration)
	{
		case RSBTC_VAL_FADING_STANDARD_DELAY:
			
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_STATE,
                                                 state), 6, "State");
		
		break;
		
		default:
		viCheckParm (RS_ERROR_INVALID_PARAMETER,3,"configuration");
        break;
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function select the fading profile for the paths.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_PROFILE
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:PROFile
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR configuration/This control selects the fading configuration.
/// HIPAR group/Selects the group.
/// HIPAR fadingPath/Selects the path.
/// HIPAR profile/Select the fading profile for the paths.
ViStatus _VI_FUNC rsbtc_ConfigureFadingPathProfile(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	configuration,
	ViInt32	group,
	ViInt32	fadingPath,
	ViInt32	profile
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (group, 1, 8), 4, "Group");
    
    sprintf (rep_cap_1, "G%ld", group);  
	
	viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 5), 5, "Fading Path");
    
    sprintf (rep_cap_2, ",P%ld", fadingPath);  
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);

	switch (configuration)
	{
	
	 case RSBTC_VAL_FADING_STANDARD_DELAY:
			
     viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_PROFILE,
                                                 profile), 6, "Profile");
	 break;
	 
	 default:
		viCheckParm (RS_ERROR_INVALID_PARAMETER,3,"configuration");
        break;
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function sets the value of selected numeric parameter of profile 
/// HIFN  table.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_PATH_LOSS
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_BASIC_DELAY
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_ADDITIONAL_DELAY
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_POWER_RATIO
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_CONST_PHASE
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_SPEED
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_FREQUENCY_RATIO
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_RESULTING_DOPPLER_SHIFT
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_CORRELATION_PATH_COEFFICIENT
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_CORRELATION_PATH_PHASE
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_LOGNORMAL_STATE_LOCAL_CONSTANT
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_LOGNORMAL_STATE_STANDARD_DEVIAION
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:LOSS
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:BDELay
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:ADELay
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:PRATio
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:CPHase
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:SPEed
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:FRATio
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:FDOPpler
/// HIFN     
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:CORRelation:COEFficient
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:CORRelation:PHASe
/// HIFN     
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:LOGNormal:LCONstant
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:LOGNormal:CSTD
/// HIFN     :CSTD
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR configuration/This control selects the fading configuration.
/// HIPAR group/Selects the group.
/// HIPAR fadingPath/Selects the path.
/// HIPAR parameterName/Select the fading profile parameter to be set.
/// HIPAR parameterValue/Sets the value of selected parameter.
ViStatus _VI_FUNC rsbtc_ConfigureFadingPathProfileTableNumeric(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	configuration,
	ViInt32	group,
	ViInt32	fadingPath,
	ViInt32	parameterName,
	ViReal64	parameterValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (group, 1, 8), 4, "Group");
    
    sprintf (rep_cap_1, "G%ld", group);  
	
	viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 5), 5, "Fading Path");
    
    sprintf (rep_cap_2, ",P%ld", fadingPath);  
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);

	configuration;

	switch (parameterName)
	{
	
	 case RSBTC_VAL_FADING_PATH_LOSS:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_PATH_LOSS,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_BASIC_DELAY:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_BASIC_DELAY,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_ADD_DELAY:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_ADDITIONAL_DELAY,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_POWER_RATIO:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_POWER_RATIO,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_CONST_PHASE:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_CONST_PHASE,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_SPEED:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_SPEED,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_FREQ_RATIO:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_FREQUENCY_RATIO,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_RES_DOPPLER_SHIFT:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_RESULTING_DOPPLER_SHIFT,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_CORRELATION_COEFFICIENT:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_CORRELATION_PATH_COEFFICIENT,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_CORRELATION_PHASE:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_CORRELATION_PATH_PHASE,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_LOGNORMAL_LOCAL_CONST:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_LOGNORMAL_STATE_LOCAL_CONSTANT,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_LOGNORMAL_STD_DEVIATION:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_LOGNORMAL_STATE_STANDARD_DEVIATION,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_FREQ_SHIFT:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_FREQUENCY_SHIFT,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	
	 case RSBTC_VAL_FADING_FREQ_SPREAD:
			
     viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_FREQUENCY_SPREAD,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 default:
		viCheckParm (RS_ERROR_INVALID_PARAMETER, 6, "Parameter Name");
        break;
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the value of selected boolean parameter of profile 
/// HIFN  table.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_CORRELATION_PATH
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_LOGNORMAL_STATE						 K
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:CORRelation:STATe
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:LOGNormal:STATe
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR configuration/This control selects the fading configuration.
/// HIPAR group/Selects the group.
/// HIPAR fadingPath/Selects the path.
/// HIPAR parameterName/Select the fading profile parameter to be set.
/// HIPAR parameterValue/Sets the value of selected parameter.
ViStatus _VI_FUNC rsbtc_ConfigureFadingPathProfileTableBoolean(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	configuration,
	ViInt32	group,
	ViInt32	fadingPath,
	ViInt32	parameterName,
	ViBoolean	parameterValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (group, 1, 8), 4, "Group");
    
    sprintf (rep_cap_1, "G%ld", group);  
	
	viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 5), 5, "Fading Path");
    
    sprintf (rep_cap_2, ",P%ld", fadingPath);  
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);

	configuration;
	switch (parameterName)
	{
	
	 case RSBTC_VAL_FADING_CORRELATION_PATH:
			
     viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_CORRELATION_PATH,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_LOGNORMAL_STATE:
			
     viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_LOGNORMAL_STATE,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 default:
		viCheckParm (RS_ERROR_INVALID_PARAMETER,6,"Parameter Name");
        break;
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function queries the value of selected resulting parameter of 
/// HIFN  profile table.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_RESULTING_DELAY
/// HIFN     RSBTC_ATTR_FADING_STANDARD_DELAY_RESULTING_DOPPLER_SHIFT
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:RDELay?
/// HIFN     [SOURce<hw>]:FSIMulator:DELay:GROup<1..8>:PATH<1..5>:FDOPpler?
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR configuration/This control selects the fading configuration.
/// HIPAR group/Selects the group.
/// HIPAR fadingPath/Selects the path.
/// HIPAR parameterName/Select the fading profile parameter to be queried.
/// HIPAR parameterValue/Returns the value of selected parameter.
ViStatus _VI_FUNC rsbtc_ReadFadingPathProfileTableResults(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	configuration,
	ViInt32	group,
	ViInt32	fadingPath,
	ViInt32	parameterName,
	ViReal64*	parameterValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	configuration;
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (group, 1, 8), 4, "Group");
    
    sprintf (rep_cap_1, "G%ld", group);  
	
	viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 5), 5, "Fading Path");
    
    sprintf (rep_cap_2, ",P%ld", fadingPath);  
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);

	switch (parameterName)
	{
	
	 case RSBTC_VAL_FADING_RES_DELAY:
			
     viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_RESULTING_DELAY,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 case RSBTC_VAL_FADING_RES_DOPPLER_SHIFT:
			
     viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_FADING_STANDARD_DELAY_RESULTING_DOPPLER_SHIFT,
                                                 parameterValue), 7, "Parameter Value");
	 break;
	 
	 default:
		viCheckParm (RS_ERROR_INVALID_PARAMETER,6,"Parameter Name");
        break;
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the value for the ratio or real part of the 
/// HIFN  correlation.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_MIMO_MATRIX_VALUE_COLUMN_MAGNITUDE
/// HIFN     RSBTC_ATTR_FADING_MIMO_MATRIX_VALUE_COLUMN_PHASE
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) The content depends on the "Data Format":
/// HIFN     First column: "Magnitude" or "Real" - Value for the ratio or real part 
/// HIFN  of the correlation.
/// HIFN     
/// HIFN     Second column: "Phase" or "Image" - Value for the phase or imaginary 
/// HIFN  part of the correlation.
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     
/// HIFN  [SOURce<device>:]FSIMulator:MIMO:TAP<channel>:MATRix:ROW<direction>:COLumn<steering>:MAGNitude
/// HIFN     
/// HIFN  [SOURce<device>:]FSIMulator:MIMO:TAP<channel>:MATRix:ROW<direction>:COLumn<steering>:PHASe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fadingPath/Selects the fading path number.
/// HIPAR direction/Signal routing.
/// HIPAR steering/Value pair number (= column number of the matrix).
/// HIPAR magnitudeReal/Sets the value for the ratio or real part of the correlation.
/// HIPAR phaseImaginary/Sets the value for the phase or imaginary part of the correlation.
ViStatus _VI_FUNC rsbtc_ConfigureFadingMIMOCorrelationMatrixTable
             (ViSession instrSession, ViInt32 path, ViInt32 fadingPath,
              ViInt32 direction, ViInt32 steering, ViReal64 magnitudeReal,
              ViReal64 phaseImaginary
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";
	ViChar	rep_cap_3[15] = "";   

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 20), 3, "Fading Path");
    
    sprintf (rep_cap_1, ",CH%ld", fadingPath);
	
	viCheckParm (rsbtc_invalidViInt32Range (direction, 1, 4), 4, "Direction");
    
    sprintf (rep_cap_2, ",DIR%ld", direction);  
	
	viCheckParm (rsbtc_invalidViInt32Range (steering, 1, 4), 5, "Steering");
    
    sprintf (rep_cap_3, ",COL%ld", steering);  
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);
	strcat (rep_cap, rep_cap_3); 

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_MIMO_MATRIX_VALUE_COLUMN_MAGNITUDE,
                                                magnitudeReal), 6, "Magnitude/Real");
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_MIMO_MATRIX_VALUE_COLUMN_PHASE,
                                                phaseImaginary), 7, "Phase/Imaginary");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
	

/// HIFN  This function sets the values for the gain/phase correlation for the 
/// HIFN  current path set under "<Current path number>".
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_MIMO_RELATIVE_TAP_VECTOR_GAIN
/// HIFN     RSBTC_ATTR_FADING_MIMO_RELATIVE_TAP_VECTOR_PHASE
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     
/// HIFN  [SOURce<device>:]FSIMulator:MIMO:TAP<channel>:GVECtor:ROW<direction>:GAIN
/// HIFN     
/// HIFN  [SOURce<device>:]FSIMulator:MIMO:TAP<channel>:GVECtor:ROW<direction>:PHASe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fadingPath/Selects the fading path number.
/// HIPAR direction/Signal routing.
/// HIPAR gain/Sets the relative gain.
/// HIPAR phase/Defines the phase shift.
ViStatus _VI_FUNC rsbtc_ConfigureFadingMIMORelativeTapGainVectorTable
             (ViSession instrSession, ViInt32 path, ViInt32 fadingPath,
              ViInt32 direction, ViReal64 gain, ViReal64 phase)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	ViChar	rep_cap_2[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 20), 3, "Fading Path");
    
    sprintf (rep_cap_1, ",CH%ld", fadingPath);
	
	viCheckParm (rsbtc_invalidViInt32Range (direction, 1, 4), 4, "Direction");
    
    sprintf (rep_cap_2, ",DIR%ld", direction);  
 
	
	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
	strcat (rep_cap, rep_cap_2);


	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_MIMO_RELATIVE_TAP_VECTOR_GAIN,
                                                gain), 5, "Gain");
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_FADING_MIMO_RELATIVE_TAP_VECTOR_PHASE,
                                                phase), 6, "Phase");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Presets the vector matrix to an unitary matrix.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fadingPath/Selects the fading path number.
ViStatus _VI_FUNC rsbtc_ConfigureFadingMIMORelativeTapGainVectorSetToUnity (ViSession instrSession,
                                                                            ViInt32 path,
                                                                            ViInt32 fadingPath)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (fadingPath, 1, 20), 3, "Fading Path");
    
    sprintf (rep_cap_1, ",CH%ld", fadingPath);

	strcat (rep_cap, "," );
	strcat (rep_cap, rep_cap_1);
    
    checkErr (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_MIMO_RELATIVE_TAP_VECTOR_SET_TO_UNITY, NULL));
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects fading simulator common settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_GENERAL_SPEED_UNIT
/// HIFN     RSBTC_ATTR_FADING_GENERAL_SIGNAL_DEDICATED_TO
/// HIFN     RSBTC_ATTR_FADING_GENERAL_VIRTUAL_RF
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:SPEed:UNIT
/// HIFN     [SOURce<hw>]:FSIMulator:SDEStination
/// HIFN     [SOURce<hw>]:FSIMulator:FREQuency
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR speedUnit/This control sets the default unit for the speed.
/// HIPAR signalDedicatedTo/Sets the RF frequency for calculating the Doppler shift.
/// HIPAR virtualRF/This control determines the virtual RF frequency if the baseband 
/// HIPAR virtualRF/signal is output (and not the RF signal) on the instrument. The entered 
/// HIPAR virtualRF/value is used as the basis for computing the Doppler shift.
ViStatus _VI_FUNC rsbtc_ConfigureFadingCommonSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	speedUnit,
	ViInt32	signalDedicatedTo,
	ViReal64	virtualRF
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_GENERAL_SPEED_UNIT, speedUnit
                                               ), 3, "Speed Unit");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_GENERAL_SIGNAL_DEDICATED_TO, signalDedicatedTo
                                               ), 4, "Signal Dedicated To");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_GENERAL_VIRTUAL_RF, virtualRF
                                               ), 5, "Virtual RF");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects fading simulator insertion loss settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_INSERTION_LOSS_MODE
/// HIFN     RSBTC_ATTR_FADING_INSERTION_LOSS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:ILOSs:MODE NORMal | LACP | USER
/// HIFN     [SOURce<hw>]:FSIMulator:ILOSs[:LOSS]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/Sets the insertion loss of the fading simulator.
/// HIPAR insertionLoss/This control sets the user-defined insertion loss of the fading 
/// HIPAR insertionLoss/simulator when User is selected.
ViStatus _VI_FUNC rsbtc_ConfigureFadingInsertionLoss(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mode,
	ViReal64	insertionLoss
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_INSERTION_LOSS_MODE, mode
                                               ), 3, "Mode");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_INSERTION_LOSS, insertionLoss
                                               ), 4, "Insertion Loss");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures fading simulator reference path settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_GENERAL_REFERENCE
/// HIFN     RSBTC_ATTR_FADING_GENERAL_COMMON_SPEED_FOR_ALL_PATHS
/// HIFN     RSBTC_ATTR_FADING_GENERAL_COMMON_DOPPLER_SHIFT_FOR_ALL_PATH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:FSIMulator:KCONstant
/// HIFN     [SOURce<hw>]:FSIMulator:CFDoppler ON | OFF
/// HIFN     [SOURce<hw>]:FSIMulator:CSPeed ON | OFF
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR reference/Defines which parameter is used as reference.
/// HIPAR commonSpeedAllPath/Activates/deactivates the same speed in all paths.
ViStatus _VI_FUNC rsbtc_ConfigureFadingReferenceSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	reference,
	ViBoolean	commonSpeedAllPath
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_GENERAL_REFERENCE, reference
                                               ), 3, "Mode");
	
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_FADING_GENERAL_COMMON_SPEED_FOR_ALL_PATHS, commonSpeedAllPath
                                               ), 4, "Common Speed All Path");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

 
/// HIFN  This function configures the external RF signal generator remote 
/// HIFN  connection parameters. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_TARGET_NAME
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_REMOTE_CONNECT
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_REMOTE_DISCONNECT
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:TNAMe
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:REMote:CONNect
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:REMote:DISConnect
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR stream/Selects the stream C or stream D.
/// HIPAR targetName/Sets the name of the external RF signal generator that is controlled 
/// HIPAR targetName/by the R&S BTC.
/// HIPAR remoteConnection/Enables or disables the remote connection to the external RF signal 
/// HIPAR remoteConnection/generator.    
ViStatus _VI_FUNC rsbtc_ConfigureFadingExternalRFRemoteConnection
             (ViSession instrSession, ViInt32 path, ViInt32 stream,
              ViString targetName, ViInt32 remoteConnection)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_stream[15] = "";
					  
    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (stream, 1, 2), 3, "Stream");    
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
 
    strcat (rep_cap, ",");
	sprintf(rep_cap_stream, ",ST%ld", stream);
	strcat (rep_cap, rep_cap_stream);

    viCheckParm(rsbtc_SetAttributeViString(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_TARGET_NAME, targetName), 4, "Target Name");
	
	switch (remoteConnection){
        case  RSBTC_VAL_CONNECT:
    		viCheckParm(rsbtc_SetAttributeViString(instrSession, rep_cap,
        	RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_REMOTE_CONNECT, NULL), 5, "Remote Connection");
	
        break;
	
		case RSBTC_VAL_DISCONNECT:
			viCheckParm(rsbtc_SetAttributeViString(instrSession, rep_cap,
        	RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_REMOTE_DISCONNECT, NULL), 5, "Remote Connection");
        break;
		
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 5, "Remote Connection"); 
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}	
			 
			 
/// HIFN  This function configures the coupling between R&S BTC and the RF 
/// HIFN  signal generator.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_COUPLING
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:RF:COUPling
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR stream/Selects the stream C or stream D.
/// HIPAR rfCoupling/Enables or disables the coupling between R&S BTC and the RF signal 
/// HIPAR rfCoupling/generator.			 
ViStatus _VI_FUNC rsbtc_ConfigureFadingExternalRFCoupling
             (ViSession instrSession, ViInt32 path, ViInt32 stream,
              ViBoolean RFCoupling)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_stream[15] = "";
					  
    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (stream, 1, 2), 3, "Stream");    
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
 
    strcat (rep_cap, ",");
	sprintf(rep_cap_stream, ",ST%ld", stream);
	strcat (rep_cap, rep_cap_stream);

    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_COUPLING, RFCoupling), 4, "RF Coupling");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}				 

/// HIFN  This function configures the external RF signal generator parameters. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_FREQUENCY
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_LEVEL
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_STATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:RF:FREQuency
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:RF:POWer
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:RF:STATe
/// HIFN     
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR stream/Selects the stream C or stream D.
/// HIPAR rfFrequency/Sets the RF frequency of the external RF signal generator.
/// HIPAR rfLevel/Sets the RF level of the external RF signal generator.
/// HIPAR rfState/Enables or disables the RF output in the external RF signal generator.			 
ViStatus _VI_FUNC rsbtc_ConfigureFadingExternalRFParameters
             (ViSession instrSession, ViInt32 path, ViInt32 stream,
              ViReal64 RFFrequency, ViReal64 RFLevel, ViBoolean RFState)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_stream[15] = "";
					  
    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (stream, 1, 2), 3, "Stream");    
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
 
    strcat (rep_cap, ",");
	sprintf(rep_cap_stream, ",ST%ld", stream);
	strcat (rep_cap, rep_cap_stream);

    viCheckParm(rsbtc_SetAttributeViReal64(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_FREQUENCY, RFFrequency), 4, "RF Frequency");
	
    viCheckParm(rsbtc_SetAttributeViReal64(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_LEVEL, RFLevel), 5, "RF Level");	

    viCheckParm(rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_RF_STATE, RFState), 6, "RF State");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}				 
			 
/// HIFN  This function returns the external RF signal generator parameters. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_REMOTE_CONNECTION_STATE
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_DIGITAL_IQ_CONNECTION_STATE
/// HIFN     RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_DIGITAL_IQ_CONNECTED_INSTRUMENT
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:RCONnection:STATe?
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:IQConnection:STATe?
/// HIFN     [SOURce<device>:]SCONfig:EXTernal:BBMM<ch>:INAMe?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR stream/Selects the stream C or stream D.
/// HIPAR remoteConnectionState/Displays whether a remote connection is established or not.
/// HIPAR digitalIQConnectionState/Queries whether a digital I/Q connection is established or not.
/// HIPAR digitalIQConnectedInstrument/Queries information on the external RF signal generator that is 
/// HIPAR digitalIQConnectedInstrument/connected to the DIG I/Q interface.
ViStatus _VI_FUNC rsbtc_ReadFadingExternalRFConnectionState(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	stream,
	ViInt32*	remoteConnectionState,
	ViInt32*	digitalIQConnectionState,
	ViInt32 bufferSize,
	ViChar	digitalIQConnectedInstrument[]
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";
	ViChar	rep_cap_stream[15] = "";
					  
    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (stream, 1, 2), 3, "Stream");    
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
 
    strcat (rep_cap, ",");
	sprintf(rep_cap_stream, ",ST%ld", stream);
	strcat (rep_cap, rep_cap_stream);

	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_REMOTE_CONNECTION_STATE, remoteConnectionState), 4, "Remote Connection State");
		
	viCheckParm(rsbtc_GetAttributeViInt32(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_DIGITAL_IQ_CONNECTION_STATE, digitalIQConnectionState), 5, "Digital IQ Connection State");
    
	viCheckParm(rsbtc_GetAttributeViString(instrSession, rep_cap,
        RSBTC_ATTR_FADING_EXTERNAL_RF_SIGNAL_GEN_DIGITAL_IQ_CONNECTED_INSTRUMENT, bufferSize, digitalIQConnectedInstrument), 7, " Digital IQ Connected Instrument");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function enables the noise generation.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_NOISE
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) Various types of noise (noise sources) can be superimposed on the 
/// HIFN  useful signal. You can choose between AWGN, IMPULSIVE NOISE and PHASE 
/// HIFN  NOISE. One or several types of noise may be superimposed at the same 
/// HIFN  time depending on the options installed.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe[:STATe] OFF | ADD | ONLY
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR noise/Switches the noise generator on or off. Selection is possible between 
/// HIPAR noise/a pure noise signal (Noise Only) and a useful signal with noise (Add).
ViStatus _VI_FUNC rsbtc_ConfigureAWGNNoise(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	noise
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
   
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_NOISE_A_NOISE_B, noise), 3, "Noise");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  Enables or disables the AWGN generator.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_NOISE_AWGN
/// HIFN     RSBTC_ATTR_NOISE_AWGN_CN
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:AWGN
/// HIFN     [SOURce<hw>]:NOISe:CN
/// HIFN     
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR awgn/Switches the AWGN on or off.
/// HIPAR cn/Sets the carrier/noise ratio (C/N).
ViStatus _VI_FUNC rsbtc_ConfigureAWGNGenerator(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	awgn,
	ViReal64	cn
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_NOISE_AWGN, awgn), 3, "AWGN");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_NOISE_AWGN_CN, cn), 4, "C/N");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function queries the noise Eb/N0 ratio
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_NOISE_AWGN_EB_N0_RATIO
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:EN?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR ebn0/Returns the noise Eb/N0 ratio.
ViStatus _VI_FUNC rsbtc_ReadAWGNNoiseEbN0(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64*	ebn0
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_AWGN_EB_N0_RATIO,
                                                ebn0), 3, "Eb/N0");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures noise generation parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_NOISE_AWGN_SETTINGS_BANDWIDTH_COUPLING
/// HIFN     RSBTC_ATTR_NOISE_AWGN_SETTINGS_RECEIVER_BANDWIDTH
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:COUPling
/// HIFN     [SOURce<hw>]:NOISe:BANDwidth
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR bandwidthCoupling/Enables or disables the coupling of the receiver bandwidth, that means 
/// HIPAR bandwidthCoupling/the noise bandwidth used for calculating the C/N.
/// HIPAR receiverBandwidth/Sets the receiver bandwidth where it is used for calculating the C/N 
/// HIPAR receiverBandwidth/ratio.
/// HIPAR generatedNoiseBandwidth/This control sets the generated noise bandwidth.
ViStatus _VI_FUNC rsbtc_ConfigureAWGNNoiseBandwidth(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	bandwidthCoupling,
	ViReal64	receiverBandwidth,
	ViReal64	generatedNoiseBandwidth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_AWGN_SETTINGS_BANDWIDTH_COUPLING, bandwidthCoupling
                                                ), 3, "Bandwidth Coupling");
	
	if (bandwidthCoupling == VI_FALSE)
	{
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_NOISE_AWGN_SETTINGS_RECEIVER_BANDWIDTH,
                                               receiverBandwidth), 4, "Receiver Bandwidth");
	}
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_AWGN_SETTINGS_GENERATED_NOISE_BANDWIDTH,
                                                generatedNoiseBandwidth), 5, "Generated Noise Bandwidth");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures pulse noise parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_NOISE_IMPULSIVE
/// HIFN     RSBTC_ATTR_NOISE_IMPULSIVE_CI
/// HIFN     RSBTC_ATTR_NOISE_IMPULSIVE_FRAME_DURATION
/// HIFN     RSBTC_ATTR_NOISE_IMPULSIVE_PULSES_PER_BURST
/// HIFN     RSBTC_ATTR_NOISE_PULSE_IMPULSIVE_SPACING_MIN
/// HIFN     RSBTC_ATTR_NOISE_PULSE_IMPULSIVE_SPACING_MAX
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:IMPulsive
/// HIFN     [SOURce<hw>]:NOISe:IMPulsive:CI
/// HIFN     [SOURce<hw>]:NOISe:IMPulsive:FRAMe
/// HIFN     [SOURce<hw>]:NOISe:IMPulsive:PULSes
/// HIFN     [SOURce<hw>]:NOISe:IMPulsive:MINSpace
/// HIFN     [SOURce<hw>]:NOISe:IMPulsive:MAXSpace
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR noiseImpulsive/Switches the impulsive noise generator on or off.
/// HIPAR ci/Sets the carrier/impulsive noise ratio (C/I).
/// HIPAR frameDuration/This control selects the frame duration of the Noise signal.
/// HIPAR pulsesperBurst/Switches on how many noise pulses per Burst are generated.
/// HIPAR pulseSpacingMin/Switches on the minimum distance of the impulses from each other 
/// HIPAR pulseSpacingMin/within a Bursts.
/// HIPAR pulseSpacingMax/Switches on the maximum distance of the impulses from each other 
/// HIPAR pulseSpacingMax/within a Bursts.
ViStatus _VI_FUNC rsbtc_ConfigureImpulsiveNoise(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	noiseImpulsive,
	ViReal64	ci,
	ViInt32	frameDuration,
	ViInt32	pulsesperBurst,
	ViReal64	pulseSpacingMin,
	ViReal64	pulseSpacingMax
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_IMPULSIVE,
                                                noiseImpulsive), 3, "Noise Impulsive");
	
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_NOISE_IMPULSIVE_CI, ci), 4, "C/I");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_IMPULSIVE_FRAME_DURATION, frameDuration), 5, "Frame Duration");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_NOISE_IMPULSIVE_PULSES_PER_BURST, pulsesperBurst), 6, "Pulses Per Burst");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_NOISE_IMPULSIVE_PULSE_SPACING_MAX, pulseSpacingMax), 8, "Pulse Spacing Max");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                 RSBTC_ATTR_NOISE_IMPULSIVE_PULSE_SPACING_MIN, pulseSpacingMin), 7, "Pulse Spacing Min");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures phase noise parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_PHASE_NOISE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:PHASenoise
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR phaseNoise/Enables or disables the phase noise generator.
ViStatus _VI_FUNC rsbtc_ConfigurePhaseNoiseState(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	phaseNoise
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                RSBTC_ATTR_PHASE_NOISE,
                                                phaseNoise), 3, "Phase Noise");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  Sets the single-sideband (SSB) spectrum of the signal carrier or, for 
/// HIFN  multicarrier methods, of all single carriers follows the filter curve 
/// HIFN  characteristics of the profile file.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_PHASE_NOISE_SSB_SHAPE_PROFILE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:PHASenoise:SHAPe:SELect
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR ssbShapeProfile/Sets the single-sideband (SSB) spectrum of the signal carrier or, for 
/// HIPAR ssbShapeProfile/multicarrier methods, of all single carriers follows the filter curve 
/// HIPAR ssbShapeProfile/characteristics of the profile file.
ViStatus _VI_FUNC rsbtc_ConfigurePhaseNoiseSSB(
	ViSession	instrSession,
	ViInt32	path,
	ViString	ssbShapeProfile
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
   
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_PHASE_NOISE_SSB_SHAPE_PROFILE, ssbShapeProfile), 3, "SSB Shape Profile");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function queries the level of phase noise at a specific frequency 
/// HIFN  offset (in the actual case it is for the frequency 100 Hz).
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_PHASE_NOISE_AT_100_HZ
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:PHASenoise:LEVel
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR result/Sets a single-sideband shape profile. For 5 points, define the 
/// HIPAR result/frequency/phase noise pairs. The resulting profile is displayed in the 
/// HIPAR result/left pane. The currently selected frequency position is indicated by a 
/// HIPAR result/vertical line.
/// HIPAR path/This control selects the path.
ViStatus _VI_FUNC rsbtc_ConfigurePhaseNoiseLevel(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	result
	)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_PHASE_NOISE_AT_100_HZ,
                                                result), 3, "Result");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN   This function sets phasenoise frequency. 
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:PHASenoise:FREQuency{1..5} 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsbtc_ConfigurePhaseNoiseFrequency(
	ViSession	instrSession,
	ViInt32	path,
		ViInt32	pointNo,  
	ViReal64	frequency
	)
{
    ViStatus	error = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");  
	viCheckParm (rsbtc_invalidViInt32Range (pointNo, 1, 5), 2, "Point No.");  

	sprintf (buffer,"SOUR%ld:NOIS:PHAS:FREQ%ld %le\n", path, pointNo, frequency);	

    viCheckErr( viPrintf (instrSession, "%s", buffer));
    viCheckErr(rsbtc_CheckStatus (instrSession));          
   
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function stores or recalls noise settings in the specified file.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_NOISE_SAVE_USER_PROFILE
/// HIFN     RSBTC_ATTR_NOISE_SELECT
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:NOISe:STORe
/// HIFN     [SOURce<hw>]:NOISe:LOAD
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR operation/Selects operation.
/// HIPAR source/This control specifies the source of the operation to be performed. If 
/// HIPAR source/the operation requires a single parameter, this control specifies that 
/// HIPAR source/parameter.
ViStatus _VI_FUNC rsbtc_NoiseFileOperations(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	operation,
	ViString	source
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	switch (operation)
	{
		case RSBTC_VAL_SAVE:
			
			viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_SAVE_USER_PROFILE,
                                                source), 4, "Source");
			
		break;
			
		case RSBTC_VAL_RECALL:
			
			viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_NOISE_SELECT,
                                                source), 4, "Source");
			
		break;
		
		default:
		    viCheckParm (RS_ERROR_INVALID_PARAMETER,3,"Operation");
            break;
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Tx Frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR frequency/Sets the frequency of the RF output. The entered and displayed 
/// HIPAR frequency/frequency corresponds to the frequency of the RF output, that means any 
/// HIPAR frequency/entered offset is not taken into account. The available range depends 
/// HIPAR frequency/on the installed options:
/// HIPAR frequencyOffset/Used to take the frequency offset of a subsequent device (e.g. a 
/// HIPAR frequencyOffset/mixer) into account. Enter the frequency offset of a subsequent device.
ViStatus _VI_FUNC rsbtc_ConfigureFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	frequency,
	ViReal64	frequencyOffset
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_FREQUENCY,
                                             frequency), 3, "Frequency");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_FREQUENCY_OFFSET,
                                             frequencyOffset), 4, "Frequency Offset");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures local oscillator coupling. Coupling 
/// HIFN  distributes the local oscillator signal so that multiple RF signals can 
/// HIFN  be driven by the same local oscillator signal. For 2 paths, this is 
/// HIFN  mandatory for minimizing the phase drift between the RF signals.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/Selects the signal that is used for the local oscillator signal. 
/// HIPAR outState/Enables/disables the local oscillator output.
ViStatus _VI_FUNC rsbtc_ConfigureLocalOscillatorCoupling(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mode,
	ViBoolean	outState
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LOCAL_OSCILLATOR_MODE,
                                             mode), 3, "Mode");
    
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_LOCAL_OSCILLATOR_OUT_STATE,
                                              outState), 4, "Out State");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function selects frequency channel table operations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR operation/Selects operation.
/// HIPAR channelName/This control specified frequency channel table.
ViStatus _VI_FUNC rsbtc_FrequencyChannelTableOperations(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	operation,
	ViString	channelName
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_RF_SIGNAL_CHANNEL_TABLE_CHANNEL_FILE,
                          RSBTC_ATTR_RF_SIGNAL_CHANNEL_TABLE_STORE,
                          RSBTC_ATTR_RF_SIGNAL_CHANNEL_TABLE_DELETE};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (operation, RSBTC_VAL_FREQ_CHAN_TAB_SELECT, RSBTC_VAL_FREQ_CHAN_TAB_DELETE), 3, "Operation");
    
    viCheckParm (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                             attr[operation],
                                             channelName), 4, "Channel Name");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures channel table frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR channel/Sets the channel.
/// HIPAR channelName/This control specified frequency channel table.
/// HIPAR channelFrequency/Sets the frequency of RF output.
ViStatus _VI_FUNC rsbtc_ConfigureChannelTableFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	channel,
	ViString	channelName,
	ViReal64	channelFrequency
)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
    viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
	viCheckParm (rsbtc_invalidViInt32Range (channel, 1, 100), 3, "Channel");
	viCheckParm (rsbtc_invalidViReal64Range (channelFrequency, 300.0e3, 3.0e9), 5, "Channel Frequency");
  
    viCheckErr (viPrintf (instrSession, "SOUR%ld:FREQ:CHAN:TABL:NAME %ld,\"%s\"\n", path, channel, channelName)); 
        
    viCheckErr (viPrintf (instrSession, "SOUR%ld:FREQ:CHAN:TABL:FREQ %ld,%lf\n", path, channel, channelFrequency));   

    viCheckErr(rsbtc_CheckStatus (instrSession));
	
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function configures the external reference parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR source/Sets the external reference frequency source. The signal is output at 
/// HIPAR source/"REF OUT".
/// HIPAR adjustmentState/Sets adjustment method for the internal reference frequency.
/// HIPAR adjustmentDACValue/Sets a user-defined adjustment value for the internal reference 
/// HIPAR adjustmentDACValue/frequency.
/// HIPAR externalReferenceFrequency/Set the frequency of the external reference in order to ensure that 
/// HIPAR externalReferenceFrequency/the R&S BTC will properly synchronize to the external reference signal.
/// HIPAR synchronizationBandwidth/Sets the synchronization bandwidth for an external reference signal.
ViStatus _VI_FUNC rsbtc_ConfigureExternalReferenceFrequency(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	source,
	ViBoolean	adjustmentState,
	ViInt32	adjustmentDACValue,
	ViInt32	externalReferenceFrequency,
	ViInt32	synchronizationBandwidth
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_EXTERNAL_REF_FREQ_SOURCE,
                                            source), 3, "Source");

	if (source == RSBTC_VAL_ROSC_SOURCE_INT)
	{
		viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
	                                              RSBTC_ATTR_RF_SIGNAL_EXTERNAL_REF_FREQ_ADJUSTMENT_STATE,
	                                              adjustmentState), 4, "Adjustment State");

		if (adjustmentState == VI_TRUE)
		{
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
		                                            RSBTC_ATTR_RF_SIGNAL_EXTERNAL_REF_FREQ_ADJUSTMENT_DAC_VALUE,
		                                            adjustmentDACValue), 5, "Adjustment DAC Value");
		}
	}
	else
	{
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                            RSBTC_ATTR_RF_SIGNAL_EXTERNAL_REF_FREQUENCY,
	                                            externalReferenceFrequency), 6, "External Reference Frequency");
    
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
	                                            RSBTC_ATTR_RF_SIGNAL_EXTERNAL_REF_FREQ_SYNC_BANDWIDTH,
	                                            synchronizationBandwidth), 7, "Synchronization Bandwidth");
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures level settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/Allows to optimize the RF output signal for applications, where 
/// HIPAR mode/improved harmonic distortion or improved wideband noise is required.
/// HIPAR settingCharacteristic/Selects additional quality characteristics to optimize the behavior of 
/// HIPAR settingCharacteristic/the RF signal level for the corresponding application.
/// HIPAR level/Sets the level of the RF signal. This value is supplied at the output 
/// HIPAR level/connector. Any offset that is entered is not taken into account.
/// HIPAR userLimit/Sets a user limit for the PEP value.
/// HIPAR offset/Used to take the level offset of a subsequent device (e.g. an 
/// HIPAR offset/attenuator or amplifier) into account.
ViStatus _VI_FUNC rsbtc_ConfigureLevel(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	mode,
	ViInt32	settingCharacteristic,
	ViReal64	level,
	ViReal64	userLimit,
	ViReal64	offset
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_SETTINGS_MODE,
                                            mode), 3, "Mode");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_SETTING_CHARACTERISTIC,
                                            settingCharacteristic), 4, "Setting Characteristic");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL,
                                             level), 5, "Level");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_USER_LIMIT_PEP,
                                             userLimit), 6, "User Limit");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_OFFSET,
                                             offset), 7, "Offset");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures Tx Level of the RF signal.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_LEVEL
/// HIFN     RSBTC_ATTR_RF_SIGNAL_VOLTAGE_LEVEL
/// HIFN     RSBTC_ATTR_RF_SIGNAL_LEVEL_UNIT
/// HIFN     RSBTC_ATTR_RF_SIGNAL_OUTPUT_STATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<device>]:POWer[:LEVel][:IMMediate][:AMPLitude]
/// HIFN     [SOURce<device>]:VOLTage[:LEVel][:IMMediate][:AMPLitude]
/// HIFN     UNIT<device>:VOLTage
/// HIFN     OUTPut<device>[:STATe]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR level/Sets the level of the RF signal. This value is supplied at the output 
/// HIPAR level/connector. Any offset that is entered is not taken into account.
/// HIPAR levelUnit/Sets the units for power.
/// HIPAR rf/Switches the RF output on or off.
ViStatus _VI_FUNC rsbtc_ConfigureLevelWithUnits (ViSession instrSession, ViInt32 path, ViReal64 level,
                                        ViInt32 levelUnit, ViBoolean rf)
{
    ViStatus    error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";   
	
    checkErr( Rs_LockSession (instrSession, NULL));
	checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));     	
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession,rep_cap, RSBTC_ATTR_RF_SIGNAL_LEVEL_UNIT, levelUnit),
                                4, "Level Unit");
	if (levelUnit == RSBTC_VAL_POW_LEV_DBM) {
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_LEVEL, level),
                                3, "Level");
	}
    else {
		
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_VOLTAGE_LEVEL, level),
                                3, "Level");
	}
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_OUTPUT_STATE, rf),
                                5, "RF");
	                                 
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function configures level attenuator settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR attenuatorMode/Sets attenuator mode.
/// HIPAR attenuation/Sets the attenuation level.
ViStatus _VI_FUNC rsbtc_ConfigureAttenuator(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	attenuatorMode,
	ViReal64	attenuation
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_ATTENUATOR_MODE,
                                            attenuatorMode), 3, "Attenuator Mode");
    
	if (attenuatorMode == RSBTC_RF_LEVEL_ATTENUATOR_MODE_MANUAL)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_ATTENUATION,
	                                             attenuation), 4, "Attenuation");
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Automatic Level Control system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Switches automatic level control.
/// HIPAR detectorSensitivity/Determines the degree to which the internal level detector responds to 
/// HIPAR detectorSensitivity/level changes.
/// HIPAR sampleLevel/Sets the sample level of the automatic level control.
ViStatus _VI_FUNC rsbtc_ConfigureAutomaticLevelControl(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	state,
	ViInt32	detectorSensitivity,
	ViInt32	sampleLevel
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_ALC_STATE,
                                            state), 3, "State");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_ALC_DETECTOR_SENSITIVITY,
                                            detectorSensitivity), 5, "Detector Sensitivity");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_ALC_SAMPLE_LEVEL,
                                            sampleLevel), 6, "Sample Level");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function determines the mode of the device and also by what 
/// HIFN  commands the output frequency is determined.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the frequency sweep.
/// HIPAR sweepMode/Sets the sweep mode.
ViStatus _VI_FUNC rsbtc_ConfigureFrequencySweep(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViInt32	sweepMode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_STATE,
                                              state), 3, "State");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_MODE,
                                            sweepMode), 4, "Sweep Mode");
    
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Tx Frequency Sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR settingType/This control determines the type of setting the sweep range.
/// HIPAR startFrequency/Sets the start frequency.
/// HIPAR stopFrequency/Sets the stop frequency for the sweep.
/// HIPAR centerFrequency/Sets the center frequency.
/// HIPAR frequencySpan/Sets the span for the sweep.
ViStatus _VI_FUNC rsbtc_ConfigureFrequencySweepRange(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	settingType,
	ViReal64	startFrequency,
	ViReal64	stopFrequency,
	ViReal64	centerFrequency,
	ViReal64	frequencySpan
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_invalidViInt32Range (settingType, RSBTC_SWEEP_START, RSBTC_SWEEP_CENTER), 4, "Setting Type");
    
    if (settingType == RSBTC_SWEEP_START)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_START,
	                                             startFrequency), 5, "Start Frequency");
    
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_STOP,
	                                             stopFrequency), 6, "Stop Frequency");
	}
	else
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
		                                         RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_CENTER,
		                                         centerFrequency), 7, "Center Frequency");

		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
		                                         RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_SPAN,
		                                         frequencySpan), 8, "Frequency Span");
	}

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Tx Frequency Sweep Step.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR sweepSpacing/Sets the type of progressive step size during the sweep.
/// HIPAR sweepStep/Sets the sweep frequency step.
/// HIPAR sweepDwell/Defines the duration of the individual sweep steps.
ViStatus _VI_FUNC rsbtc_ConfigureFrequencySweepStep(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	sweepSpacing,
	ViReal64	sweepStep,
	ViReal64	sweepDwell
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_STEP_LINEAR,
                          RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_STEP_LOGARITHMIC};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_SPACING,
                                            sweepSpacing), 3, "SweepSpacing");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             attr[sweepSpacing],
                                             sweepStep), 4, "Sweep Step");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_FREQUENCY_SWEEP_DWELL,
                                             sweepDwell), 5, "Sweep Dwell");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures the level sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the frequency sweep.
/// HIPAR mode/Sets the sweep mode.
ViStatus _VI_FUNC rsbtc_ConfigureLevelSweep(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViInt32	mode
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_STATE,
                                              state), 3, "State");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_MODE,
                                            mode), 4, "Mode");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Tx level Sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR startLevel/Sets the start level to define the level sweep range.
/// HIPAR stopLevel/Sets the stop level to define the level sweep range
ViStatus _VI_FUNC rsbtc_ConfigureLevelSweepRange(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	startLevel,
	ViReal64	stopLevel
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_START,
                                             startLevel), 3, "Start Level");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_STOP,
                                             stopLevel), 3, "Stop Level");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Tx level Sweep Step.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR shape/Selects the waveform shape of the sweep signal.
/// HIPAR step/Sets the step width for the level sweep steps. The step width is 
/// HIPAR step/specified logarithmically as constant fraction of the current level.
/// HIPAR dwell/Defines the duration of the individual sweep steps.
ViStatus _VI_FUNC rsbtc_ConfigureLevelSweepStep(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	shape,
	ViReal64	step,
	ViReal64	dwell
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_SHAPE,
                                            shape), 3, "Shape");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_STEP,
                                             step), 4, "Step");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_LEVEL_SWEEP_DWELL,
                                             dwell), 5, "Dwell");
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures Tx modulator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR signalSource/Selects the input. Select the signal type under "Signal Type".
/// HIPAR i_qWideband/Switches the cutoff frequency of the RF lowpass filters depending on 
/// HIPAR i_qWideband/the bandwidth of the externally supplied digital I/Q signal. Choose the 
/// HIPAR i_qWideband/setting depending on the bandwidth to avoid or decrease harmonics that 
/// HIPAR i_qWideband/impair the filter edges of the desired signal.
/// HIPAR optimizationMode/Selects the optimization mode.
/// HIPAR crestFactor/Sets the crest factor. The crest factor represents the ratio of the 
/// HIPAR crestFactor/peak voltage value to the RMS voltage value. The higher the crest 
/// HIPAR crestFactor/factor and resulting dynamics of a signal, the greater the requirement 
/// HIPAR crestFactor/for a power amplifier fed by the signal to be linear
/// HIPAR gain/Sets the level at the I/Q modulator.
ViStatus _VI_FUNC rsbtc_ConfigureModulation(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	signalSource,
	ViBoolean	i_qWideband,
	ViInt32	optimizationMode,
	ViInt32	gain,
	ViReal64	crestFactor
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";
	ViAttr      attr[] = {RSBTC_ATTR_RF_SIGNAL_MODULATION_INTERNAL_BASEBAND_GAIN,
                          RSBTC_ATTR_RF_SIGNAL_MODULATION_WIDEBAND_IQ_GAIN,
                          RSBTC_ATTR_RF_SIGNAL_MODULATION_WIDEBAND_IQ_GAIN};

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_MODULATION_SIGNAL_SOURCE,
                                            signalSource), 3, "Signal Source");
    
	viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_MODULATION_IQ_WIDEBAND,
                                              i_qWideband), 4, "I/Q Wideband");

	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            RSBTC_ATTR_RF_SIGNAL_MODULATION_OPTIMIZATION_MODE,
                                            optimizationMode), 5, "Optimization Mode");
    
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                            attr[signalSource],
                                            gain), 6, "Gain");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                             RSBTC_ATTR_RF_SIGNAL_MODULATION_WIDEBAND_IQ_CREST_FACTOR,
                                             crestFactor), 7, "Crest Factor");
    
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures baseband impairments parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the internal baseband I/Q impairments.
/// HIPAR iOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR iOffset/normalized to the peak envelope power (PEP) for the I signal component.
/// HIPAR qOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR qOffset/normalized to the peak envelope power (PEP) for the Q signal component.
/// HIPAR quadratureError/Defines the quadrature error.
/// HIPAR amplitudeImbalance/Defines an amplitude imbalance for the I and Q vector.
/// HIPAR i_qDelay/Sets the time delay of both I and Q vectors relative to the selected 
/// HIPAR i_qDelay/trigger.
ViStatus _VI_FUNC rsbtc_ConfigureBasebandImpairments(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViReal64	iOffset,
	ViReal64	qOffset,
	ViReal64	quadratureError,
	ViReal64	amplitudeImbalance,
	ViReal64	i_qDelay
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_MODULATION_BASEBAND_IMPAIRMENTS_STATE,
                                              state), 3, "State");

	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATION_BASEBAND_IMPAIRMENTS_I_OFFSET,
	                                             iOffset), 4, "I Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATION_BASEBAND_IMPAIRMENTS_Q_OFFSET,
	                                             qOffset), 5, "Q Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MOD_BB_IMPAIRMENTS_QUADRATURE_ERR,
	                                             quadratureError), 6, "Quadrature Error");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MOD_BB_IMPAIR_AMPLITUDE_IMBALANCE,
	                                             amplitudeImbalance), 7, "Amplitude Imbalance");
		
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATION_BASEBAND_IMPAIRMENTS_IQ_DELAY,
	                                             i_qDelay), 8, "I/Q Delay");
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function configures modulator impairments parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the I/Q impairment of the modulator.
/// HIPAR iOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR iOffset/normalized to the peak envelope power (PEP) for the I signal component.
/// HIPAR qOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR qOffset/normalized to the peak envelope power (PEP) for the Q signal component
/// HIPAR quadratureError/Defines the quadrature error.
/// HIPAR amplitudeImbalance/Defines an amplitude imbalance for the I and Q vector.
ViStatus _VI_FUNC rsbtc_ConfigureModulatorImpairments(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViReal64	iOffset,
	ViReal64	qOffset,
	ViReal64	quadratureError,
	ViReal64	amplitudeImbalance
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_MODULATOR_IMPAIRMENTS_STATE,
                                              state), 3, "State");

	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATOR_IMPAIRMENTS_I_OFFSET,
	                                             iOffset), 4, "I Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATOR_IMPAIRMENTS_Q_OFFSET,
	                                             qOffset), 5, "Q Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATOR_IMPAIRMENTS_QUADRATURE_ERROR,
	                                             quadratureError), 6, "Quadrature Error");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_MODULATOR_IMPAIRMENTS_AMPLITUDE_IMBALANCE,
	                                             amplitudeImbalance), 7, "Amplitude Imbalance");
	}
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}



/// HIFN  This function configures IQ Digital Output parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_STATE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_SAMPLE_RATE_SOURCE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_SAMPLE_RATE_VALUE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_SET_LEVEL_VIA
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_PEAK_LEVEL
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_LEVEL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:STATe
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:SRATe:SOURce
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:SRATe
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:POWer:VIA
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:POWer:PEP
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:POWer:LEVel
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the digital I/Q output.
/// HIPAR sampleRateSource/Sets the sample rate source.
/// HIPAR sampleRateValue/Sets the sample rate of the digital I/Q output signal.
/// HIPAR setLevelVia/Sets how the signal level is expressed.
/// HIPAR levelValue/Sets the level value, under 'Set Level Via' parameter.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalOutput(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean state,
	ViInt32	sampleRateSource,
	ViReal64 sampleRateValue,
	ViInt32	setLevelVia,
	ViReal64 levelValue
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_STATE, state),
                         3, "State");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_SAMPLE_RATE_SOURCE, sampleRateSource),
                         4, "Sample Rate Source");
	
	if (sampleRateSource == RSBTC_VAL_RF_MOD_IQ_DIGITAL_USER)  {
			viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_SAMPLE_RATE_VALUE, sampleRateValue),
                         5, "Sample Rate Value");
	}
  
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_SET_LEVEL_VIA, setLevelVia),
                         6, "Set Level Via");
		
	switch (setLevelVia){
        case RSBTC_VAL_RF_MOD_IQ_DIGITAL_PEAK_LEVEL:
    		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_PEAK_LEVEL, 
	            levelValue), 7, "Level Value");
        break;
        case RSBTC_VAL_RF_MOD_IQ_DIGITAL_LEVEL:
    		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_LEVEL, 
                levelValue), 7, "Level Value");
        break;
			
		default:
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 6, "Set Level Via"); 
   }	

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures IQ Digital Output user variation parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_USER_VARIATION_ACTIVE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_USER_VARIATION_STEP
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:POWer:STEP:MODE DEC|USER
/// HIFN     [SOURce<hw>]:IQ:OUTPut:DIGital:BBMM:POWer:STEP:INCRement
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR variationActive/Enables or disables the step width set under 'Variation Step'.
/// HIPAR userVariationStep/Sets a user-defined step width.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalOutputVariation(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32	variationActive,
	ViReal64	userVariationStep
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_USER_VARIATION_ACTIVE, variationActive),
                         3, "Variation Active");
	
	if (variationActive == RSBTC_VAL_RF_MOD_IQ_DIGITAL_USER_VARIATION_ON)
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_OUTPUT_USER_VARIATION_STEP, userVariationStep),
                         4, "User Variation Step");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures I/Q Digital impairments parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_STATE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_I_OFFSET
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_Q_OFFSET
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_QUADRATURE_ERROR
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_AMPLITUDE_IMBALANCE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:IMPairment:DIGital:BBMM[:STATe]
/// HIFN     [SOURce<hw>]:BB:IMPairment:DIGital:BBMM:LEAKage:I
/// HIFN     [SOURce<hw>]:BB:IMPairment:DIGital:BBMM:LEAKage:Q
/// HIFN     [SOURce<hw>]:BB:IMPairment:DIGital:BBMM:QUADrature[:ANGLe]
/// HIFN     [SOURce<hw>]:BB:IMPairment:DIGital:BBMM:IQRatio
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the I/Q impairment of the modulator.
/// HIPAR iOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR iOffset/normalized to the peak envelope power (PEP) for the I signal component.
/// HIPAR qOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR qOffset/normalized to the peak envelope power (PEP) for the Q signal component
/// HIPAR quadratureError/Defines the quadrature error.
/// HIPAR amplitudeImbalance/Defines an amplitude imbalance for the I and Q vector.
ViStatus _VI_FUNC rsbtc_ConfigureIQDigitalImpairments(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViReal64	iOffset,
	ViReal64	qOffset,
	ViReal64	quadratureError,
	ViReal64	amplitudeImbalance
)
{
    ViStatus	error = VI_SUCCESS;
 	ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_STATE,
                                              state), 3, "State");
	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_I_OFFSET,
	                                             iOffset), 4, "I Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_Q_OFFSET,
	                                             qOffset), 5, "Q Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_QUADRATURE_ERROR,
	                                             quadratureError), 6, "Quadrature Error");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_DIGITAL_IMPAIRMENTS_AMPLITUDE_IMBALANCE,
	                                             amplitudeImbalance), 7, "Amplitude Imbalance");
	}

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures IQ Analog Output parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_STATE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_TYPE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_MODE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_IQ_LEVEL_VP
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_COUPLE_IQ_BIAS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:STATe
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:TYPE
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:MODE
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:LEVel
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:BIAS:COUPling
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the analog I/Q output.
/// HIPAR iqOutputType/Sets the type of the output signal.
/// HIPAR mode/Sets whether the following parameters are alterable or read-only: 'I/Q 
/// HIPAR mode/Level Vp (EMF)' ,'I Settings / Q Settings'.
/// HIPAR iqLevelVp/Sets the output voltage for both signal components.
/// HIPAR coupleIQBias/Enables or disables the coupling of Bias (EMF).
ViStatus _VI_FUNC rsbtc_ConfigureIQAnalogOutput(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean state,
	ViInt32 iqOutputType,
	ViInt32	mode,
	ViReal64 iqLevelVp,
	ViBoolean coupleIQBias
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));

	
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_STATE, state),
                         3, "IQ Output Type");
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_TYPE, iqOutputType),
                         4, "Sample Rate Source");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_MODE, mode),
                         5, "Mode");

    if (mode == RSBTC_VAL_RF_MOD_IQ_ANALOG_OUT_MODE_VARIABLE) 
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_IQ_LEVEL_VP, iqLevelVp),
						 6, "IQ Level Vp");

 		viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_COUPLE_IQ_BIAS, coupleIQBias),
                         7, "Couple IQ Bias");
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures I/Q signal component.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_I_SETTINGS_BIAS
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_Q_SETTINGS_BIAS
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_I_SETTINGS_OFFSET
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_Q_SETTINGS_OFFSET
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:BIAS:I
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:BIAS:Q
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:OFFSet:I
/// HIFN     [SOURce<hw>]:IQ:OUTPut:ANALog:OFFSet:Q
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR iBias/This parameter defines the operating point of a DUT.
/// HIPAR iOffset/Sets an offset between the inverting and the non-inverting output.
/// HIPAR qBias/This parameter defines the operating point of a DUT.
/// HIPAR qOffset/Sets an offset between the inverting and the non-inverting output.
ViStatus _VI_FUNC rsbtc_ConfigureIQAnalogSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViReal64	iBias,
	ViReal64	iOffset,
	ViReal64	qBias,
	ViReal64	qOffset
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
	
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_I_SETTINGS_BIAS, iBias),
						 3, "I Bias");
	
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_I_SETTINGS_OFFSET, iOffset),
						 4, "I Offset");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_Q_SETTINGS_BIAS, qBias),
						 5, "Q Bias");

	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap, RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_OUTPUT_Q_SETTINGS_OFFSET, qOffset),
						 6, "Q Offset");


Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures I/Q Analog impairments parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_STATE
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_I_OFFSET
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_Q_OFFSET
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_QUADRATURE_ERROR
/// HIFN     RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_AMPLITUDE_IMBALANCE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:BB:IMPairment:ANALog:BBMM[:STATe]
/// HIFN     [SOURce<hw>]:BB:IMPairment:ANALog:BBMM:LEAKage:I
/// HIFN     [SOURce<hw>]:BB:IMPairment:ANALog:BBMM:LEAKage:Q
/// HIFN     [SOURce<hw>]:BB:IMPairment:ANALog:BBMM:QUADrature[:ANGLe]
/// HIFN     [SOURce<hw>]:BB:IMPairment:ANALog:BBMM:IQRatio
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR state/Enables or disables the I/Q impairment of the modulator.
/// HIPAR iOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR iOffset/normalized to the peak envelope power (PEP) for the I signal component.
/// HIPAR qOffset/Defines the residual carrier as a percentage of the amplitudes 
/// HIPAR qOffset/normalized to the peak envelope power (PEP) for the Q signal component
/// HIPAR quadratureError/Defines the quadrature error.
/// HIPAR amplitudeImbalance/Defines an amplitude imbalance for the I and Q vector.
ViStatus _VI_FUNC rsbtc_ConfigureIQAnalogImpairments(
	ViSession	instrSession,
	ViInt32	path,
	ViBoolean	state,
	ViReal64	iOffset,
	ViReal64	qOffset,
	ViReal64	quadratureError,
	ViReal64	amplitudeImbalance
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                              RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_STATE,
                                              state), 3, "State");

	if (state == VI_TRUE)
	{
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_I_OFFSET,
	                                             iOffset), 4, "I Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_Q_OFFSET,
	                                             qOffset), 5, "Q Offset");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_QUADRATURE_ERROR,
	                                             quadratureError), 6, "Quadrature Error");
	
		viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
	                                             RSBTC_ATTR_RF_SIGNAL_IQ_ANALOG_DIGITAL_IMPAIRMENTS_AMPLITUDE_IMBALANCE,
	                                             amplitudeImbalance), 7, "Amplitude Imbalance");
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*****************************************************************************
 *------------------------- BER Application ---------------------------------*
 *****************************************************************************/


/*============================================================================/
 * Function: Configure BER Serial Clock Data Input
 * Purpose:  This function configures parameters of BER measurement for 
 *           Serial Clock Data Input.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureBERDataInputInterface (ViSession instrSession,
                                                        ViInt32 input,
                                                        ViInt32 clockInput,
														ViInt32 dataInput,
                                                        ViInt32 enable,
                                                        ViInt32 inputFormat,
                                                        ViInt32 signal,
                                                        ViBoolean PIDFilter,
                                                        ViInt32 PID_Hex)
{
	ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
	
	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT, 
                input), 2, "Input");
	if (input == RSBTC_VAL_BER_INPUT_SERIAL){
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_CLOCK, 
                clockInput), 3, "Clock");
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_DATA, 
                dataInput), 4, "Data");
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_ENABLE, 
                enable), 5, "Enable");
	}  
	else {
		if ((input > RSBTC_VAL_BER_INPUT_SERIAL) || (input < RSBTC_VAL_BER_INPUT_IPA)) { 
			viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_FORMAT, 
                inputFormat), 6, "Input Format");
		}
		if (input >= RSBTC_VAL_BER_INPUT_TS1){
    		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_SIGNAL, 
                	signal), 7, "Signal");
			if (signal >= RSBTC_VAL_BER_SIGNAL_H184){  
		    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_PID_FILTER, 
		                PIDFilter), 8, "PID Filter");
				viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_PID, 
		                PID_Hex), 9, "PID Hex");
			}
		}
		
	}
		
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

 /// HIFN  This function sets the high/low threshold in volts for the serial data 
/// HIFN  input at the BER interfaces.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_BER_INPUT_TRESHOLD_CLK_DATA_EN
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     SENSe:BER[:INPut]:SERial:LEVel
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR tresholdClk/Data/En/This control sets the high/low threshold in volts for the serial data 
/// HIPAR tresholdClk/Data/En/input at the BER interfaces.
ViStatus _VI_FUNC rsbtc_ConfigureBERTresholdClkDataEn(
	ViSession	instrSession,
	ViReal64	tresholdClkDataEn
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
    
       viCheckParm(rsbtc_SetAttributeViReal64(instrSession, NULL,
        RSBTC_ATTR_BER_INPUT_TRESHOLD_CLK_DATA_EN, tresholdClkDataEn), 2, "Treshold Clk Data En");
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*===========================================================================*/
/* Function: Configure BER Gating Time
/* Purpose:  This function defines the gating time in hh:mm:ss format. Only 
/*           effective if gating mode with user defined time is selected.
/*===========================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureBERGatingTime (ViSession instrSession,
                                           ViString gatingTime, ViInt32 gatingMode)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));    

    viCheckErr (rsbtc_SetAttributeViString (instrSession, "", RSBTC_ATTR_BER_GATING_TIME_USER, gatingTime)); 
	    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_GATING_MODE, gatingMode), 3, "Gating Mode");

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;	
}

/*============================================================================/
 * Function: Configure BER Settings
 * Purpose:  This function configures settings of BER measurement.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigureBERInputSettings (ViSession instrSession,
                                                   ViInt32 payload, ViInt32 prbs)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_SETTINGS_PAYLOAD, 
                payload), 2, "Payload");
	
	if (payload == RSBTC_VAL_DTV_PAYLOAD_PRBS)  
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_BER_INPUT_SETTINGS_PRBS, 
                prbs), 3, "PRBS");

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*============================================================================/
 * Function: BER Measurement
 * Purpose:  This function queries selected BER measurement.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_BERMeasurement(ViSession   instrSession,
                                ViInt32 measurement,
                                ViInt32 bufferSize,
                                ViChar  result[])
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((measurement < RSBTC_VAL_BER_BER) || (measurement > RSBTC_VAL_BER_ALL))  
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Measurement");
    if (bufferSize<=0)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Buffer Size");                                 
    
    switch (measurement){
        case RSBTC_VAL_BER_BER:
            viCheckParm (rsbtc_GetAttributeViString (instrSession, "", RSBTC_ATTR_BER_RESULT, 
                        bufferSize, result), 4, "Result");  
        break;
        case RSBTC_VAL_BER_EVALUATION:
            viCheckParm (rsbtc_GetAttributeViString (instrSession, "", RSBTC_ATTR_BER_EVALUATION, 
                        bufferSize, result), 4, "Result");  
        break;
        case RSBTC_VAL_BER_STATE:
            viCheckParm (rsbtc_GetAttributeViString (instrSession, "", RSBTC_ATTR_BER_STATE, 
                        bufferSize, result), 4, "Result");  
        break;
        case RSBTC_VAL_BER_ERROR_COUNT:
            viCheckParm (rsbtc_GetAttributeViString (instrSession, "", RSBTC_ATTR_BER_ERROR_COUNT, 
                        bufferSize, result), 4, "Result");  
        break;
        case RSBTC_VAL_BER_GATING_TIME:
            viCheckParm (rsbtc_GetAttributeViString (instrSession, "", RSBTC_ATTR_BER_GATING_TIME, 
                        bufferSize, result), 4, "Result");  
        break;
        case RSBTC_VAL_BER_ALL:         
            viCheckParm (rsbtc_GetAttributeViString (instrSession, "", RSBTC_ATTR_BER_ALL_RESULTS, 
                        bufferSize, result), 4, "Result");  		   
        break;      
    }   
        
Error:      
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  Displays the name of the loaded file.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) If you want to load another file - The "File" dialog is displayed, 
/// HIFN  further details see "File and Data Management".
/// HIFN     
/// HIFN     (2) As soon as a file is loaded, it is played. Files that are accepted 
/// HIFN  as play files are listed in table "Files accepted as play files".
/// HIFN     
/// HIFN     (3) If there is a file with the same name and the *.scpi file 
/// HIFN  extension in the same directory, it will be loaded as well. The content 
/// HIFN  is interpreted as macro containing SCPI commands and will be processed 
/// HIFN  as described in "Running Scripts".
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_FILE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:PLAYfile[?]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fileName/Displays the name of the loaded file.
ViStatus _VI_FUNC rsbtc_SelectPlayFile(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViString	fileName
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);
	strcat (rep_cap, rep_cap_1);   
    
	viCheckErr (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_FILE, fileName));
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  Select the status of the Player.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_STATUS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:COMMand
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR command/Select the status of the file player.
ViStatus _VI_FUNC rsbtc_SelectFileCommandsControl(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViInt32	command
)
{
    ViStatus	error = VI_SUCCESS;
	ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);
    strcat (rep_cap, rep_cap_1);
	
    viCheckErr (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_STATUS, command));
    
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function reads player parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_FILE_DATE_AND_TIME
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_ORIGINAL_LOOP_TIME
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_ORIGINAL_DATA_RATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:READ{Hardware}:FILeinfo?
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:READ{Hardware}:PLAYfile:LENGth?
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:READ{Hardware}:ORIGtsrate?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR fileDateTime/Returns the date and time when the file was created and size of the 
/// HIPAR fileDateTime/file.
/// HIPAR originalLoopTime/Queries the Original Loop Time of the playback. The Original Loop Time 
/// HIPAR originalLoopTime/is calculated using the File Size parameter and Original TS Data Rate 
/// HIPAR originalLoopTime/setting.
/// HIPAR originalTSDataRate/Displays the original data rate.
ViStatus _VI_FUNC rsbtc_ReadPlayerParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViChar	fileDateTime[],
	ViChar	originalLoopTime[],
	ViReal64*	originalTSDataRate
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);  
	strcat (rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_GetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_PLAYER_FILE_DATE_AND_TIME,
												1024, fileDateTime), 4, "File Date/ Time");  
    
	viCheckParm (rsbtc_GetAttributeViString (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_PLAYER_ORIGINAL_LOOP_TIME, 1024, originalLoopTime
                                                ), 5, "Original Loop Time");
	
    viCheckParm (rsbtc_GetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_ORIGINAL_DATA_RATE,originalTSDataRate
                                               ), 6, "Original TS Data Rate");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  Configures the output data parameters.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_DATA_RATE
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_PACKET_LENGTH
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_NULLPACKET_STUFFING
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_STOP_DATA
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     SOURce<hw>:MMGen:PLAYer:CONFigure:TSRATE
/// HIFN     SOURce<hw>:MMGen:PLAYer:CONFigure:PLENgth
/// HIFN     SOURce<hw>:MMGen:PLAYer:CONFigure:STUFfing
/// HIFN     SOURce<hw>:MMGen:PLAYer:CONFigure:STOPdata
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR dataRate/Sets the output data rate of the player.
/// HIPAR nullpacketStuffing/Enables or disables stuffing. The data rate of the player should 
/// HIPAR nullpacketStuffing/exactly be the original data rate. This ensures that the time 
/// HIPAR nullpacketStuffing/references in the tables of the played TS stream are correct during 
/// HIPAR nullpacketStuffing/replay.
/// HIPAR stopData/Configures the behavior when in pause or stop status.
ViStatus _VI_FUNC rsbtc_ConfigurePlayerOutputParameters(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViReal64	dataRate,
	ViBoolean	nullpacketStuffing,
	ViInt32	stopData
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);    
    strcat (rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_DATA_RATE, dataRate), 4, "Data Rate");
	
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_NULLPACKET_STUFFING,
                                               nullpacketStuffing), 5, "Null Packet Stuffing");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_STOP_DATA,
                                                stopData), 6, "Stop Data");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  This function configures player output settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_TEST_TS_PACKET
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PID_TEST_PACKET
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PID
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PAYLOAD
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PRBS
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:TSPacket
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:PIDTestpack
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:PID
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:PAYLoad
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:PRBS[:SEQuence]
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR testTSPacket/Selects the structure of the generated test packets in pause or stop 
/// HIPAR testTSPacket/status.
/// HIPAR pidTestPacket/Defines the PID, if a header was set under "Test TS Packet".
/// HIPAR pid/Sets the header value. The available values depend on the setting 
/// HIPAR pid/under "PID Test Packet".
/// HIPAR payload/Defines the payload area content of the test packet. Also influences 
/// HIPAR payload/the payload of the generated stuffing packets while the player is 
/// HIPAR payload/running.
/// HIPAR prbs/Defines the period length of the PRBS sequence.
ViStatus _VI_FUNC rsbtc_ConfigurePlayerOutputSettings(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViInt32	testTSPacket,
	ViInt32	pidTestPacket,
	ViInt32	pid,
	ViInt32	payload,
	ViInt32	prbs
)
{
    ViStatus	error = VI_SUCCESS;
   	ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);    
    strcat (rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_TEST_TS_PACKET, testTSPacket
                                               ), 4, "Test TS Packet");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PID_TEST_PACKET, pidTestPacket
                                                ), 5, "Pid Test Packet");
	
	if (pidTestPacket == RSBTC_DTV_PID_TEST_VARIABLE) 
    	viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PID, pid
                                               ), 6, "PID");
	
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PAYLOAD,
                                                payload), 7, "Payload");
	
	if (payload == RSBTC_VAL_DTV_PAYLOAD_PRBS) 
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap, RSBTC_ATTR_DVBC2_CONFIGURING_PRBS, prbs),
                         7, "PRBS");  
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                                 RSBTC_ATTR_MM_GENERATOR_PLAYER_OUTPUT_SETTINGS_PRBS,
                                                 prbs), 8, "PRBS");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}


/// HIFN  Defines the start position in the loaded play file. Data which 
/// HIFN  chronologically precedes the start position is not replayed by the 
/// HIFN  player. The entered time must chronologically always precede the entry 
/// HIFN  under "Stop".
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAY_WINDOW_START
/// HIFN     RSBTC_ATTR_MM_GENERATOR_PLAY_WINDOW_STOP
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:SEEK:STARt
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:SEEK:STOP
/// HIFN     
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR start/Defines the start position in the loaded play file. Data which 
/// HIPAR start/chronologically precedes the start position is not replayed by the 
/// HIPAR start/player. The entered time must chronologically always precede the entry 
/// HIPAR start/under "Stop".
/// HIPAR stop/Defines the stop position in the loaded play file. Data which 
/// HIPAR stop/chronologically follows the stop position is not replayed by the 
/// HIPAR stop/player. When the player reaches this position, it returns to the start 
/// HIPAR stop/position (continuous play). The entered time must chronologically 
/// HIPAR stop/always follow the entry under "Start".
ViStatus _VI_FUNC rsbtc_ConfigurePlayFilePosition(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViReal64 start,
	ViReal64 stop
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);    
    strcat (rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAY_WINDOW_START, start), 4, "Start");
    
	viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_PLAY_WINDOW_STOP, stop), 5, "Stop");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Sets the default values for: 'Start' and 'Stop'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR player/This control selects the player.
ViStatus _VI_FUNC rsbtc_ConfigurePlayFileReset (ViSession instrSession,
                                                ViInt32 path, ViInt32 player)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);    
    strcat (rep_cap, rep_cap_1);
	
    viCheckErr (rsbtc_SetAttributeViString (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_PLAY_WINDOW_RESET, NULL));
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  Decodes the stream without interruption, if the play file is looping.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_MM_GENERATOR_SEAMLESS_LOOP_CONTINUITY_COUNTER
/// HIFN     RSBTC_ATTR_MM_GENERATOR_SEAMLESS_LOOP_PCR_DTS_PTS
/// HIFN     RSBTC_ATTR_MM_GENERATOR_SEAMLESS_LOOP_TDT_TOT
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:SEAMless:CC
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:SEAMless:PCR
/// HIFN     [SOURce<hw>]:MMGen:PLAYer:CONFigure:SEAMless:TT
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR continuityCounter/Enables or disables the correction of the continuity counters in the 
/// HIPAR continuityCounter/replayed TS data stream.
/// HIPAR pcrDTSPTS/Enables or disables the correction of the time stamps in the replayed 
/// HIPAR pcrDTSPTS/TS data stream.
/// HIPAR tdtTot/Enables or disables the correction of the time and date table in the 
/// HIPAR tdtTot/replayed TS data stream.
ViStatus _VI_FUNC rsbtc_ConfigurePlayerSeamlessLoop(
	ViSession	instrSession,
	ViInt32	path,
	ViInt32 player,
	ViBoolean	continuityCounter,
	ViBoolean	pcrDTSPTS,
	ViBoolean	tdtTot
)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[15] = "";

    checkErr (Rs_LockSession (instrSession, NULL));

	viCheckParm (rsbtc_invalidViInt32Range (player, 1, 2), 3, "Player");
	
    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	sprintf(rep_cap_1, ",PL%ld", player);    
    strcat (rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_SEAMLESS_LOOP_CONTINUITY_COUNTER, continuityCounter), 4, "Continuity Counter");
	
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                                RSBTC_ATTR_MM_GENERATOR_SEAMLESS_LOOP_PCR_DTS_PTS, pcrDTSPTS), 5, "PCR,DTS/PTS");
	
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, rep_cap,
                                               RSBTC_ATTR_MM_GENERATOR_SEAMLESS_LOOP_TDT_TOT, tdtTot), 6, "TDT/TOT");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*****************************************************************************
 *---------------------------- Gateway --------------------------------------*
 *****************************************************************************/
/// HIFN Disables the gateway or enables the standard-specific input signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR mode/Disables the gateway or enables the standard-specific input signal.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayMode (ViSession instrSession,
                                                 ViInt32 path, 
												 ViInt32 mode)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_MODE, mode), 3, "Mode");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Queries the current error message of the DVB-T2 MI gateway.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR bufferSize/Sets the size of memory allocated for Status Info. 
/// HIPAR statusInfo/Queries the current error message of the DVB-T2 MI gateway.
ViStatus _VI_FUNC rsbtc_GetMMGGatewayStatusInfo (ViSession instrSession,
                                                 ViInt32 path,
                                                 ViInt32 bufferSize,
                                                 ViChar statusInfo[])
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_GetAttributeViString(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_STATUS_INFO, bufferSize, statusInfo), 
											   4, "Status Info");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*****************************************************************************
 *---------------------------- Gateway DVBT2 MI------------------------------*
 *****************************************************************************/
/// HIFN Configures the multimedia generator gateway common parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR useCase/Disables the gateway or enables the standard-specific input signal.
/// HIPAR profiles/Sets the number of profiles.
/// HIPAR PLPGroups/Sets the number of physical layer pipe (PLP) groups that have
/// HIPAR PLPGroups/the same group ID.
/// HIPAR PLPs/Sets the number of PLPs, including common PLPs
/// HIPAR vVStreamGeneration/Allows to generate test patterns for multiple PLP transmission.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIInput (ViSession instrSession,
                                                         ViInt32 path,
                                                         ViInt32 useCase,
                                                         ViInt32 profiles,
                                                         ViInt32 PLPGroups,
                                                         ViInt32 PLPs,
                                                         ViBoolean vVStreamGeneration)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_USE_CASE, useCase), 
											   3, "Use Case");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PROFILES, profiles), 
											   4, "Profiles");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PLP_GROUPS, PLPGroups), 
											   5, "PLP Groups");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PLP, PLPs), 
											   7, "PLPs");
	switch (useCase){
		case RSBTC_VAL_MMG_DVBT2MI_USE_CASE_SPNORMAL:
		case RSBTC_VAL_MMG_DVBT2MI_USE_CASE_MPSNORMAL:
		case RSBTC_VAL_MMG_DVBT2MI_USE_CASE_MPDNORMAL:
		break;
		
		default:
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_VV_STREAM_GENERATION, vVStreamGeneration), 
											   8, "V&V Stream Generation");
	}
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the individual parameters for each PLP group.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR group/Sets the group number.
/// HIPAR PLPGroupID/Sets the group ID.
/// HIPAR mapToProfile/Maps the PLP group to a profile.
/// HIPAR inputType/Configures the input.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPGroup (ViSession instrSession,
                                                            ViInt32 path,
                                                            ViInt32 group,
                                                            ViInt32 PLPGroupID,
                                                            ViInt32 mapToProfile,
                                                            ViInt32 inputType)
{
    ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_groupPLPRepCap (instrSession, group, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PLP_GROUP_ID, PLPGroupID), 
											   4, "PLP Group ID");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MAP_TO_PROFILE, mapToProfile), 
											   5, "Map to Profile");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_INPUT_TYPE, inputType), 
											   7, "Input Type");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the input.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR group/Sets the group number.
/// HIPAR selectInput/Selects the input.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPGroupInput (ViSession instrSession,
                                                                 ViInt32 path,
                                                                 ViInt32 group,
                                                                 ViInt32 selectInput)
{
   	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_groupPLPRepCap (instrSession, group, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_INPUT_SELECT, selectInput), 
											   4, "Select Input");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the individual parameters for PRBS patterns.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR group/Sets the group number.
/// HIPAR genDataRate/Sets the output data rate of the pattern generator.
/// HIPAR commonSlotInterval/Sets the interval in packets between common PLP slots.
/// HIPAR numChapters/Sets the number of separate chapters for pattern generation.
/// HIPAR numEITPackets/Sets the number of successive common packet slots carrying EIT
/// HIPAR numEITPackets/packets.
/// HIPAR TSOverPLPID/Sets the ID of the data PLP to which the input transport stream
/// HIPAR TSOverPLPID/is mapped.
/// HIPAR TSOverCPLP/Enables or disables that the transport stream transported over
/// HIPAR TSOverCPLP/the data PLP is also transported over the common PLP of the
/// HIPAR TSOverCPLP/group.
/// HIPAR PRBSPID/Sets the PID of the PRBS packets additionally inserted to match
/// HIPAR PRBSPID/the generated data rate.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPGroupPRBS (ViSession instrSession,
                                                                ViInt32 path,
                                                                ViInt32 group,
                                                                ViReal64 genDataRate,
                                                                ViInt32 commonSlotInterval,
                                                                ViInt32 numChapters,
                                                                ViInt32 numEITPackets,
                                                                ViInt32 TSOverPLPID,
                                                                ViBoolean TSOverCPLP,
                                                                ViInt32 PRBSPID)
{
   	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_groupPLPRepCap (instrSession, group, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
    viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_GENERATOR_DATA_RATE, genDataRate), 
											   4, "Gen Data Rate");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_COMMON_SLOT_INTERVAL, commonSlotInterval), 
											   5, "Common SLot Interval");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_NUM_CHAPTERS, numChapters), 
											   6, "Num Chapters");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_NUM_EIT_PACKETS, numEITPackets), 
											   7, "Num EIT Packets");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_TS_OVER_PLP_ID, TSOverPLPID), 
											   8, "TS Over PLP ID");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_TS_OVER_CPLP, TSOverCPLP), 
											   9, "TS Over CPLP");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PRBS_ID, PRBSPID), 
											   10, "PRBS ID");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Sets the number of pattern repetitions constituting one chapter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR group/Sets the group number.
/// HIPAR arraySize/Defines the number of values in Repetitions array.
/// HIPAR repetitions/Sets the number of pattern repetitions for each chapter. Array
/// HIPAR repetitions/of ViInt32.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPGroupPRBSNumRep (ViSession instrSession,
                                                                      ViInt32 path,
                                                                      ViInt32 group,
                                                                      ViInt32 arraySize,
                                                                      ViInt32 repetitions[])
{
	ViStatus	error = VI_SUCCESS;
	ViChar		buffer[RSBTC_IO_BUFFER_SIZE];
	ViChar		*p2buffer = buffer;
	ViInt32		i=0;
	
	checkErr (Rs_LockSession (instrSession, NULL));    
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
	viCheckParm (rsbtc_invalidViInt32Range (group, 1, 40), 3, "Group");  
	if (arraySize<1) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Array Size"); 
	
	p2buffer += sprintf(buffer,"SOUR%ld:MMG:GAT:T2MI:GRO%ld:NREP \"", path, group);
	
	while(i<arraySize){
		p2buffer += sprintf(p2buffer,"%ld,",repetitions[i]);
		i++;
	}
	p2buffer--;
	sprintf(p2buffer,"\"");  
	
	checkErr (viPrintf (instrSession, "%s\n", buffer));
		
	viCheckErr(rsbtc_CheckStatus (instrSession));     	
		
Error:
	Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the individual parameters for each PLP.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR PLPID/Sets the hexadecimal ID value of every PLP.
/// HIPAR PLPType/Sets the PLP type.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLP (ViSession instrSession,
                                                       ViInt32 path, 
													   ViInt32 PLP,
                                                       ViInt32 PLPID,
                                                       ViInt32 PLPType)
{
   	ViStatus	error = VI_SUCCESS;
    ViChar	rep_cap[25] = "";
	ViChar	rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PLP_ID, PLPID), 
											   4, "PLP ID");
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PLP_TYPE, PLPType), 
											   5, "PLP Type");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the PLP map to group.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR group/Sets the group number for PLP mapping
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPMapToGroup (ViSession instrSession,
                                                                 ViInt32 path,
                                                                 ViInt32 PLP,
                                                                 ViInt32 group)
{
   	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MAP_TO_GROUP, group), 
											   4, "Group");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the individual parameters for PLP Data
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR PLPData/Sets the data to be transmitted over the PLP.
/// HIPAR arraySize/Defines the number of values in Service ID List array.
/// HIPAR serviceIDList/ich service of the group input stream is extracted. Array of ViInt32.
/// HIPAR newTSID/Sets the transport stream ID of the new partial stream to be
/// HIPAR newTSID/extracted (in terms of annex D splitting) into corresponding PLP
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPData (ViSession instrSession,
                                                           ViInt32 path,
                                                           ViInt32 PLP,
                                                           ViInt32 PLPData,
                                                           ViInt32 arraySize,
                                                           ViInt32 serviceIDList[],
                                                           ViInt32 newTSID)
{
   	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	ViChar		buffer[RSBTC_IO_BUFFER_SIZE];
	ViChar		*p2buffer = buffer;
	ViInt32		i=0;
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_PLP_DATA, PLPData), 
											   4, "PLP Data");
	switch(PLPData){
		case RSBTC_VAL_MMG_DVBT2MI_PLP_DATA_SERVICE:	
			if (arraySize<1) viCheckParm (RS_ERROR_INVALID_PARAMETER, 5, "Array Size"); 
	
			p2buffer += sprintf(buffer,"SOUR%ld:MMG:GAT:T2MI:PLP%ld:SIDL \"", path, PLP);			 

			while(i<arraySize){
				p2buffer += sprintf(p2buffer,"%ld,",serviceIDList[i]);
				i++;
			}
			p2buffer--;
			sprintf(p2buffer,"\"");

			checkErr (viPrintf (instrSession, "%s\n", buffer));
	
			viCheckErr(rsbtc_CheckStatus (instrSession));     
			
			viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_NEW_TS_ID, newTSID), 
											   7, "New TS ID");
		break;
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Configures the individual parameters for PLP Data
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR arraySize/Defines the number of values in Number Packets array.
/// HIPAR numberPackets/Sets the number of consecutive TS packets that are generated for
/// HIPAR numberPackets/the corresponding PLP in each chapter. Array of ViInt32.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIPLPRunLength (ViSession instrSession,
                                                                ViInt32 path,
                                                                ViInt32 PLP,
                                                                ViInt32 arraySize,
                                                                ViInt32 numberPackets[])
{
	ViStatus	error = VI_SUCCESS;
	ViChar		buffer[RSBTC_IO_BUFFER_SIZE];
	ViChar		*p2buffer = buffer;
	ViInt32		i=0;

	checkErr (Rs_LockSession (instrSession, NULL));     
	
	viCheckParm (rsbtc_invalidViInt32Range (path, 1, 2), 2, "Path");
	viCheckParm (rsbtc_invalidViInt32Range (PLP, 1, 40), 3, "PLP");  
	if (arraySize<1) viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Array Size"); 
	
	p2buffer += sprintf(buffer,"SOUR%ld:MMG:GAT:T2MI:PLP%ld:RLEN \"", path, PLP);			 

	while(i<arraySize){
		p2buffer += sprintf(p2buffer,"%ld,",numberPackets[i]);
		i++;
	}
	p2buffer--;
	sprintf(p2buffer,"\"");

	checkErr (viPrintf (instrSession, "%s\n", buffer));

	viCheckErr(rsbtc_CheckStatus (instrSession));     
	
Error:
	Rs_UnlockSession(instrSession, NULL);
	return error;
}

/// HIFN This function configures DVB-T2 MI Mode Stream parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR BBMode/This control selects the baseband mode.
/// HIPAR nullPacketDeletion/Enables or disables the use of null packet deletion.
/// HIPAR autoISSY/Enables or disables the automatic setting of the input stream
/// HIPAR autoISSY/synchronization (ISSY) parameters.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIModeStreamPLP (ViSession instrSession,
                                                                 ViInt32 path,
                                                                 ViInt32 PLP,
                                                                 ViInt32 BBMode,
                                                                 ViBoolean nullPacketDeletion,
                                                                 ViBoolean autoISSY)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_BB_MODE, BBMode), 
											   4, "BB Mode");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_NULL_PACKET_DELETION, nullPacketDeletion), 
											   5, "Null Packet Deletion");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_AUTO_ISSY, autoISSY), 
											   6, "Auto ISSY");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVB-T2 MI Mode Stream ISSY Parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR ISSY/Sets the use of the input stream synchronization (ISSY).
/// HIPAR maxBufferSize/Sets the use of the input stream synchronization (ISSY).
/// HIPAR bufferSizeUnit/Sets the use of the input stream synchronization (ISSY).
/// HIPAR designDelay/Sets the design delay (in samples) of the receiver buffer model.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIModeStreamPLPISSY (ViSession instrSession,
                                                                     ViInt32 path,
                                                                     ViInt32 PLP,
                                                                     ViInt32 ISSY,
                                                                     ViInt32 maxBufferSize,
                                                                     ViInt32 bufferSizeUnit,
                                                                     ViInt32 designDelay)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_ISSY, ISSY), 
											   4, "ISSY");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_BUFFER_SIZE_UNIT, bufferSizeUnit), 
											   6, "Buffer Size Unit");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_MAX_BUFFER_SIZE, maxBufferSize), 
											   5, "Max Buffer Size");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_DESIGN_DELAY, designDelay), 
											   7, "Design Delay");	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVB-T2 MI In-Band Signalling
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR inBandSIgnalling/This control selects the In-Band Signalling Type
/// HIPAR state/Enables or disables the selected in-band signaling
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIModeStreamPLPInBandSign (ViSession instrSession,
                                                                           ViInt32 path,
                                                                           ViInt32 PLP,
                                                                           ViInt32 inBandSignalling,
                                                                           ViBoolean state)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	switch(inBandSignalling){
		case RSBTC_VAL_DVBT2MI_IN_BAND_SIGN:
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_INBAND_SIGNALLING, state), 
											   5, "State");
		break;
		case RSBTC_VAL_DVBT2MI_IN_BAND_SIGN_A:
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_INBAND_SIGNALLING_A, state), 
											   5, "State");
		break;
		case RSBTC_VAL_DVBT2MI_IN_BAND_SIGN_B:
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_MODE_STREAM_INBAND_SIGNALLING_B, state), 
											   5, "State");
		break;
		default:
			viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "In Band Signalling");    	
	}
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVB-T2 MI bit-interleaved coding and modulation parameters
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR FECFrame/This control sets the FEC frame.
/// HIPAR codeRate/This control sets the code rate.
/// HIPAR constellation/This control selects the constellation.
/// HIPAR constellRotation/Defines whether the constellation is transmitted rotated or not.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIBICMParameters (ViSession instrSession,
                                                                  ViInt32 path,
                                                                  ViInt32 PLP,
                                                                  ViInt32 FECFrame,
                                                                  ViInt32 codeRate,
                                                                  ViInt32 constellation,
                                                                  ViBoolean constellRotation)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_FEC_FRAME, FECFrame), 
											   4, "FEC Frame");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_CODE_RATE, codeRate), 
											   5, "Code Rate");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_CONSTELLATION, constellation), 
											   6, "Constellation");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_CONSTELLATION_ROTATION, constellRotation), 
											   7, "Constell Rotation");	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVB-T2 MI Time Interleaver parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR timeInterleaverType/This control sets the time interleaver type.
/// HIPAR frameIntervalIJump/Defines the frame interval (I Jump).
/// HIPAR timeInterleaverLength/Time Interleaver LengthDefines the number of time interleaver
/// HIPAR timeInterleaverLength/blocks (TIB) within the time interleaving frame.
/// HIPAR firstFrameIndex/Displays the index of the first frame of the super frame in
/// HIPAR firstFrameIndex/which the current PLP occurs.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIBICMTimeInterleaverParameters (ViSession instrSession,
                                                                                 ViInt32 path,
                                                                                 ViInt32 PLP,
                                                                                 ViInt32 timeInterleaverType,
                                                                                 ViInt32 frameIntervalIJump,
                                                                                 ViInt32 timeInterleaverLength,
                                                                                 ViInt32 firstFrameIndex)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
    viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_TIME_INTERLEAVER_TYPE, timeInterleaverType), 
											   4, "Time Interleaver Type");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_FRAME_INTERVAL, frameIntervalIJump), 
											   5, "Frame Interval I Jump");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_TIME_INTERLEAVER_LENGTH, timeInterleaverLength), 
											   6, "Time Interleaver Length");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_FIRST_FRAME_INDEX, firstFrameIndex), 
											   7, "First Frame Index");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVB-T2 MI Max Blocks parameters.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR PLP/Sets the PLP number.
/// HIPAR autoNumBlockMax/Enables or disables the automatic calculation of Num Blocks Max.
/// HIPAR numBlocksMax/Sets the maximum number of FEC blocks per interleaving frame.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIBICMMaxBlocks (ViSession instrSession,
                                                                 ViInt32 path,
                                                                 ViInt32 PLP,
                                                                 ViBoolean autoNumBlockMax,
                                                                 ViInt32 numBlocksMax)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_plpRepCap (instrSession, PLP, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_AUTO_NUM_BLOCKS_MAX, autoNumBlockMax), 
											   4, "Auto Num Block Max");
	if (autoNumBlockMax == VI_FALSE)
	{
		viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_BICM_NUM_BLOCKS_MAX, numBlocksMax), 
											   5, "Num Blocks Max");											   
	}		
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures FRAMING + OFDM parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number.
/// HIPAR channelBandwidth/This control sets the channel bandwidth.
/// HIPAR FFTSize/This control sets the FFT size.
/// HIPAR guardInterval/This control sets the guard interval.
/// HIPAR pilotPattern/This control sets the pilot pattern.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIFramingOFDMParameters (ViSession instrSession,
                                                                         ViInt32 path,
                                                                         ViInt32 profile,
                                                                         ViInt32 channelBandwidth,
                                                                         ViInt32 FFTSize,
                                                                         ViInt32 guardInterval,
                                                                         ViInt32 pilotPattern)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_CHANNEL_BANDWIDTH, channelBandwidth), 
											   4, "Channel Bandwidth");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_FFT_SIZE, FFTSize), 
											   5, "FFT Size");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_GUARD_INTERVAL, guardInterval), 
											   6, "Guard Interval");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_PILOT_PATTERN, pilotPattern), 
											   7, "Pilot Pattern");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}
 
/// HIFN This function configures DVB-T2 MI Frames parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number.
/// HIPAR t2FramesPerSuperFrame/This control sets the number of T2 frames per super frame.
/// HIPAR dataSymbolsPerT2Frame/Sets the number of data symbols per T2 frame.
/// HIPAR subslicesPerT2Frame/Sets the number of subslices per T2 frame. The possible values
/// HIPAR subslicesPerT2Frame/depend on the constellation and the FEC type of all data type 2
/// HIPAR subslicesPerT2Frame/PLPs.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIFramingOFDM (ViSession instrSession,
                                                               ViInt32 path,
                                                               ViInt32 profile,
                                                               ViInt32 t2FramesPerSuperFrame,
                                                               ViInt32 dataSymbolsPerT2Frame,
                                                               ViInt32 subslicesPerT2Frame)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_T2_FRAMES_PER_SUPER_FRAME, t2FramesPerSuperFrame), 
											   4, "T2 Frames Per Super Frame");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_DATA_SYMBOLS_PER_T2_FRAME, dataSymbolsPerT2Frame), 
											   5, "Data Symbols Per T2 Frame");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_FRAMING_SUBSLICES_PER_T2_FRAME, subslicesPerT2Frame), 
											   6, "Subslices Per T2 Frame");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures transmission system parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number.
/// HIPAR scheduling/Sets the input stream adaptation model.
/// HIPAR transmissionSystem/Displays the transmission system.
/// HIPAR peakToAveragePowerRatio/This control sets the peak-to-average-power ratio state.
/// HIPAR futureExtensionFrames/Sets the future extension frames (FEF) state.
/// HIPAR timeFrequencySlicing/Sets the time frequency slicing (TFS) state.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MITransmissionSystem (ViSession instrSession,
                                                                      ViInt32 path,
                                                                      ViInt32 profile,
                                                                      ViInt32 scheduling,
                                                                      ViInt32 transmissionSystem,
                                                                      ViInt32 peakToAveragePowerRatio,
                                                                      ViBoolean futureExtensionFrames,
                                                                      ViBoolean timeFrequencySlicing)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_SCHEDULING, scheduling), 
											   4, "Scheduling");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_TRANSMISSION_SYSTEM, transmissionSystem), 
											   5, "Transmission System");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_PEAK_TO_AVERAGE_POWER_RATIO, peakToAveragePowerRatio), 
											   6, "Peak To Average Power Ratio");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_FUTURE_EXTENSION_FRAMES, futureExtensionFrames), 
											   7, "Future Extension Frames");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_TIME_FREQUENCY_SLICING, timeFrequencySlicing), 
											   8, "Time Frequency Slicing");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures T2 parameters system identification.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number.
/// HIPAR networkID/Sets the network identification.
/// HIPAR cellID/Sets the cell identification.
/// HIPAR t2SystemID/Sets the T2 system identification.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MITransmissionSystemIdentification (ViSession instrSession,
                                                                                    ViInt32 path,
                                                                                    ViInt32 profile,
                                                                                    ViInt32 networkID,
                                                                                    ViInt32 cellID,
                                                                                    ViInt32 t2SystemID)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_NETWORK_ID, networkID), 
											   4, "Network ID");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_CELL_ID, cellID), 
											   5, "Cell ID");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_ID, t2SystemID), 
											   6, "T2 System ID");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures Future Extension Frames parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number.
/// HIPAR FEFLength/This control sets Future Extension Frames length.
/// HIPAR FEFType/This control sets the type of the associated FEF part.
/// HIPAR FEFInterval/This control sets Future Extension Frames interval.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MITransmissionFutureExtensionFrames (ViSession instrSession,
                                                                                     ViInt32 path,
                                                                                     ViInt32 profile,
                                                                                     ViInt32 FEFLength,
                                                                                     ViInt32 FEFType,
                                                                                     ViInt32 FEFInterval)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_FEF_LENGTH, FEFLength), 
											   4, "FEF Length");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_FEF_TYPE, FEFType), 
											   5, "FEF Type");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_FEF_INTERVAL, FEFInterval), 
											   6, "FEF Interval");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures transmission system L1 parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number.
/// HIPAR l1T2Version/This control sets the T2 specification version used for transmission.
/// HIPAR l1PostModulation/This control sets the L1 post constellation.
/// HIPAR l1Repetition/Sets the L1 repetition state.
/// HIPAR l1PostExtension/L1 post extension is not implemented and cannot be enabled.   
/// HIPAR l1PostScrambled/Activates or deactivates L1 post scrambling according to T2
/// HIPAR l1PostScrambled/version 1.3.1 ("L1 T2 VERSION").
/// HIPAR l1BiasBalancingBits/Enables or disables L1 bias balancing using reserved bits.
/// HIPAR t2BaseLite/Enables or disables T2 base lite flag in the L1 pre signaling.
/// HIPAR l1RFFrequency/Sets the RF frequency in the L1 post signaling.
ViStatus _VI_FUNC rsbtc_ConfigureMMGDVBT2MITransmissionL1Parameters (ViSession instrSession,
                                                                     ViInt32 path,
                                                                     ViInt32 profile,
                                                                     ViInt32 l1T2Version,
                                                                     ViInt32 l1PostModulation,
                                                                     ViBoolean l1Repetition,
                                                                     ViBoolean l1PostExtension, 
																	 ViBoolean l1PostScrambled,
                                                                     ViBoolean l1BiasBalancingBits,
                                                                     ViBoolean t2BaseLite,
                                                                     ViReal64 l1RFFrequency)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_T2_VERSION, l1T2Version), 
											   4, "L1 T2 Version");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_POST_MODULATION, l1PostModulation), 
											   5, "L1 Post Modulation");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_REPETITION, l1Repetition), 
											   6, "L1 Repetition");
	viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_POST_EXTENSION, l1PostExtension), 
											   7, "L1 Post Extension");
	switch (l1T2Version){
		case RSBTC_VAL_IQC_DVBT2_L1_VER_V121:
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_BIAS_BALANCING_BITS, l1BiasBalancingBits), 
											   9, "L1 Bias Balancing Bits");
		break;	
		case RSBTC_VAL_IQC_DVBT2_L1_VER_V131:
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_POST_SCRAMBLED, l1PostScrambled), 
											   8, "L1 Post Scrambled");
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_BIAS_BALANCING_BITS, l1BiasBalancingBits), 
											   9, "L1 Bias Balancing Bits");
			viCheckParm (rsbtc_SetAttributeViBoolean(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_T2_BASE_LITE, t2BaseLite), 
											   10, "T2 Base Lite");
		break;	
	}
	
	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_T2_SYSTEM_L1_RF_FREQUENCY, l1RFFrequency), 
											   10, "L1 RF Frequency");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function configures DVB-T2 MI output parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR t2TimestampMode/This control sets the channel bandwidth.
/// HIPAR timeOffset/Sets the offset for the time stamp in milliseconds. This affects
/// HIPAR timeOffset/the dynamic delay within the modulator only.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIOutputParameters (ViSession instrSession,
                                                                    ViInt32 path,
                                                                    ViInt32 t2TimestampMode,
                                                                    ViInt32 timeOffset)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_T2_TIMESTAMP_MODE, t2TimestampMode), 
											   3, "T2 Timestamp Mode");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_TIME_OFFSET, timeOffset), 
											   4, "Time Offset");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN This function sets the individual parameters for each profile.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
/// HIPAR profile/Sets the profile number. 
/// HIPAR PID/Sets the PID of the output MPEG stream packets carrying T2-MI
/// HIPAR PID/data of this profile.
/// HIPAR SID/Sets the T2-MI stream ID of the output T2-MI packets of this
/// HIPAR SID/profile.
/// HIPAR TSType/Defines whether the T2-MI stream is carried within a full MPEG-2
/// HIPAR TSType/transport stream or a single PID MPEG-2 transport stream.
/// HIPAR PMTPID/Sets the PID used for the PMT of the T2-MI service.
/// HIPAR outputDataRate/Sets the output stream data rate of this profile.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIOutputProfile (ViSession instrSession,
                                                                 ViInt32 path,
																 ViInt32 profile,  
                                                                 ViInt32 PID,
                                                                 ViInt32 SID,
                                                                 ViInt32 TSType,
                                                                 ViInt32 PMTPID,
                                                                 ViReal64 outputDataRate)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[25] = "";
	ViChar		rep_cap_1[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    checkErr(rsbtc_profileRepCap (instrSession, profile, rep_cap_1));
	
	strcat(rep_cap, ",");
	strcat(rep_cap, rep_cap_1);
	
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_T2_MI_PID, PID), 
											   4, "PID");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_T2_MI_SID, SID), 
											   5, "SID");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_T2_MI_TS_TYPE, TSType), 
											   6, "TS Type");
	viCheckParm (rsbtc_SetAttributeViInt32(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_T2_MI_PMT_PID, PMTPID), 
											   7, "PMT PID");
	viCheckParm (rsbtc_SetAttributeViReal64(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_T2_MI_DATA_RATE, outputDataRate), 
											   8, "Output Data Rate");
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN Restarts the T2-MI stream output of the gateway.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control selects the path.
ViStatus _VI_FUNC rsbtc_ConfigureMMGGatewayDVBT2MIOutputRestart (ViSession instrSession,
                                                                 ViInt32 path)
{
	ViStatus	error = VI_SUCCESS;
    ViChar		rep_cap[10] = "";
	
    checkErr (Rs_LockSession (instrSession, NULL));

    checkErr(rsbtc_pathRepCap (instrSession, path, rep_cap));
    
	viCheckErr (rsbtc_SetAttributeViString(instrSession, rep_cap,
                                               RSBTC_ATTR_MMG_GATEWAY_DVBT2MI_OUTPUT_RESTART, NULL));
	
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/*****************************************************************************
 *---------------------------- Power Meter ----------------------------------*
 *****************************************************************************/
/*============================================================================/
 * Function: Power Meter Configuration
 * Purpose:  This function selects the unit used for measured value and
 *			 sets the reference value for use in computation of relative
 * 			 power value.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_PowerMeterConfiguration (ViSession instrSession,
                                                 ViInt32 unit,
                                                 ViReal64 referencePower)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr( Rs_LockSession (instrSession, NULL));

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_POWER_METER_UNIT, unit),
                         2, "Unit");
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, "", RSBTC_ATTR_POWER_METER_SOURCE_REF_POWER, 
                        referencePower), 3, "Reference Power");

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}
	
/*============================================================================/
 * Function: Configure Power Meter Frequency
 * Purpose:  This function configures the power meter frequency.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigurePowerMeterFrequency(ViSession instrSession,
                                                 ViInt32 source,
                                                 ViReal64 frequency)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr( Rs_LockSession (instrSession, NULL));

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_POWER_METER_SOURCE, source),
                         2, "Source");
    viCheckParm (rsbtc_SetAttributeViReal64 (instrSession, "", RSBTC_ATTR_POWER_METER_SOURCE_FREQUENCY, 
                        frequency), 3, "Frequency");

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/*============================================================================/
 * Function: Configure Average Filter
 * Purpose:  This function configures the filter length used for measurement.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_ConfigurePowerMeterAverageFilter (ViSession instrSession,
                                           ViInt32 filterType,
                                           ViInt32 filterLength)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr( Rs_LockSession (instrSession, NULL));

    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_POWER_METER_AVERAGE_FILTER_TYPE,
						filterType), 2, "Filter Type");
	if(filterType == RSBTC_VAL_PWR_METER_FILTER_USER)
	{
		viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_POWER_METER_AVERAGE_FILTER_LENGTH,
						filterLength), 3, "Filter Length");
	}	
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}




/// HIFN  This function activates/deactivates updating of the display. Upon 
/// HIFN  changing to manual control, the status is automatically set to ON.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_SYSTEM_DISPLAY_UPDATE
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     SYSTem:DISPlay:UPDate ON | OFF
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR displayUpdate/This control activates/deactivates updating of the display. 
ViStatus _VI_FUNC rsbtc_SystemDisplayUpdate(
	ViSession	instrSession,
	ViBoolean	displayUpdate
)
{
    ViStatus	error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, NULL));

   
    viCheckParm (rsbtc_SetAttributeViBoolean (instrSession, "",
                                                 RSBTC_ATTR_SYSTEM_DISPLAY_UPDATE, displayUpdate
                                                 ), 2, "Display Update");
Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function locks or unlocks the front panel keypad of the R&S SFU 
/// HIFN  including the LOCAL key.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_SYSTEM_KLOCK
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     SYSTem:KLOCk 1 | 0
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR keypadLock/This control locks or unlocks the front panel keypad.
ViStatus _VI_FUNC rsbtc_SystemKeypadLock(
	ViSession	instrSession,
	ViInt32	keypadLock
)
{
    ViStatus	error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, NULL));

   
    viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "",
                                                 RSBTC_ATTR_SYSTEM_KLOCK, keypadLock
                                                 ), 2, "Keypad Lock");

Error:
    Rs_UnlockSession(instrSession, NULL);    
    return error;
}

/// HIFN  This function sets the Enable, NTransition and PTransition bits     of 
/// HIFN  status questionable and operating registers.
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) For detailed description of Status Reporting System see also 
/// HIFN  operating manual.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     STATus:OPERation:ENABle
/// HIFN     STATus:OPERation:NTRansition
/// HIFN     STATus:OPERation:PTRansition
/// HIFN     STATus:QUEStionable:ENABle
/// HIFN     STATus:QUEStionable:NTRansition
/// HIFN     STATus:QUEStionable:PTRansition
/// HIFN     
/// HIFN     
/// HIFN     
/// HIFN     
/// HIFN     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR enable/This control sets the enable bits of the status register.  
/// HIPAR ptransition/This control sets the PTransition bits (edge detectors) of the status 
/// HIPAR ptransition/register.  
/// HIPAR ntransition/This control sets the NTransition bits (edge detectors) of the status 
/// HIPAR ntransition/register.  
ViStatus _VI_FUNC rsbtc_SetStatusRegister(
	ViSession	instrSession,
	ViInt32	registerOperation,
	ViInt32	enable,
	ViInt32	ptransition,
	ViInt32	ntransition
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((registerOperation < RSBTC_VAL_PRESET_STAT_REG) || (registerOperation > RSBTC_VAL_OPER_STAT_REG))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Register Operation");
        
    if ((enable < 0) || (enable > 32767))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Enable");
    
    if ((ptransition < 0) || (ptransition > 32767))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "PTransition");     
    
    if ((ntransition < 0) || (ntransition > 32767))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 5, "NTransition");     
            
        
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */
    
        switch (registerOperation) {
            case RSBTC_VAL_PRESET_STAT_REG:
                viCheckErr(viPrintf (instrSession, ":STAT:PRES\n")); 
            break;
            
            case RSBTC_VAL_QUEST_STAT_REG:
                viCheckErr(viPrintf (instrSession, ":STAT:QUES:ENAB %ld;PTR %ld;NTR %ld\n",
                    enable, ptransition, ntransition)); 
            break;
            
            case RSBTC_VAL_OPER_STAT_REG:
                viCheckErr(viPrintf (instrSession, ":STAT:OPER:ENAB %ld;PTR %ld;NTR %ld\n",
                    enable, ptransition, ntransition)); 
            break;
        }
    }   
    
    viCheckErr(rsbtc_CheckStatus (instrSession));       
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN  This function contains the commands for the querying status reporting 
/// HIFN  system.
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     For detailed description of Status Reporting System see also operating 
/// HIFN  manual.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     STATus:OPERation:ENABle?
/// HIFN     STATus:OPERation:NTRansition?
/// HIFN     STATus:OPERation:PTRansition?
/// HIFN     STATus:OPERation:EVENt?
/// HIFN     STATus:OPERation:CONDition?
/// HIFN     STATus:QUEStionable:ENABle?
/// HIFN     STATus:QUEStionable:NTRansition?
/// HIFN     STATus:QUEStionable:PTRansition?
/// HIFN     STATus:QUEStionable:EVENt?
/// HIFN     STATus:QUEStionable:CONDition?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR statusRegistersQuery/This control selects the registers to be queried.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rsbtc_GetStatusRegister(
	ViSession	instrSession,
	ViInt32	registerOperation,
	ViInt32	statusRegistersQuery,
	ViInt32*	registerValue
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((registerOperation < RSBTC_VAL_QUEST_STAT_REG   ) || (registerOperation > RSBTC_VAL_OPER_STAT_REG))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Register Operation");
    
    if ((statusRegistersQuery < RSBTC_VAL_REG_CONDITION   ) || (statusRegistersQuery > RSBTC_VAL_REG_NTRANSITION))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Register Operation");  
            
        
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */
    
        switch (registerOperation) {
            case RSBTC_VAL_QUEST_STAT_REG:
                viCheckErr (viQueryf (instrSession, ":STAT:QUES:%s?", "%ld",
                    statusRegisterArr[statusRegistersQuery], registerValue)); 
            break;
            
            case RSBTC_VAL_OPER_STAT_REG:
                viCheckErr (viQueryf (instrSession, ":STAT:OPER:%s?", "%ld",
                    statusRegisterArr[statusRegistersQuery], registerValue)); 
            break;
        }
    }   

    viCheckErr(rsbtc_CheckStatus (instrSession));       
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/// HIFN  This function sets the Enable, NTransition and PTransition 
/// HIFN  user-definable bits of status questionable and operating registers.
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     (1) For detailed description of Status Reporting System see also 
/// HIFN  operating manual.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     STATus:OPERation:BIT{8..12}:ENABle
/// HIFN     STATus:OPERation:BIT{8..12}:NTRansition
/// HIFN     STATus:OPERation:BIT{8..12}:PTRansition
/// HIFN     STATus:QUEStionable:BIT{9..12}:ENABle
/// HIFN     STATus:QUEStionable:BIT{9..12}:NTRansition
/// HIFN     STATus:QUEStionable:BIT{9..12}:PTRansition
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR userdefinableBit/This control sets the user-definable bits in the QUEStionable or  
/// HIPAR userdefinableBit/OPERation register.
/// HIPAR enable/This control sets the enable bits of the status register.  
/// HIPAR ptransition/This control sets the PTransition bits (edge detectors) of the status 
/// HIPAR ptransition/register.  
/// HIPAR ntransition/This control sets the NTransition bits (edge detectors) of the status 
/// HIPAR ntransition/register.  
ViStatus _VI_FUNC rsbtc_SetUserDefStatusRegister(
	ViSession	instrSession,
	ViInt32	registerOperation,
	ViInt32	userdefinableBit,
	ViInt32	enable,
	ViInt32	ptransition,
	ViInt32	ntransition
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((registerOperation < RSBTC_VAL_QUEST_STAT_REG) || (registerOperation > RSBTC_VAL_OPER_STAT_REG))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Register Operation");

    if (registerOperation == RSBTC_VAL_QUEST_STAT_REG) {
        if ((userdefinableBit < 9) || (userdefinableBit > 12))
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "User-definable Bit");
    }
    else {
        if ((userdefinableBit < 8) || (userdefinableBit > 12))
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "User-definable Bit");
    }
    
    if ((enable < 0) || (enable > 32767))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Enable");
    
    if ((ptransition < 0) || (ptransition > 32767))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 5, "PTransition");     
    
    if ((ntransition < 0) || (ntransition > 32767))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 6, "NTransition");     
            
        
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */
    
        switch (registerOperation) {

            case RSBTC_VAL_QUEST_STAT_REG:
                viCheckErr(viPrintf (instrSession, ":STAT:QUES:BIT%ld:ENAB %ld;PTR %ld;NTR %ld\n",
                    userdefinableBit, enable, ptransition, ntransition)); 
            break;
            
            case RSBTC_VAL_OPER_STAT_REG:
                viCheckErr(viPrintf (instrSession, ":STAT:OPER:BIT%ld:ENAB %ld;PTR %ld;NTR %ld\n",
                    userdefinableBit, enable, ptransition, ntransition)); 
            break;
        }
    }   
    
    viCheckErr(rsbtc_CheckStatus (instrSession));       
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/// HIFN  This function contains the commands for the querying user-definable 
/// HIFN  bits status reporting system.
/// HIFN     
/// HIFN     Note:
/// HIFN     
/// HIFN     For detailed description of Status Reporting System see also operating 
/// HIFN  manual.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     STATus:OPERation:BIT{8..12}:ENABle?
/// HIFN     STATus:OPERation:BIT{8..12}:NTRansition?
/// HIFN     STATus:OPERation:BIT{8..12}:PTRansition?
/// HIFN     STATus:OPERation:BIT{8..12}:EVENt?
/// HIFN     STATus:OPERation:BIT{8..12}:CONDition?
/// HIFN     STATus:QUEStionable:BIT{9..12}:ENABle?
/// HIFN     STATus:QUEStionable:BIT{9..12}:NTRansition?
/// HIFN     STATus:QUEStionable:BIT{9..12}:PTRansition?
/// HIFN     STATus:QUEStionable:BIT{9..12}:EVENt?
/// HIFN     STATus:QUEStionable:BIT{9..12}:CONDition?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR userdefinableBit/This control sets the user-definable bits in the QUEStionable or  
/// HIPAR userdefinableBit/OPERation register.
/// HIPAR statusRegistersQuery/This control selects the registers to be queried.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rsbtc_GetUserDefStatusRegister(
	ViSession	instrSession,
	ViInt32	registerOperation,
	ViInt32	userdefinableBit,
	ViInt32	statusRegistersQuery,
	ViInt32*	registerValue
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((registerOperation < RSBTC_VAL_QUEST_STAT_REG   ) || (registerOperation > RSBTC_VAL_OPER_STAT_REG))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Register Operation");
    
    if (registerOperation == RSBTC_VAL_QUEST_STAT_REG) {
        if ((userdefinableBit < 9) || (userdefinableBit > 12))
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "User-definable Bit");
    }
    else {
        if ((userdefinableBit < 8) || (userdefinableBit > 12))
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "User-definable Bit");
    }
    
    if ((statusRegistersQuery < RSBTC_VAL_REG_CONDITION   ) || (statusRegistersQuery > RSBTC_VAL_REG_NTRANSITION))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Register Operation");  
            
        
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */
    
        switch (registerOperation) {
            case RSBTC_VAL_QUEST_STAT_REG:
                viCheckErr (viQueryf (instrSession, ":STAT:QUES:BIT%ld:%s?", "%ld",
                    userdefinableBit, statusRegisterArr[statusRegistersQuery], registerValue)); 
            break;
            
            case RSBTC_VAL_OPER_STAT_REG:
                viCheckErr (viQueryf (instrSession, ":STAT:OPER:BIT%ld:%s?", "%ld",
                    userdefinableBit, statusRegisterArr[statusRegistersQuery], registerValue)); 
            break;
        }
    }   

    viCheckErr(rsbtc_CheckStatus (instrSession));       
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*****************************************************************************
 * Function: File Operations
 * Purpose:  The MMEMory subsystem (Mass Memory) contains the commands for
 *           managing files and directories as well as for loading and
 *           storing complete instrument settings in files.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_FileOperations (ViSession instrSession,
                                           ViInt32 operation,
                                           ViString source,
                                           ViString destination)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
    if (Rs_Simulating(instrSession) == 0){                /* call only when locked */
    switch (operation){
        case RSBTC_VAL_MMEM_COPY:
            viCheckErr( viPrintf (instrSession, "MMEM:COPY '%s','%s'\n", source, destination)); 
        break;
        
        case RSBTC_VAL_MMEM_DELETE:
            viCheckErr( viPrintf (instrSession, "MMEM:DEL '%s'\n", source)); 
        break;
        
        case RSBTC_VAL_MMEM_RENAME:
            viCheckErr( viPrintf (instrSession, "MMEM:MOVE '%s','%s'\n", source, destination)); 
        break;
        
        case RSBTC_VAL_MMEM_MDIR:
            viCheckErr( viPrintf (instrSession, "MMEM:MDIR '%s'\n", source)); 
        break;
        
        case RSBTC_VAL_MMEM_CDIR:
            viCheckErr( viPrintf (instrSession, "MMEM:CDIR '%s'\n", source)); 
        break;        
        
        case RSBTC_VAL_MMEM_RDIR:
            viCheckErr( viPrintf (instrSession, "MMEM:RDIR '%s'\n", source)); 
        break;
        
        case RSBTC_VAL_MMEM_MSIS:
            viCheckErr( viPrintf (instrSession, "MMEM:MSIS '%s'\n", source)); 
        break;        
        }
    viCheckErr(rsbtc_CheckStatus (instrSession));
    }
    

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*===========================================================================
 * Function: File Directory Path                                             
 * Purpose:  This fuction reads out the subdirectories or subdirectories and
 *           files in the specified directory.                        
/============================================================================*/
ViStatus _VI_FUNC rsbtc_DirectoryPath (ViSession instrSession, ViInt32 read,
                                        ViString directory, ViInt32 bufferSize,
                                        ViChar output[], ViInt32 *returnedValues)
{
   
    ViChar*     pbuffer = NULL;
    ViUInt32    count = 0;
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
    if (Rs_Simulating(instrSession) == 0){                /* call only when locked */

    if (bufferSize != 0 && output == NULL)
        return VI_ERROR_PARAMETER5;

    if (read == RSBTC_VAL_MMEM_CATALOG_FILES)
    {
        viCheckErr( viPrintf(instrSession, ":MMEM:CAT? '%s'\n", directory));
    }
    else
        viCheckErr( viPrintf(instrSession, ":MMEM:DCAT? '%s'\n", directory)); 
    
    
    //viCheckErr( rsbtc_WaitForOPC (instrSession, MAX_OPC_TIME)); 
    viCheckErr( rsbtc_ReadDataUnknownLength(instrSession, &pbuffer, &count));
    
    if (output != NULL) strncpy(output, pbuffer, (size_t) ((bufferSize > (ViInt32) count) ? (ViInt32) count : bufferSize));
    free(pbuffer);
    if (returnedValues) *returnedValues = (ViInt32) count;
        
    viCheckErr(rsbtc_CheckStatus (instrSession)); 
    }
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;   
}

/*============================================================================/
 * Function: Catalog Length
 * Purpose:  This function reads out the number of files or subdirectories in
 *           the specified directory.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_CatalogLength (ViSession instrSession, ViInt32 read,
                                         ViInt32 *catalogLength)
{
   ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
    if (Rs_Simulating(instrSession) == 0){                /* call only when locked */

    if (!catalogLength) viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Catalog Length");
    
    if (read == RSBTC_VAL_MMEM_CATALOG_FILES)
    {
        viCheckErr( viQueryf (instrSession, "MMEM:CAT:LENG?", "%ld", catalogLength));
    }
    else
        viCheckErr( viQueryf (instrSession, "MMEM:DCAT:LENG?", "%ld", catalogLength));
 }   
    viCheckErr(rsbtc_CheckStatus (instrSession));
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/// HIFN  This function stores or recalls application settings in the specified 
/// HIFN  file.
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     MMEMory:STORe:STATe 1,<string>
/// HIFN     MMEMory:LOAD:STATe 1,<string>
/// HIFN     *RCL
/// HIFN     *SAV
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/Selects operation.
/// HIPAR source/This control specifies the source of the operation to be performed. If 
/// HIPAR source/the operation requires a single parameter, this control specifies that 
/// HIPAR source/parameter.
ViStatus _VI_FUNC rsbtc_StoreAndLoadApplication(
	ViSession	instrSession,
	ViInt32	operation,
	ViString	source
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((operation < RSBTC_VAL_SAVE) || (operation > RSBTC_VAL_RECALL))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Operation");
        
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */

        switch (operation){
            case RSBTC_VAL_SAVE:
                 sprintf (buffer,"*SAV 1;:MMEMory:STORe:STATe 1,\"%s\";*OPC", source);
            break;
        
            case RSBTC_VAL_RECALL:
                sprintf (buffer,":MMEMory:LOAD:STATe 1,\"%s\";*RCL 1;*OPC", source);
            break;
        }   
    }
    viCheckErr( viPrintf (instrSession, "%s\n", buffer));
    viCheckErr (rsbtc_WaitForOPC (instrSession, 60000));
    viCheckErr(rsbtc_CheckStatus (instrSession));       
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/// HIFN  This function stores or recalls instrument data. 
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     RSBTC_ATTR_SAV
/// HIFN     RSBTC_ATTR_RCL
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     *SAV
/// HIFN     *RCL
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/Select the operation.
/// HIPAR stateNumber/This control sets the state number.
ViStatus _VI_FUNC rsbtc_StoreAndLoadInstrumentData(
	ViSession	instrSession,
	ViInt32	operation,
	ViInt32	stateNumber
)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */
    switch (operation){
        case RSBTC_VAL_SAVE:
             viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_SAV, stateNumber),
                         3, "State Number"); 
        break;
        
        case RSBTC_VAL_RECALL:
             viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_RCL, stateNumber),
                         3, "State Number"); 
        break;
        }
    }
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*****************************************************************************
 * Function: rsbtc_close
 * Purpose:  This function closes the instrument.
 *
 *           Note:  This function must unlock the session before calling
 *           Rs_Dispose.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_close (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;

    // checkErr( Rs_LockSession (vi, NULL));
    
    checkErr( rsbtc_RsClose (instrSession));

Error:

    // Rs_UnlockSession (vi, NULL);
    (void) Rs_Dispose (instrSession);

    return error;
}

/*****************************************************************************
 * Function: rsbtc_RsClose
 * Purpose:  This function performs all of the drivers clean-up operations
 *           except for closing the RS session.  This function is called by
 *           rsbtc_close or by an RS class driver.
 *
 *           Note:  This function must close the I/O session and set
 *           RS_ATTR_IO_SESSION to 0.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_RsClose (ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if(instrSession != 0)
        {
        ViSession   rmSession = 0;

        checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_VISA_RM_SESSION, 0, (ViUInt32) sizeof (rmSession), &rmSession));
        
        viPrintf (instrSession, "&LOC");
        
        (void) viClose (instrSession);
        (void) viClose (rmSession);
        }
Error:    
    return error;
}	

    /* Do not lock here. The caller manages the lock. */
	//
    //(void) Rs_SetAttribute (instrSession, NULL, RS_ATTR_IO_SESSION, 0, NULL);
    //(void) Rs_GetAttribute (instrSession, NULL, RS_ATTR_VISA_RM_SESSION, 0, (ViInt32) sizeof (rmSession), &rmSession);
        
    //viWrite (instrSession, (ViBuf) "@LOC\n", 5, NULL);
	
	//(void) viClose (instrSession);
    //if (rmSession != 0)
    //    (void) viClose (rmSession);
   
   // return error;



ViStatus _VI_FUNC rsbtc_SetErrorInfo (ViSession session,
                          ViBoolean overWrite,
                          ViStatus primaryError,
                          ViStatus secondaryError,
                          ViConstString errorElaboration)
{
    return Rs_SetErrorInfo (session,
                          overWrite,
                          primaryError,
                          secondaryError,
                          errorElaboration);
}

ViStatus _VI_FUNC rsbtc_GetErrorInfo (ViSession session,
                          ViStatus *primaryError,
                          ViStatus *secondaryError,
                          ViChar errorElaboration[])
{
    return Rs_GetErrorInfo (session,
                          primaryError,
                          secondaryError,
                          errorElaboration);
}



/*****************************************************************************
 * Function: rsbtc_reset
 * Purpose:  This function resets the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_reset (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;
    ViUInt32    tout    = 0;

    checkErr( Rs_LockSession (instrSession, NULL));

    if (Rs_Simulating(instrSession) == 0)                /* call only when locked */
        {
            viCheckErr (viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &tout));
            viCheckErr (viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, 30000));
          /*
            viCheckErr (Rs_WriteInstrData (instrSession, "*RST;*OPC?"));
            viCheckErr (viScanf (instrSession, "%hu", &opc));
            */
			     
			viCheckErr (Rs_WriteInstrData (instrSession, "*RST")); 
            
			viCheckErr (viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, tout));
        }

    checkErr( rsbtc_DefaultInstrSetup (instrSession));
    checkErr( rsbtc_CheckStatus (instrSession));

Error:

    (void) Rs_UnlockSession (instrSession, NULL);

    return error;
}

/*****************************************************************************
 * Function: rsbtc_ResetWithDefaults
 * Purpose:  This function resets the instrument and applies default settings
 *           from the RS Configuration Store based on the logical name
 *           from which the session was created.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_ResetWithDefaults (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
    checkErr( rsbtc_reset(instrSession));
    checkErr( Rs_ApplyDefaultSetup(instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/****************************************************************************
 *  Function: rsbtc_Disable
 *  Purpose:  This function places the instrument in a quiescent state as
 *            quickly as possible.
 ****************************************************************************/
ViStatus _VI_FUNC rsbtc_Disable (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;
	instrSession;
    
/*    checkErr( Rs_LockSession (vi, NULL));

    if (Rs_Simulating(vi) == 0)
        {
        }
Error:
//    (void) Rs_UnlockSession (vi, NULL);
        */
    return error;
}

/*****************************************************************************
 * Function: rsbtc_self_test
 * Purpose:  This function executes the instrument self-test and returns the
 *           result.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_self_test (ViSession instrSession, ViInt16 *testResult,
                                      ViChar testMessage[])
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if (testResult == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Test Result")
    if (testMessage == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Test Message");

    if (Rs_Simulating(instrSession) == 0)                /* call only when locked */
        {
        viCheckErr( viPrintf (instrSession, "*TST?\n"));
        viCheckErr( viScanf (instrSession, "%hd,\"%256[^\"]", testResult, testMessage));

        }
    else
        {
        /* Simulate Self Test */
        if (testResult != NULL)
            *testResult = 0;
        strcpy (testMessage, "No error.");
        }

    checkErr( rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*****************************************************************************
 * Function: rsbtc_revision_query
 * Purpose:  This function returns the driver and instrument revisions.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_revision_query (ViSession instrSession, ViChar driverRev[],
                                           ViChar instrRev[])
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));

    if (driverRev == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Driver Revision");
    if (instrRev == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Instrument Revision");

    checkErr( Rs_GetAttribute (instrSession, NULL, RSBTC_ATTR_SPECIFIC_DRIVER_REVISION,
                                        0, 256, driverRev));
    checkErr( Rs_GetAttribute (instrSession, "", RSBTC_ATTR_INSTRUMENT_FIRMWARE_REVISION,
                                        0, 256, instrRev));
    checkErr( rsbtc_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*****************************************************************************
 * Function: rsbtc_error_query
 * Purpose:  This function queries the instrument error queue and returns
 *           the result.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_error_query (ViSession instrSession, ViInt32 *errCode,
                                        ViChar errMessage[])
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = "";
    ViInt32     oldCode = 0;
    ViChar      oldMessage[1024] = "";
    ViChar      *p2buf = NULL;
    ViInt32     i = 0;
    ViUInt32    retCnt = 0;

    checkErr( Rs_LockSession (instrSession, NULL));

    if (errCode == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Error Code");
    if (errMessage == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Error Message");

    if (Rs_Simulating(instrSession) == 0)                /* call only when locked */
    {
        p2buf = (char *)malloc (1);

        *p2buf='\0';
            
        do 
        {
            checkErr (viWrite (instrSession, (ViBuf) "SYST:ERR?\n", 10, NULL));
            checkErr (viRead (instrSession, (ViBuf)buffer, RSBTC_IO_BUFFER_SIZE, &retCnt));
            if  (sscanf (buffer, "%ld,%*[^0-9a-zA-Z]%256[^\"]", &oldCode, oldMessage) != 2)
            {
                viCheckErr(RS_ERROR_UNEXPECTED_RESPONSE);
            }
            else
            {
                if (oldCode != 0)
                {
                    *errCode = oldCode;
                    
                    p2buf = (char *)realloc (p2buf, strlen(p2buf) + strlen (oldMessage) + 2);
        
                    strcat (p2buf, oldMessage);
        
                    strcat (p2buf, "\n");
                    
                    i++;
                }
                else if (i == 0)
                {
                    *errCode = oldCode;
    
                    strncpy (errMessage, oldMessage, 1024);
                }
            }

        } while (oldCode != 0);
        
        if (i > 0)
        {
            p2buf[strlen (p2buf) - 1] = '\0'; 
            
            strncpy (errMessage, p2buf, 1024);
        }
    }
    
    else
    {
        /* Simulate Error Query */
        *errCode = 0;
        strcpy (errMessage, "No error.");
    }

Error:
    if (p2buf) free (p2buf);
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*****************************************************************************
 * Function: rsbtc_error_message
 * Purpose:  This function translates the error codes returned by this
 *           instrument driver into user-readable strings.
 *
 *           Note:  The caller can pass NULL for the vi parameter.  This
 *           is useful if one of the init functions fail.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_error_message (ViSession instrSession, ViStatus errorCode,
                                          ViChar errorMessage[])
{
    ViStatus    error   = VI_SUCCESS;

    static      RsStringValueTable errorTable =
        {
 
            RSBTC_ERROR_CODES_AND_MSGS,
            {NULL,                               NULL}
        };

    (void) Rs_LockSession(instrSession, NULL);

        /* all VISA and RS error codes are handled as well as codes in the table */
    if (errorMessage == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Error Message");

    checkErr( Rs_GetSpecificDriverStatusDesc(instrSession, errorCode, errorMessage, errorTable));

Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/*===========================================================================*/
/* Function: Set OPC Timeout                                                 */
/* Purpose:  Sets new OPC timeout                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsbtc_SetOPCTimeout (ViSession instrSession,
                                       ViInt32 timeout)
{
	ViStatus    error = VI_SUCCESS; 
    
    checkErr( Rs_SetAttribute (instrSession, NULL, RSBTC_ATTR_OPC_TIMEOUT, 0, &timeout));  
    
Error:    
    return error;
}
/*===========================================================================*/
/* Function: Get OPC Timeout                                                 */
/* Purpose:  Gets new OPC timeout                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsbtc_GetOPCTimeout(ViSession instrSession, ViInt32 *timeout)

{
    ViStatus    error = VI_SUCCESS; 
    
    checkErr( Rs_GetAttribute (instrSession, NULL, RSBTC_ATTR_OPC_TIMEOUT, 0, sizeof(timeout), timeout));  
    
Error:    
    return error;
}
/*****************************************************************************
 * Function: rsbtc_GetError and rsbtc_ClearError Functions
 * Purpose:  These functions enable the instrument driver user to
 *           get or clear the error information the driver associates with the
 *           RS session.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_GetError (ViSession instrSession,
                                     ViStatus *errorCode,
                                     ViInt32 bufferSize,
                                     ViChar description[])
{
    ViStatus    error       = VI_SUCCESS;
    ViStatus    primary     = VI_SUCCESS,
                secondary   = VI_SUCCESS;
    ViChar      elaboration[RS_MAX_MESSAGE_BUF_SIZE]    = "";
    ViChar      errorMessage[1024]  = "";
    ViChar     *appendPoint = errorMessage;
    ViInt32     actualSize  = 0;
    ViBoolean   locked      = VI_FALSE;

    /* Lock Session */
    checkErr( Rs_LockSession(instrSession, &locked));

    /* Test for nulls and acquire error data */
    if (bufferSize != 0)
        {
        if (errorCode == NULL)
            {
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Error");
            }
        if (description == NULL)
            {
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Null address for Description");
            }
        checkErr( Rs_GetErrorInfo (instrSession, &primary, &secondary, elaboration));
        }

    else
        {
        checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_ERROR_ELABORATION, 0, RS_MAX_MESSAGE_BUF_SIZE, elaboration));
        checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_SECONDARY_ERROR, 0, (ViInt32) sizeof (secondary), &secondary));
        checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_PRIMARY_ERROR, 0, (ViInt32) sizeof (primary), &primary));
        }

    /* Format data */
    if (primary != VI_SUCCESS)
        {
        ViChar msg[256] = "";
        checkErr( rsbtc_error_message (instrSession, primary, msg));
        appendPoint += sprintf(appendPoint, "Primary Error: (Hex 0x%08X) %s\n", (unsigned int) primary, msg);
        }

    if (secondary != VI_SUCCESS)
        {
        ViChar msg[256] = "";
        checkErr( rsbtc_error_message (instrSession, secondary, msg));
        appendPoint += sprintf(appendPoint, "Secondary Error: (Hex 0x%08X) %s\n", (unsigned int) secondary, msg);
        }

    if (elaboration[0] != '\0')
        {
        sprintf(appendPoint, "Elaboration: %s", elaboration);
        }

    actualSize = (ViInt32) strlen(errorMessage) + 1;

    /* Prepare return values */
    if (bufferSize == 0)
        {
        error = actualSize;
        }
    else
        {
        if (bufferSize > 0)
            {
            if (actualSize > bufferSize)
                {
                error = actualSize;
                actualSize = bufferSize;
                }
            }
        memcpy(description, errorMessage, (size_t)(actualSize-1));
        if (description != NULL)
            description[actualSize-1] = '\0';
        }

    if (errorCode != 0)
        {
        *errorCode = primary;
        }

Error:
    /* Unlock Session */
    (void) Rs_UnlockSession (instrSession, &locked);
    return error;
}

ViStatus _VI_FUNC rsbtc_ClearError (ViSession instrSession)
{
    return Rs_ClearErrorInfo (instrSession);
}

/*****************************************************************************
 * Function: rsbtc_LockSession and rsbtc_UnlockSession Functions
 * Purpose:  These functions enable the instrument driver user to lock the
 *           session around a sequence of driver calls during which other
 *           execution threads must not disturb the instrument state.
 *
 *           NOTE:  The callerHasLock parameter must be a local variable
 *           initialized to VI_FALSE and passed by reference, or you can pass
 *           NULL.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_LockSession (ViSession instrSession, ViBoolean *callerHasLock)
{
    return Rs_LockSession(instrSession, callerHasLock);
}

ViStatus _VI_FUNC rsbtc_UnlockSession (ViSession instrSession, ViBoolean *callerHasLock)
{
    return Rs_UnlockSession(instrSession,callerHasLock);
}


/*============================================================================/
 * Function: Store and Load Application
 * Purpose:  This function stores or recalls application settings in the
 *           specified file.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_storeLoadApplication (ViSession instrSession,
                                                         ViInt32 operation,
                                                         ViString source)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      buffer[RSBTC_IO_BUFFER_SIZE] = ""; 

    checkErr( Rs_LockSession (instrSession, NULL));

    if ((operation < RSBTC_VAL_SAVE) || (operation > RSBTC_VAL_RECALL))
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Operation");
        
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */

        switch (operation){
            case RSBTC_VAL_SAVE:
                 sprintf (buffer,"*SAV 1;:MMEMory:STORe:STATe 1,\"%s\";*OPC", source);
            break;
        
            case RSBTC_VAL_RECALL:
                sprintf (buffer,":MMEMory:LOAD:STATe 1,\"%s\";*RCL 1;*OPC", source);
            break;
        }   
    }
    viCheckErr( viPrintf (instrSession, "%s\n", buffer));
    viCheckErr (rsbtc_WaitForOPC (instrSession, 60000));
    viCheckErr(rsbtc_CheckStatus (instrSession));       
     
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}
     

/*============================================================================/
 * Function: Store and Load Instrument Data
 * Purpose:  This function stores or recalls instrument data.
/============================================================================*/
ViStatus _VI_FUNC rsbtc_storeLoadInstrumentData (ViSession instrSession,
                                                 ViInt32 operation,
                                                 ViInt32 stateNumber)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, NULL));
  
    if (Rs_Simulating(instrSession) == 0) {                /* call only when locked */
    switch (operation){
        case RSBTC_VAL_SAVE:
             viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_SAV, stateNumber),
                         3, "State Number"); 
        break;
        
        case RSBTC_VAL_RECALL:
             viCheckParm (rsbtc_SetAttributeViInt32 (instrSession, "", RSBTC_ATTR_RCL, stateNumber),
                         3, "State Number"); 
        break;
        }
    }
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}





/*****************************************************************************
 * Function: rsbtc_GetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to get
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession attributes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rsbtc_GetAttributeViInt32 (ViSession instrSession, ViString channelName,
                                                ViUInt32 attributeId, ViInt32 *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViInt32), (ViInt32 *)value);
}

/* ViReal64 */
ViStatus _VI_FUNC rsbtc_GetAttributeViReal64 (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViReal64 *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViReal64), (ViReal64 *)value);
}

/* ViString */
ViStatus _VI_FUNC rsbtc_GetAttributeViString (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViInt32 bufSize,
                                                 ViChar value[])
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            bufSize, value);
}

/* ViBoolean */
ViStatus _VI_FUNC rsbtc_GetAttributeViBoolean (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViBoolean *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViBoolean), (ViBoolean *)value);
}

/* ViSession */
ViStatus _VI_FUNC rsbtc_GetAttributeViSession (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViSession *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViSession), (ViSession *)value);
}

/*****************************************************************************
 * Function: rsbtc_SetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to set
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rsbtc_SetAttributeViInt32 (ViSession instrSession, ViString channelName,
                                                ViUInt32 attributeId, ViInt32 value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/* ViReal64 */
ViStatus _VI_FUNC rsbtc_SetAttributeViReal64 (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViReal64 value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/* ViString */
ViStatus _VI_FUNC rsbtc_SetAttributeViString (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViString value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);
}

/* ViBoolean */
ViStatus _VI_FUNC rsbtc_SetAttributeViBoolean (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViBoolean value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/* ViSession */
ViStatus _VI_FUNC rsbtc_SetAttributeViSession (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViSession value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/*****************************************************************************
 * Function: rsbtc_CheckAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to check
 *           attribute values directly.  These functions check the value you
 *           specify even if you set the RSBTC_ATTR_RANGE_CHECK
 *           attribute to VI_FALSE.  There are typesafe versions for ViInt32,
 *           ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rsbtc_CheckAttributeViInt32 (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViInt32 value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/* ViReal64 */
ViStatus _VI_FUNC rsbtc_CheckAttributeViReal64 (ViSession instrSession, ViString channelName,
                                                   ViUInt32 attributeId, ViReal64 value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/* ViString */
ViStatus _VI_FUNC rsbtc_CheckAttributeViString (ViSession instrSession, ViString channelName,
                                                   ViUInt32 attributeId, ViString value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);
}

/* ViBoolean */
ViStatus _VI_FUNC rsbtc_CheckAttributeViBoolean (ViSession instrSession, ViString channelName,
                                                    ViUInt32 attributeId, ViBoolean value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/* ViSession */
ViStatus _VI_FUNC rsbtc_CheckAttributeViSession (ViSession instrSession, ViString channelName,
                                                    ViUInt32 attributeId, ViSession value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/*****************************************************************************
 * Function: Rs_GetAttributeRepCapNameId
 * Purpose:  This function returns the repeated capability id(s) that
 *           belongs to the attribute you specify. More then one id is listed
 *           in comma separated string.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_GetAttributeRepeatedCapabilityIds (ViSession instrSession,
                                                            ViUInt32 attributeID,
                                                            ViInt32 bufferSize,
                                                            ViChar _VI_FAR repeatedCapabilityIds[])
{
    ViStatus    error = VI_SUCCESS;
    ViChar      repCapNameId[RS_MAX_MESSAGE_BUF_SIZE] = "";

    if (bufferSize <= 0)
        viCheckParm(RS_ERROR_INVALID_PARAMETER, 3, "Buffer Size");

    viCheckErr (Rs_GetAttributeRepCapNameId (instrSession, attributeID, repCapNameId));

    strncpy (repeatedCapabilityIds, repCapNameId, RS_MAX_MESSAGE_BUF_SIZE);
    repeatedCapabilityIds[(bufferSize > RS_MAX_MESSAGE_BUF_SIZE) ?
        RS_MAX_MESSAGE_BUF_SIZE : bufferSize] = '\0';

Error:
    return error;
}

/*****************************************************************************
 * Function: Get Attribute Repeated Capability Id Name(s)
 * Purpose:  This function returns the repeated capability name(s) that
 *           belongs to the attribute and single repeated capability id you
 *           may specify. More then one name is listed in comma separated
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_GetAttributeRepeatedCapabilityIdNames (ViSession instrSession,
                                                                /*@unused@*/ViUInt32 attributeID,
                                                                ViString repeatedCapabilityId,
                                                                ViInt32 bufferSize,
                                                                ViChar _VI_FAR repeatedCapabilityIdNames[])
{
    ViStatus    error = VI_SUCCESS;
    RsSessionPropertiesPtr  sessionProperties = Rs_ViSession (instrSession);
    ViUInt32     rcap;
	attributeID;

    if (bufferSize <= 0)
        viCheckParm(RS_ERROR_INVALID_PARAMETER, 4, "Buffer Size");

    for (rcap = 0; rcap < sessionProperties -> numberOfRepCaps; rcap++)
        if (strncmp (sessionProperties -> repCapTable[rcap].repCapNameId, repeatedCapabilityId, strlen (repeatedCapabilityId)) == 0)
            break;

    strncpy (repeatedCapabilityIdNames, sessionProperties -> repCapTable[rcap].repCapName, RS_MAX_MESSAGE_BUF_SIZE);
    repeatedCapabilityIdNames[(bufferSize > RS_MAX_MESSAGE_BUF_SIZE) ?
        RS_MAX_MESSAGE_BUF_SIZE - 1 : bufferSize - 1] = '\0';

Error:
    return error;
}

/*****************************************************************************
 * Function: WriteInstrData and ReadInstrData Functions
 * Purpose:  These functions enable the instrument driver user to
 *           write and read commands directly to and from the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rsbtc_WriteInstrData (ViSession instrSession, ViString writeBuffer)
{
    return Rs_WriteInstrData (instrSession, writeBuffer);
}

ViStatus _VI_FUNC rsbtc_ReadInstrData (ViSession instrSession, ViInt32 numBytes,
                                          ViChar rdBuf[], ViInt32 *bytesRead)
{
    return Rs_ReadInstrData (instrSession, numBytes, rdBuf, (ViUInt32 *) bytesRead);
}

/*****************************************************************************
 *------------------- End Instrument Driver Source Code ---------------------*
 *****************************************************************************/
